builder.BaseNode

BaseNode(node=None)

Base class for all node wrappers.

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
name The name of the node being wrapped by this instance.
node
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
outputs
tree The TreeBuilder instance this node belongs to and is being built within.