export.to_mermaid
to_mermaid(tree, fenced=True)Generate a Mermaid diagram string from a node tree.
Arguments
tree:
TreeBuilder or Blender node tree
fenced:
Whether to wrap the output in a fenced code block
Returns
| Name | Type | Description |
|---|---|---|
| A string containing the Mermaid diagram as a possibly fenced markdown code block |