nodes.compositor.converter

converter

Classes

Name Description
AlphaConvert Convert to and from premultiplied (associated) alpha
CombineColor Combine an image from its composite color channels
ConvertColorspace Convert between color spaces
ConvertToDisplay Convert from scene linear to display color space, with a view transform and look for tone mapping
IDMask Create a matte from an object or material index pass
Levels Compute average and standard deviation of pixel values
Mix Mix values by a factor
RGBToBw Convert RGB input into grayscale using luminance
RelativeToPixel Converts values that are relative to the image size to be in terms of pixels
SeparateColor Split an image into its composite color channels
SetAlpha Add an alpha channel to an image
Split Combine two images for side-by-side display. Typically used in combination with a Viewer node
Switch Switch between two images using a checkbox
SwitchView Combine the views (left and right) into a single stereo 3D output

AlphaConvert

AlphaConvert(image=None, type='To Premultiplied')

Convert to and from premultiplied (associated) alpha

Parameters

Name Type Description Default
image InputColor Image None
type InputMenu | Literal['To Premultiplied', 'To Straight'] Type 'To Premultiplied'

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
to_premultiplied Create Alpha Convert node with type ‘To Premultiplied’.
to_straight Create Alpha Convert node with type ‘To Straight’.
to_premultiplied
to_premultiplied(image=None)

Create Alpha Convert node with type ‘To Premultiplied’.

to_straight
to_straight(image=None)

Create Alpha Convert node with type ‘To Straight’.

Inputs

Attribute Type Description
i.image ColorSocket Image
i.type MenuSocket Type

Outputs

Attribute Type Description
o.image ColorSocket Image

CombineColor

CombineColor(
    red=0.0,
    green=0.0,
    blue=0.0,
    alpha=1.0,
    *,
    mode='RGB',
    ycc_mode='ITUBT709',
)

Combine an image from its composite color channels

Parameters

Name Type Description Default
red InputFloat Red 0.0
green InputFloat Green 0.0
blue InputFloat Blue 0.0
alpha InputFloat Alpha 1.0

Attributes

Name Description
i
inputs
mode
name
node
o
outputs
tree
type
ycc_mode

Methods

Name Description
hsl Create Combine Color with operation ‘HSL’. Use HSL (Hue, Saturation, Lightness) color processing
hsv Create Combine Color with operation ‘HSV’. Use HSV (Hue, Saturation, Value) color processing
rgb Create Combine Color with operation ‘RGB’. Use RGB (Red, Green, Blue) color processing
ycbcr Create Combine Color with operation ‘YCbCr’. Use YCbCr (Y - luma, Cb - blue-difference chroma, Cr - red-difference chroma) color processing
yuv Create Combine Color with operation ‘YUV’. Use YUV (Y - luma, U V - chroma) color processing
hsl
hsl(red=0.0, green=0.0, blue=0.0, alpha=1.0)

Create Combine Color with operation ‘HSL’. Use HSL (Hue, Saturation, Lightness) color processing

hsv
hsv(red=0.0, green=0.0, blue=0.0, alpha=1.0)

Create Combine Color with operation ‘HSV’. Use HSV (Hue, Saturation, Value) color processing

rgb
rgb(red=0.0, green=0.0, blue=0.0, alpha=1.0)

Create Combine Color with operation ‘RGB’. Use RGB (Red, Green, Blue) color processing

ycbcr
ycbcr(red=0.0, green=0.0, blue=0.0, alpha=1.0)

Create Combine Color with operation ‘YCbCr’. Use YCbCr (Y - luma, Cb - blue-difference chroma, Cr - red-difference chroma) color processing

yuv
yuv(red=0.0, green=0.0, blue=0.0, alpha=1.0)

Create Combine Color with operation ‘YUV’. Use YUV (Y - luma, U V - chroma) color processing

Inputs

Attribute Type Description
i.red FloatSocket Red
i.green FloatSocket Green
i.blue FloatSocket Blue
i.alpha FloatSocket Alpha

Outputs

Attribute Type Description
o.image ColorSocket Image

ConvertColorspace

ConvertColorspace(
    image=None,
    *,
    from_color_space='scene_linear',
    to_color_space='scene_linear',
)

Convert between color spaces

Parameters

Name Type Description Default
image InputColor Image None

Attributes

Name Description
from_color_space
i
inputs
name
node
o
outputs
to_color_space
tree
type

Inputs

Attribute Type Description
i.image ColorSocket Image

Outputs

Attribute Type Description
o.image ColorSocket Image

ConvertToDisplay

ConvertToDisplay(image=None, invert=False)

Convert from scene linear to display color space, with a view transform and look for tone mapping

Parameters

Name Type Description Default
image InputColor Image None
invert InputBoolean Invert False

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.image ColorSocket Image
i.invert BooleanSocket Invert

Outputs

Attribute Type Description
o.image ColorSocket Image

IDMask

IDMask(id_value=1.0, index=0, anti_alias=False)

Create a matte from an object or material index pass

Parameters

Name Type Description Default
id_value InputFloat ID value 1.0
index InputInteger Index 0
anti_alias InputBoolean Anti-Alias False

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.id_value FloatSocket ID value
i.index IntegerSocket Index
i.anti_alias BooleanSocket Anti-Alias

Outputs

Attribute Type Description
o.alpha FloatSocket Alpha

Levels

Levels(image=None, channel='Combined')

Compute average and standard deviation of pixel values

Parameters

Name Type Description Default
image InputColor Image None
channel InputMenu | Literal['Combined', 'Red', 'Green', 'Blue', 'Luminance'] Channel 'Combined'

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.image ColorSocket Image
i.channel MenuSocket Channel

Outputs

Attribute Type Description
o.mean FloatSocket Mean
o.standard_deviation FloatSocket Standard Deviation

Mix

Mix(
    factor_float=0.5,
    factor_vector=None,
    a_float=0.0,
    b_float=0.0,
    a_vector=None,
    b_vector=None,
    a_color=None,
    b_color=None,
    a_rotation=None,
    b_rotation=None,
    *,
    data_type='FLOAT',
    factor_mode='UNIFORM',
    blend_type='MIX',
    clamp_factor=False,
    clamp_result=False,
)

Mix values by a factor

Parameters

Name Type Description Default
factor_float InputFloat Factor 0.5
factor_vector InputVector Factor None
a_float InputFloat A 0.0
b_float InputFloat B 0.0
a_vector InputVector A None
b_vector InputVector B None
a_color InputColor A None
b_color InputColor B None
a_rotation InputRotation A None
b_rotation InputRotation B None

Attributes

Name Description
blend_type
clamp_factor
clamp_result
data_type
factor_mode
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
color Create Mix with operation ‘Color’.
float Create Mix with operation ‘Float’.
vector Create Mix with operation ‘Vector’.
color
color(factor=0.5, a_color=None, b_color=None)

Create Mix with operation ‘Color’.

float
float(factor=0.5, a=0.0, b=0.0)

Create Mix with operation ‘Float’.

vector
vector(factor=0.5, a=None, b=None)

Create Mix with operation ‘Vector’.

Inputs

Attribute Type Description
i.factor_float FloatSocket Factor
i.factor_vector VectorSocket Factor
i.a_float FloatSocket A
i.b_float FloatSocket B
i.a_vector VectorSocket A
i.b_vector VectorSocket B
i.a_color ColorSocket A
i.b_color ColorSocket B
i.a_rotation RotationSocket A
i.b_rotation RotationSocket B

Outputs

Attribute Type Description
o.result_float FloatSocket Result
o.result_vector VectorSocket Result
o.result_color ColorSocket Result
o.result_rotation RotationSocket Result

RGBToBw

RGBToBw(image=None)

Convert RGB input into grayscale using luminance

Parameters

Name Type Description Default
image InputColor Image None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.image ColorSocket Image

Outputs

Attribute Type Description
o.val FloatSocket Val

RelativeToPixel

RelativeToPixel(
    vector_value=None,
    float_value=0.0,
    image=None,
    *,
    data_type='FLOAT',
    reference_dimension='X',
)

Converts values that are relative to the image size to be in terms of pixels

Parameters

Name Type Description Default
vector_value InputVector Value None
float_value InputFloat Value 0.0
image InputColor Image None

Attributes

Name Description
data_type
i
inputs
name
node
o
outputs
reference_dimension
tree
type

Methods

Name Description
float Create Relative To Pixel with operation ‘Float’. Float value
vector Create Relative To Pixel with operation ‘Vector’. Vector value
float
float(float_value=0.0, image=None)

Create Relative To Pixel with operation ‘Float’. Float value

vector
vector(vector_value=None, image=None)

Create Relative To Pixel with operation ‘Vector’. Vector value

Inputs

Attribute Type Description
i.vector_value VectorSocket Value
i.float_value FloatSocket Value
i.image ColorSocket Image

Outputs

Attribute Type Description
o.float_value FloatSocket Value
o.vector_value VectorSocket Value

SeparateColor

SeparateColor(image=None, *, mode='RGB', ycc_mode='ITUBT709')

Split an image into its composite color channels

Parameters

Name Type Description Default
image InputColor Image None

Attributes

Name Description
i
inputs
mode
name
node
o
outputs
tree
type
ycc_mode

Methods

Name Description
hsl Create Separate Color with operation ‘HSL’. Use HSL (Hue, Saturation, Lightness) color processing
hsv Create Separate Color with operation ‘HSV’. Use HSV (Hue, Saturation, Value) color processing
rgb Create Separate Color with operation ‘RGB’. Use RGB (Red, Green, Blue) color processing
ycbcr Create Separate Color with operation ‘YCbCr’. Use YCbCr (Y - luma, Cb - blue-difference chroma, Cr - red-difference chroma) color processing
yuv Create Separate Color with operation ‘YUV’. Use YUV (Y - luma, U V - chroma) color processing
hsl
hsl(image=None)

Create Separate Color with operation ‘HSL’. Use HSL (Hue, Saturation, Lightness) color processing

hsv
hsv(image=None)

Create Separate Color with operation ‘HSV’. Use HSV (Hue, Saturation, Value) color processing

rgb
rgb(image=None)

Create Separate Color with operation ‘RGB’. Use RGB (Red, Green, Blue) color processing

ycbcr
ycbcr(image=None)

Create Separate Color with operation ‘YCbCr’. Use YCbCr (Y - luma, Cb - blue-difference chroma, Cr - red-difference chroma) color processing

yuv
yuv(image=None)

Create Separate Color with operation ‘YUV’. Use YUV (Y - luma, U V - chroma) color processing

Inputs

Attribute Type Description
i.image ColorSocket Image

Outputs

Attribute Type Description
o.red FloatSocket Red
o.green FloatSocket Green
o.blue FloatSocket Blue
o.alpha FloatSocket Alpha

SetAlpha

SetAlpha(image=None, alpha=1.0, type='Apply Mask')

Add an alpha channel to an image

Parameters

Name Type Description Default
image InputColor Image None
alpha InputFloat Alpha 1.0
type InputMenu | Literal['Apply Mask', 'Replace Alpha'] Type 'Apply Mask'

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
apply_mask Create Set Alpha node with type ‘Apply Mask’.
replace_alpha Create Set Alpha node with type ‘Replace Alpha’.
apply_mask
apply_mask(image=None, alpha=1.0)

Create Set Alpha node with type ‘Apply Mask’.

replace_alpha
replace_alpha(image=None, alpha=1.0)

Create Set Alpha node with type ‘Replace Alpha’.

Inputs

Attribute Type Description
i.image ColorSocket Image
i.alpha FloatSocket Alpha
i.type MenuSocket Type

Outputs

Attribute Type Description
o.image ColorSocket Image

Split

Split(position=None, rotation=0.7854, image=None, image_001=None)

Combine two images for side-by-side display. Typically used in combination with a Viewer node

Parameters

Name Type Description Default
position InputVector Position None
rotation InputFloat Rotation 0.7854
image InputColor Image None
image_001 InputColor Image None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.position VectorSocket Position
i.rotation FloatSocket Rotation
i.image ColorSocket Image
i.image_001 ColorSocket Image

Outputs

Attribute Type Description
o.image ColorSocket Image

Switch

Switch(switch=False, off=None, on=None)

Switch between two images using a checkbox

Parameters

Name Type Description Default
switch InputBoolean Switch False
off InputColor Off None
on InputColor On None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.switch BooleanSocket Switch
i.off ColorSocket Off
i.on ColorSocket On

Outputs

Attribute Type Description
o.image ColorSocket Image

SwitchView

SwitchView(left=None, right=None)

Combine the views (left and right) into a single stereo 3D output

Parameters

Name Type Description Default
left InputColor left None
right InputColor right None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.left ColorSocket left
i.right ColorSocket right

Outputs

Attribute Type Description
o.image ColorSocket Image