nodes.compositor.distort
distort
Classes
| Name | Description |
|---|---|
| CornerPin | Plane warp transformation using explicit corner values |
| Crop | Crops image to a smaller region, either making the cropped area transparent or resizing the image |
| Displace | Displace pixel position using an offset vector |
| Flip | Flip an image along a defined axis |
| LensDistortion | Simulate distortion and dispersion from camera lenses |
| MapUV | Map a texture using UV coordinates, to apply a texture to objects in compositing |
| MovieDistortion | Remove lens distortion from footage, using motion tracking camera lens settings |
| PlaneTrackDeform | Replace flat planes in footage by another image, detected by plane tracks from motion tracking |
| Rotate | Rotate image by specified angle |
| Scale | Change the size of the image |
| Stabilize2D | Stabilize footage using 2D stabilization motion tracking settings |
| Transform | Scale, translate and rotate an image |
| Translate | Offset an image |
CornerPin
CornerPin(
image=None,
upper_left=(0.0, 1.0),
upper_right=(1.0, 1.0),
lower_left=(0.0, 0.0),
lower_right=(1.0, 0.0),
interpolation='Bilinear',
extension_x='Clip',
extension_y='Clip',
)Plane warp transformation using explicit corner values
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| upper_left | InputVector | Upper Left | (0.0, 1.0) |
| upper_right | InputVector | Upper Right | (1.0, 1.0) |
| lower_left | InputVector | Lower Left | (0.0, 0.0) |
| lower_right | InputVector | Lower Right | (1.0, 0.0) |
| interpolation | InputMenu | Literal['Nearest', 'Bilinear', 'Bicubic', 'Anisotropic'] | Interpolation | 'Bilinear' |
| extension_x | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension X | 'Clip' |
| extension_y | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension Y | 'Clip' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.upper_left |
VectorSocket |
Upper Left |
i.upper_right |
VectorSocket |
Upper Right |
i.lower_left |
VectorSocket |
Lower Left |
i.lower_right |
VectorSocket |
Lower Right |
i.interpolation |
MenuSocket |
Interpolation |
i.extension_x |
MenuSocket |
Extension X |
i.extension_y |
MenuSocket |
Extension Y |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
o.plane |
FloatSocket |
Plane |
Crop
Crop(image=None, x=0, y=0, width=1920, height=1080, alpha_crop=False)Crops image to a smaller region, either making the cropped area transparent or resizing the image
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| x | InputInteger | X | 0 |
| y | InputInteger | Y | 0 |
| width | InputInteger | Width | 1920 |
| height | InputInteger | Height | 1080 |
| alpha_crop | InputBoolean | Alpha Crop | False |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.x |
IntegerSocket |
X |
i.y |
IntegerSocket |
Y |
i.width |
IntegerSocket |
Width |
i.height |
IntegerSocket |
Height |
i.alpha_crop |
BooleanSocket |
Alpha Crop |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Displace
Displace(
image=None,
displacement=(0.0, 0.0),
interpolation='Bilinear',
extension_x='Clip',
extension_y='Clip',
)Displace pixel position using an offset vector
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| displacement | InputVector | Displacement | (0.0, 0.0) |
| interpolation | InputMenu | Literal['Nearest', 'Bilinear', 'Bicubic', 'Anisotropic'] | Interpolation | 'Bilinear' |
| extension_x | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension X | 'Clip' |
| extension_y | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension Y | 'Clip' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.displacement |
VectorSocket |
Displacement |
i.interpolation |
MenuSocket |
Interpolation |
i.extension_x |
MenuSocket |
Extension X |
i.extension_y |
MenuSocket |
Extension Y |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Flip
Flip(image=None, flip_x=False, flip_y=False)Flip an image along a defined axis
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| flip_x | InputBoolean | Flip X | False |
| flip_y | InputBoolean | Flip Y | False |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.flip_x |
BooleanSocket |
Flip X |
i.flip_y |
BooleanSocket |
Flip Y |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
LensDistortion
LensDistortion(
image=None,
type='Radial',
distortion=0.0,
dispersion=0.0,
jitter=False,
fit=False,
)Simulate distortion and dispersion from camera lenses
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| type | InputMenu | Literal['Radial', 'Horizontal'] | Type | 'Radial' |
| distortion | InputFloat | Distortion | 0.0 |
| dispersion | InputFloat | Dispersion | 0.0 |
| jitter | InputBoolean | Jitter | False |
| fit | InputBoolean | Fit | False |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Methods
| Name | Description |
|---|---|
| horizontal | Create Lens Distortion node with type ‘Horizontal’. |
| radial | Create Lens Distortion node with type ‘Radial’. |
horizontal
horizontal(image=None, dispersion=0.0)Create Lens Distortion node with type ‘Horizontal’.
radial
radial(image=None, distortion=0.0, dispersion=0.0, jitter=False, fit=False)Create Lens Distortion node with type ‘Radial’.
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.type |
MenuSocket |
Type |
i.distortion |
FloatSocket |
Distortion |
i.dispersion |
FloatSocket |
Dispersion |
i.jitter |
BooleanSocket |
Jitter |
i.fit |
BooleanSocket |
Fit |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
MapUV
MapUV(
image=None,
uv=(1.0, 0.0, 0.0),
interpolation='Bilinear',
extension_x='Clip',
extension_y='Clip',
)Map a texture using UV coordinates, to apply a texture to objects in compositing
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| uv | InputVector | UV | (1.0, 0.0, 0.0) |
| interpolation | InputMenu | Literal['Nearest', 'Bilinear', 'Bicubic', 'Anisotropic'] | Interpolation | 'Bilinear' |
| extension_x | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension X | 'Clip' |
| extension_y | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension Y | 'Clip' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.uv |
VectorSocket |
UV |
i.interpolation |
MenuSocket |
Interpolation |
i.extension_x |
MenuSocket |
Extension X |
i.extension_y |
MenuSocket |
Extension Y |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
MovieDistortion
MovieDistortion(image=(0.8, 0.8, 0.8, 1.0), type='Undistort')Remove lens distortion from footage, using motion tracking camera lens settings
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | (0.8, 0.8, 0.8, 1.0) |
| type | InputMenu | Literal['Undistort', 'Distort'] | Type | 'Undistort' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Methods
| Name | Description |
|---|---|
| distort | Create Movie Distortion node with type ‘Distort’. |
| undistort | Create Movie Distortion node with type ‘Undistort’. |
distort
distort(image=(0.8, 0.8, 0.8, 1.0))Create Movie Distortion node with type ‘Distort’.
undistort
undistort(image=(0.8, 0.8, 0.8, 1.0))Create Movie Distortion node with type ‘Undistort’.
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.type |
MenuSocket |
Type |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
PlaneTrackDeform
PlaneTrackDeform(
image=None,
motion_blur=False,
motion_blur_samples=16,
motion_blur_shutter=0.5,
*,
tracking_object='',
plane_track_name='',
)Replace flat planes in footage by another image, detected by plane tracks from motion tracking
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| motion_blur | InputBoolean | Motion Blur | False |
| motion_blur_samples | InputInteger | Samples | 16 |
| motion_blur_shutter | InputFloat | Shutter | 0.5 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
plane_track_name |
|
tracking_object |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.motion_blur |
BooleanSocket |
Motion Blur |
i.motion_blur_samples |
IntegerSocket |
Samples |
i.motion_blur_shutter |
FloatSocket |
Shutter |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
o.plane |
FloatSocket |
Plane |
Rotate
Rotate(
image=None,
angle=0.0,
interpolation='Bilinear',
extension_x='Clip',
extension_y='Clip',
)Rotate image by specified angle
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| angle | InputFloat | Angle | 0.0 |
| interpolation | InputMenu | Literal['Nearest', 'Bilinear', 'Bicubic', 'Anisotropic'] | Interpolation | 'Bilinear' |
| extension_x | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension X | 'Clip' |
| extension_y | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension Y | 'Clip' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.angle |
FloatSocket |
Angle |
i.interpolation |
MenuSocket |
Interpolation |
i.extension_x |
MenuSocket |
Extension X |
i.extension_y |
MenuSocket |
Extension Y |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Scale
Scale(
image=None,
type='Relative',
x=1.0,
y=1.0,
frame_type='Stretch',
interpolation='Bilinear',
extension_x='Clip',
extension_y='Clip',
)Change the size of the image
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| type | InputMenu | Literal['Relative', 'Absolute', 'Scene Size', 'Render Size'] | Type | 'Relative' |
| x | InputFloat | X | 1.0 |
| y | InputFloat | Y | 1.0 |
| frame_type | InputMenu | Literal['Stretch', 'Fit', 'Crop'] | Frame Type | 'Stretch' |
| interpolation | InputMenu | Literal['Nearest', 'Bilinear', 'Bicubic', 'Anisotropic'] | Interpolation | 'Bilinear' |
| extension_x | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension X | 'Clip' |
| extension_y | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension Y | 'Clip' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Methods
| Name | Description |
|---|---|
| absolute | Create Scale node with type ‘Absolute’. |
| relative | Create Scale node with type ‘Relative’. |
| render_size | Create Scale node with type ‘Render Size’. |
| scene_size | Create Scale node with type ‘Scene Size’. |
absolute
absolute(
image=None,
x=1.0,
y=1.0,
interpolation='Bilinear',
extension_x='Clip',
extension_y='Clip',
)Create Scale node with type ‘Absolute’.
relative
relative(
image=None,
x=1.0,
y=1.0,
interpolation='Bilinear',
extension_x='Clip',
extension_y='Clip',
)Create Scale node with type ‘Relative’.
render_size
render_size(
image=None,
frame_type='Stretch',
interpolation='Bilinear',
extension_x='Clip',
extension_y='Clip',
)Create Scale node with type ‘Render Size’.
scene_size
scene_size(
image=None,
interpolation='Bilinear',
extension_x='Clip',
extension_y='Clip',
)Create Scale node with type ‘Scene Size’.
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.type |
MenuSocket |
Type |
i.x |
FloatSocket |
X |
i.y |
FloatSocket |
Y |
i.frame_type |
MenuSocket |
Frame Type |
i.interpolation |
MenuSocket |
Interpolation |
i.extension_x |
MenuSocket |
Extension X |
i.extension_y |
MenuSocket |
Extension Y |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Stabilize2D
Stabilize2D(
image=None,
frame=None,
invert=False,
interpolation='Bilinear',
extension_x='Clip',
extension_y='Clip',
)Stabilize footage using 2D stabilization motion tracking settings
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| frame | InputInteger | Frame | None |
| invert | InputBoolean | Invert | False |
| interpolation | InputMenu | Literal['Nearest', 'Bilinear', 'Bicubic', 'Anisotropic'] | Interpolation | 'Bilinear' |
| extension_x | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension X | 'Clip' |
| extension_y | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension Y | 'Clip' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.frame |
IntegerSocket |
Frame |
i.invert |
BooleanSocket |
Invert |
i.interpolation |
MenuSocket |
Interpolation |
i.extension_x |
MenuSocket |
Extension X |
i.extension_y |
MenuSocket |
Extension Y |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Transform
Transform(
image=None,
x=0.0,
y=0.0,
angle=0.0,
scale=1.0,
interpolation='Bilinear',
extension_x='Clip',
extension_y='Clip',
)Scale, translate and rotate an image
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| x | InputFloat | X | 0.0 |
| y | InputFloat | Y | 0.0 |
| angle | InputFloat | Angle | 0.0 |
| scale | InputFloat | Scale | 1.0 |
| interpolation | InputMenu | Literal['Nearest', 'Bilinear', 'Bicubic', 'Anisotropic'] | Interpolation | 'Bilinear' |
| extension_x | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension X | 'Clip' |
| extension_y | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension Y | 'Clip' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.x |
FloatSocket |
X |
i.y |
FloatSocket |
Y |
i.angle |
FloatSocket |
Angle |
i.scale |
FloatSocket |
Scale |
i.interpolation |
MenuSocket |
Interpolation |
i.extension_x |
MenuSocket |
Extension X |
i.extension_y |
MenuSocket |
Extension Y |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Translate
Translate(
image=None,
x=0.0,
y=0.0,
interpolation='Bilinear',
extension_x='Clip',
extension_y='Clip',
)Offset an image
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| x | InputFloat | X | 0.0 |
| y | InputFloat | Y | 0.0 |
| interpolation | InputMenu | Literal['Nearest', 'Bilinear', 'Bicubic', 'Anisotropic'] | Interpolation | 'Bilinear' |
| extension_x | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension X | 'Clip' |
| extension_y | InputMenu | Literal['Clip', 'Extend', 'Repeat'] | Extension Y | 'Clip' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.x |
FloatSocket |
X |
i.y |
FloatSocket |
Y |
i.interpolation |
MenuSocket |
Interpolation |
i.extension_x |
MenuSocket |
Extension X |
i.extension_y |
MenuSocket |
Extension Y |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |