nodes.compositor.input

input

Classes

Name Description
BlankImage Returns an image with the given size and constant color
BokehImage Generate image with bokeh shape for use with the Bokeh Blur filter node
Color A color picker
ImageCoordinates Returns the coordinates of the pixels of an image
ImageInfo Returns information about an image
Mask Input mask from a mask data-block, created in the image editor
MovieClip Input image or movie from a movie clip data-block, typically used for motion tracking
Normal Input normalized normal values to other nodes in the tree
RenderLayers Input render passes from a scene render
SceneTime Input the current scene time in seconds or frames
SequencerStripInfo Returns information about the active strip of the modifier
StringToImage Generates an image containing the given paragraph of text
TimeCurve Generate a factor value (from 0.0 to 1.0) between scene start and end time, using a curve mapping
TrackPosition Provide information about motion tracking points, such as x and y values

BlankImage

BlankImage(color=None, size=None)

Returns an image with the given size and constant color

Parameters

Name Type Description Default
color InputColor Color None
size InputInteger Size None

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Inputs

Attribute Type Description
i.color ColorSocket Color
i.size IntegerSocket Size

Outputs

Attribute Type Description
o.image ColorSocket Image

BokehImage

BokehImage(
    flaps=5,
    angle=0.0,
    roundness=0.0,
    catadioptric_size=0.0,
    color_shift=0.0,
)

Generate image with bokeh shape for use with the Bokeh Blur filter node

Parameters

Name Type Description Default
flaps InputInteger Flaps 5
angle InputFloat Angle 0.0
roundness InputFloat Roundness 0.0
catadioptric_size InputFloat Catadioptric Size 0.0
color_shift InputFloat Color Shift 0.0

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Inputs

Attribute Type Description
i.flaps IntegerSocket Flaps
i.angle FloatSocket Angle
i.roundness FloatSocket Roundness
i.catadioptric_size FloatSocket Catadioptric Size
i.color_shift FloatSocket Color Shift

Outputs

Attribute Type Description
o.image ColorSocket Image

Color

Color()

A color picker

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Outputs

Attribute Type Description
o.color ColorSocket Color

ImageCoordinates

ImageCoordinates(image=None)

Returns the coordinates of the pixels of an image

Parameters

Name Type Description Default
image InputColor Image None

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Inputs

Attribute Type Description
i.image ColorSocket Image

Outputs

Attribute Type Description
o.uniform VectorSocket Uniform
o.normalized VectorSocket Normalized
o.pixel IntegerSocket Pixel

ImageInfo

ImageInfo(image=None)

Returns information about an image

Parameters

Name Type Description Default
image InputColor Image None

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Inputs

Attribute Type Description
i.image ColorSocket Image

Outputs

Attribute Type Description
o.dimensions IntegerSocket Dimensions
o.resolution IntegerSocket Resolution
o.location VectorSocket Location
o.rotation FloatSocket Rotation
o.scale VectorSocket Scale

Mask

Mask(
    size_source='Scene Size',
    size_x=256,
    size_y=256,
    feather=True,
    motion_blur=False,
    motion_blur_samples=16,
    motion_blur_shutter=0.5,
)

Input mask from a mask data-block, created in the image editor

Parameters

Name Type Description Default
size_source InputMenu | Literal['Scene Size', 'Fixed', 'Fixed/Scene'] Size Source 'Scene Size'
size_x InputInteger Size X 256
size_y InputInteger Size Y 256
feather InputBoolean Feather True
motion_blur InputBoolean Motion Blur False
motion_blur_samples InputInteger Samples 16
motion_blur_shutter InputFloat Shutter 0.5

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Inputs

Attribute Type Description
i.size_source MenuSocket Size Source
i.size_x IntegerSocket Size X
i.size_y IntegerSocket Size Y
i.feather BooleanSocket Feather
i.motion_blur BooleanSocket Motion Blur
i.motion_blur_samples IntegerSocket Samples
i.motion_blur_shutter FloatSocket Shutter

Outputs

Attribute Type Description
o.mask FloatSocket Mask

MovieClip

MovieClip()

Input image or movie from a movie clip data-block, typically used for motion tracking

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Outputs

Attribute Type Description
o.image ColorSocket Image
o.alpha FloatSocket Alpha
o.offset_x FloatSocket Offset X
o.offset_y FloatSocket Offset Y
o.scale FloatSocket Scale
o.angle FloatSocket Angle

Normal

Normal()

Input normalized normal values to other nodes in the tree

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Outputs

Attribute Type Description
o.normal VectorSocket Normal

RenderLayers

RenderLayers(layer='ViewLayer')

Input render passes from a scene render

Attributes

Name Description
i
layer
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Outputs

Attribute Type Description
o.image ColorSocket Image
o.alpha FloatSocket Alpha

SceneTime

SceneTime()

Input the current scene time in seconds or frames

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Outputs

Attribute Type Description
o.seconds FloatSocket Seconds
o.frame FloatSocket Frame

SequencerStripInfo

SequencerStripInfo()

Returns information about the active strip of the modifier

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Outputs

Attribute Type Description
o.start_frame IntegerSocket Start Frame
o.end_frame IntegerSocket End Frame
o.location VectorSocket Location
o.rotation FloatSocket Rotation
o.scale VectorSocket Scale

StringToImage

StringToImage(
    string='',
    font=None,
    size=128.0,
    horizontal_alignment='Center',
    vertical_alignment='Middle',
    wrap=True,
    wrap_width=1920,
)

Generates an image containing the given paragraph of text

Parameters

Name Type Description Default
string InputString String ''
font InputFont Font None
size InputFloat Size 128.0
horizontal_alignment InputMenu | Literal['Left', 'Center', 'Right'] Horizontal Alignment 'Center'
vertical_alignment InputMenu | Literal['Top', 'Top Baseline', 'Middle', 'Bottom Baseline', 'Bottom'] Vertical Alignment 'Middle'
wrap InputBoolean Wrap True
wrap_width InputInteger Width 1920

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Inputs

Attribute Type Description
i.string StringSocket String
i.font FontSocket Font
i.size FloatSocket Size
i.horizontal_alignment MenuSocket Horizontal Alignment
i.vertical_alignment MenuSocket Vertical Alignment
i.wrap BooleanSocket Wrap
i.wrap_width IntegerSocket Width

Outputs

Attribute Type Description
o.image FloatSocket Image

TimeCurve

TimeCurve(start_frame=1, end_frame=250)

Generate a factor value (from 0.0 to 1.0) between scene start and end time, using a curve mapping

Parameters

Name Type Description Default
start_frame InputInteger Start Frame 1
end_frame InputInteger End Frame 250

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Inputs

Attribute Type Description
i.start_frame IntegerSocket Start Frame
i.end_frame IntegerSocket End Frame

Outputs

Attribute Type Description
o.fac FloatSocket Factor

TrackPosition

TrackPosition(mode='Absolute', frame=0, *, tracking_object='', track_name='')

Provide information about motion tracking points, such as x and y values

Parameters

Name Type Description Default
mode InputMenu | Literal['Absolute', 'Relative Start', 'Relative Frame', 'Absolute Frame'] Mode 'Absolute'
frame InputInteger Frame 0

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
track_name
tracking_object
tree The TreeBuilder instance this node belongs to and is being built within.

Inputs

Attribute Type Description
i.mode MenuSocket Mode
i.frame IntegerSocket Frame

Outputs

Attribute Type Description
o.x FloatSocket X
o.y FloatSocket Y
o.speed VectorSocket Speed