nodes.compositor.output

output

Classes

Name Description
FileOutput Write image file to disk
Viewer Visualize data from inside a node graph, in the image editor or as a backdrop

FileOutput

FileOutput(
    directory='',
    file_name='',
    save_as_render=False,
    use_file_extension=False,
)

Write image file to disk

Attributes

Name Description
directory
file_name
i
name The name of the node being wrapped by this instance.
node
o
save_as_render
tree The TreeBuilder instance this node belongs to and is being built within.
use_file_extension

Viewer

Viewer(image=(0.0, 0.0, 0.0, 1.0), *, ui_shortcut=0)

Visualize data from inside a node graph, in the image editor or as a backdrop

Parameters

Name Type Description Default
image InputColor Image (0.0, 0.0, 0.0, 1.0)

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
tree The TreeBuilder instance this node belongs to and is being built within.
ui_shortcut

Inputs

Attribute Type Description
i.image ColorSocket Image