nodes.compositor.vector

vector

Classes

Name Description
Normalize Map values to 0 to 1 range, based on the minimum and maximum pixel values

Normalize

Normalize(value=1.0)

Map values to 0 to 1 range, based on the minimum and maximum pixel values

Parameters

Name Type Description Default
value InputFloat Value 1.0

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Inputs

Attribute Type Description
i.value FloatSocket Value

Outputs

Attribute Type Description
o.value FloatSocket Value