nodes.geometry.color

color

Classes

Name Description
Gamma Apply a gamma correction
RGBCurves Apply color corrections for each color channel

Gamma

Gamma(color=None, gamma=1.0)

Apply a gamma correction

Parameters

Name Type Description Default
color InputColor Color None
gamma InputFloat Gamma 1.0

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Inputs

Attribute Type Description
i.color ColorSocket Color
i.gamma FloatSocket Gamma

Outputs

Attribute Type Description
o.color ColorSocket Color

RGBCurves

RGBCurves(fac=1.0, color=None)

Apply color corrections for each color channel

Parameters

Name Type Description Default
fac InputFloat Factor 1.0
color InputColor Color None

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Inputs

Attribute Type Description
i.fac FloatSocket Factor
i.color ColorSocket Color

Outputs

Attribute Type Description
o.color ColorSocket Color