nodes.geometry.converter

converter

Classes

Name Description
AlignRotationToVector Orient a rotation along the given direction
AxesToRotation Create a rotation from a primary and (ideally orthogonal) secondary axis
AxisAngleToRotation Build a rotation from an axis and a rotation around that axis
BitMath Perform bitwise operations on 32-bit integers
Blackbody Convert a blackbody temperature to an RGB value
BooleanMath Perform a logical operation on the given boolean inputs
Clamp Clamp a value between a minimum and a maximum
ColorRamp Map values to colors with the use of a gradient
CombineBundle Combine multiple socket values into one.
CombineColor Combine four channels into a single color, based on a particular color model
CombineMatrix Construct a 4x4 matrix from its individual values
CombineTransform Combine a translation vector, a rotation, and a scale vector into a transformation matrix
CombineXYZ Create a vector from X, Y, and Z components
EulerToRotation Build a rotation from separate angles around each axis
FindInString Find the number of times a given string occurs in another string and the position of the first match
FloatCurve Map an input float to a curve and outputs a float value
FloatToInteger Convert the given floating-point number to an integer, with a choice of methods
HashValue Generate a randomized integer using the given input value as a seed
IndexOfNearest Find the nearest element in a group. Similar to the “Sample Nearest” node
IntegerMath Perform various math operations on the given integer inputs
InvertMatrix Compute the inverse of the given matrix, if one exists
InvertRotation Compute the inverse of the given rotation
JoinBundle Join multiple bundles together
MapRange Remap a value from a range to a target range
MatchString Check if a given string exists within another string
Math Perform math operations
MatrixDeterminant Compute the determinant of the given matrix
Mix Mix values by a factor
MultiplyMatrices Perform a matrix multiplication on two input matrices
PackUVIslands Scale islands of a UV map and move them so they fill the UV space as much as possible
ProjectPoint Project a point using a matrix, using location, rotation, scale, and perspective divide
QuaternionToRotation Build a rotation from quaternion components
RandomValue Output a randomized value
ReplaceString Replace a given string segment with another
RotateEuler Apply a secondary Euler rotation to a given Euler rotation
RotateRotation Apply a secondary rotation to a given rotation value
RotateVector Apply a rotation to a given vector
RotationToAxisAngle Convert a rotation to axis angle components
RotationToEuler Convert a standard rotation value to an Euler rotation
RotationToQuaternion Retrieve the quaternion components representing a rotation
SeparateBundle Split a bundle into multiple sockets.
SeparateColor Split a color into separate channels, based on a particular color model
SeparateMatrix Split a 4x4 matrix into its individual values
SeparateTransform Split a transformation matrix into a translation vector, a rotation, and a scale vector
SeparateXYZ Split a vector into its X, Y, and Z components
SliceString Extract a string segment from a larger string
StringLength Output the number of characters in the given string
StringToValue Derive a numeric value from a given string representation
Switch Switch between two inputs
TransformDirection Apply a transformation matrix (excluding translation) to the given vector
TransformPoint Apply a transformation matrix to the given vector
TransposeMatrix Flip a matrix over its diagonal, turning columns into rows and vice-versa
UVUnwrap Generate a UV map based on seam edges
ValueToString Generate a string representation of the given input value

AlignRotationToVector

AlignRotationToVector(
    rotation=None,
    factor=1.0,
    vector=None,
    *,
    axis='Z',
    pivot_axis='AUTO',
)

Orient a rotation along the given direction

Parameters

Name Type Description Default
rotation InputRotation Rotation None
factor InputFloat Factor 1.0
vector InputVector Vector None

Attributes

Name Description
axis
i
inputs
name
node
o
outputs
pivot_axis
tree
type

Inputs

Attribute Type Description
i.rotation RotationSocket Rotation
i.factor FloatSocket Factor
i.vector VectorSocket Vector

Outputs

Attribute Type Description
o.rotation RotationSocket Rotation

AxesToRotation

AxesToRotation(
    primary_axis=None,
    secondary_axis=None,
    *,
    primary='Z',
    secondary='X',
)

Create a rotation from a primary and (ideally orthogonal) secondary axis

Parameters

Name Type Description Default
primary_axis InputVector Primary Axis None
secondary_axis InputVector Secondary Axis None

Attributes

Name Description
i
inputs
name
node
o
outputs
primary
primary_axis
secondary
secondary_axis
tree
type

Inputs

Attribute Type Description
i.primary_axis VectorSocket Primary Axis
i.secondary_axis VectorSocket Secondary Axis

Outputs

Attribute Type Description
o.rotation RotationSocket Rotation

AxisAngleToRotation

AxisAngleToRotation(axis=None, angle=0.0)

Build a rotation from an axis and a rotation around that axis

Parameters

Name Type Description Default
axis InputVector Axis None
angle InputFloat Angle 0.0

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.axis VectorSocket Axis
i.angle FloatSocket Angle

Outputs

Attribute Type Description
o.rotation RotationSocket Rotation

BitMath

BitMath(a=0, b=0, shift=0, *, operation='AND')

Perform bitwise operations on 32-bit integers

Parameters

Name Type Description Default
a InputInteger A 0
b InputInteger B 0
shift InputInteger Shift 0

Attributes

Name Description
i
inputs
name
node
o
operation
outputs
tree
type

Methods

Name Description
exclusive_or Create Bit Math with operation ‘Exclusive Or’. Returns a value where only one bit from A and B is set
l_and Create Bit Math with operation ‘And’. Returns a value where the bits of A and B are both set
l_not Create Bit Math with operation ‘Not’. Returns the opposite bit value of A, in decimal it is equivalent of A = -A - 1
l_or Create Bit Math with operation ‘Or’. Returns a value where the bits of either A or B are set
rotate Create Bit Math with operation ‘Rotate’. Rotates the bit values of A by the specified Shift amount. Positive values rotate left, negative values rotate right.
shift Create Bit Math with operation ‘Shift’. Shifts the bit values of A by the specified Shift amount. Positive values shift left, negative values shift right.
exclusive_or
exclusive_or(a=0, b=0)

Create Bit Math with operation ‘Exclusive Or’. Returns a value where only one bit from A and B is set

l_and
l_and(a=0, b=0)

Create Bit Math with operation ‘And’. Returns a value where the bits of A and B are both set

l_not
l_not(a=0)

Create Bit Math with operation ‘Not’. Returns the opposite bit value of A, in decimal it is equivalent of A = -A - 1

l_or
l_or(a=0, b=0)

Create Bit Math with operation ‘Or’. Returns a value where the bits of either A or B are set

rotate
rotate(a=0, shift=0)

Create Bit Math with operation ‘Rotate’. Rotates the bit values of A by the specified Shift amount. Positive values rotate left, negative values rotate right.

shift
shift(a=0, shift=0)

Create Bit Math with operation ‘Shift’. Shifts the bit values of A by the specified Shift amount. Positive values shift left, negative values shift right.

Inputs

Attribute Type Description
i.a IntegerSocket A
i.b IntegerSocket B
i.shift IntegerSocket Shift

Outputs

Attribute Type Description
o.value IntegerSocket Value

Blackbody

Blackbody(temperature=6500.0)

Convert a blackbody temperature to an RGB value

Parameters

Name Type Description Default
temperature InputFloat Temperature 6500.0

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.temperature FloatSocket Temperature

Outputs

Attribute Type Description
o.color ColorSocket Color

BooleanMath

BooleanMath(boolean=False, boolean_001=False, *, operation='AND')

Perform a logical operation on the given boolean inputs

Parameters

Name Type Description Default
boolean InputBoolean Boolean False
boolean_001 InputBoolean Boolean False

Attributes

Name Description
i
inputs
name
node
o
operation
outputs
tree
type

Methods

Name Description
equal Create Boolean Math with operation ‘Equal’. True when both inputs are equal (exclusive nor)
imply Create Boolean Math with operation ‘Imply’. True unless the first input is true and the second is false
l_and Create Boolean Math with operation ‘And’. True when both inputs are true
l_not Create Boolean Math with operation ‘Not’. Opposite of the input
l_or Create Boolean Math with operation ‘Or’. True when at least one input is true
nor Create Boolean Math with operation ‘Nor’. True when both inputs are false
not_and Create Boolean Math with operation ‘Not And’. True when at least one input is false
not_equal Create Boolean Math with operation ‘Not Equal’. True when both inputs are different (exclusive or)
subtract Create Boolean Math with operation ‘Subtract’. True when the first input is true and the second is false (not imply)
equal
equal(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘Equal’. True when both inputs are equal (exclusive nor)

imply
imply(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘Imply’. True unless the first input is true and the second is false

l_and
l_and(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘And’. True when both inputs are true

l_not
l_not(boolean=False)

Create Boolean Math with operation ‘Not’. Opposite of the input

l_or
l_or(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘Or’. True when at least one input is true

nor
nor(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘Nor’. True when both inputs are false

not_and
not_and(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘Not And’. True when at least one input is false

not_equal
not_equal(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘Not Equal’. True when both inputs are different (exclusive or)

subtract
subtract(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘Subtract’. True when the first input is true and the second is false (not imply)

Inputs

Attribute Type Description
i.boolean BooleanSocket Boolean
i.boolean_001 BooleanSocket Boolean

Outputs

Attribute Type Description
o.boolean BooleanSocket Boolean

Clamp

Clamp(value=1.0, min=0.0, max=1.0, *, clamp_type='MINMAX')

Clamp a value between a minimum and a maximum

Parameters

Name Type Description Default
value InputFloat Value 1.0
min InputFloat Min 0.0
max InputFloat Max 1.0

Attributes

Name Description
clamp_type
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
min_max Create Clamp with operation ‘Min Max’. Constrain value between min and max
range Create Clamp with operation ‘Range’. Constrain value between min and max, swapping arguments when min > max
min_max
min_max(value=1.0, min=0.0, max=1.0)

Create Clamp with operation ‘Min Max’. Constrain value between min and max

range
range(value=1.0, min=0.0, max=1.0)

Create Clamp with operation ‘Range’. Constrain value between min and max, swapping arguments when min > max

Inputs

Attribute Type Description
i.value FloatSocket Value
i.min FloatSocket Min
i.max FloatSocket Max

Outputs

Attribute Type Description
o.result FloatSocket Result

ColorRamp

ColorRamp(fac=0.5)

Map values to colors with the use of a gradient

Parameters

Name Type Description Default
fac InputFloat Factor 0.5

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.fac FloatSocket Factor

Outputs

Attribute Type Description
o.color ColorSocket Color
o.alpha FloatSocket Alpha

CombineBundle

CombineBundle(define_signature=False)

Combine multiple socket values into one.

Attributes

Name Description
define_signature
i
inputs
name
node
o
outputs
tree
type

Outputs

Attribute Type Description
o.bundle BundleSocket Bundle

CombineColor

CombineColor(red=0.0, green=0.0, blue=0.0, alpha=1.0, *, mode='RGB')

Combine four channels into a single color, based on a particular color model

Parameters

Name Type Description Default
red InputFloat Red 0.0
green InputFloat Green 0.0
blue InputFloat Blue 0.0
alpha InputFloat Alpha 1.0

Attributes

Name Description
i
inputs
mode
name
node
o
outputs
tree
type

Methods

Name Description
hsl Create Combine Color with operation ‘HSL’. Use HSL (Hue, Saturation, Lightness) color processing
hsv Create Combine Color with operation ‘HSV’. Use HSV (Hue, Saturation, Value) color processing
rgb Create Combine Color with operation ‘RGB’. Use RGB (Red, Green, Blue) color processing
hsl
hsl(red=0.0, green=0.0, blue=0.0, alpha=1.0)

Create Combine Color with operation ‘HSL’. Use HSL (Hue, Saturation, Lightness) color processing

hsv
hsv(red=0.0, green=0.0, blue=0.0, alpha=1.0)

Create Combine Color with operation ‘HSV’. Use HSV (Hue, Saturation, Value) color processing

rgb
rgb(red=0.0, green=0.0, blue=0.0, alpha=1.0)

Create Combine Color with operation ‘RGB’. Use RGB (Red, Green, Blue) color processing

Inputs

Attribute Type Description
i.red FloatSocket Red
i.green FloatSocket Green
i.blue FloatSocket Blue
i.alpha FloatSocket Alpha

Outputs

Attribute Type Description
o.color ColorSocket Color

CombineMatrix

CombineMatrix(
    column_1_row_1=1.0,
    column_1_row_2=0.0,
    column_1_row_3=0.0,
    column_1_row_4=0.0,
    column_2_row_1=0.0,
    column_2_row_2=1.0,
    column_2_row_3=0.0,
    column_2_row_4=0.0,
    column_3_row_1=0.0,
    column_3_row_2=0.0,
    column_3_row_3=1.0,
    column_3_row_4=0.0,
    column_4_row_1=0.0,
    column_4_row_2=0.0,
    column_4_row_3=0.0,
    column_4_row_4=1.0,
)

Construct a 4x4 matrix from its individual values

Parameters

Name Type Description Default
column_1_row_1 InputFloat Column 1 Row 1 1.0
column_1_row_2 InputFloat Column 1 Row 2 0.0
column_1_row_3 InputFloat Column 1 Row 3 0.0
column_1_row_4 InputFloat Column 1 Row 4 0.0
column_2_row_1 InputFloat Column 2 Row 1 0.0
column_2_row_2 InputFloat Column 2 Row 2 1.0
column_2_row_3 InputFloat Column 2 Row 3 0.0
column_2_row_4 InputFloat Column 2 Row 4 0.0
column_3_row_1 InputFloat Column 3 Row 1 0.0
column_3_row_2 InputFloat Column 3 Row 2 0.0
column_3_row_3 InputFloat Column 3 Row 3 1.0
column_3_row_4 InputFloat Column 3 Row 4 0.0
column_4_row_1 InputFloat Column 4 Row 1 0.0
column_4_row_2 InputFloat Column 4 Row 2 0.0
column_4_row_3 InputFloat Column 4 Row 3 0.0
column_4_row_4 InputFloat Column 4 Row 4 1.0

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.column_1_row_1 FloatSocket Column 1 Row 1
i.column_1_row_2 FloatSocket Column 1 Row 2
i.column_1_row_3 FloatSocket Column 1 Row 3
i.column_1_row_4 FloatSocket Column 1 Row 4
i.column_2_row_1 FloatSocket Column 2 Row 1
i.column_2_row_2 FloatSocket Column 2 Row 2
i.column_2_row_3 FloatSocket Column 2 Row 3
i.column_2_row_4 FloatSocket Column 2 Row 4
i.column_3_row_1 FloatSocket Column 3 Row 1
i.column_3_row_2 FloatSocket Column 3 Row 2
i.column_3_row_3 FloatSocket Column 3 Row 3
i.column_3_row_4 FloatSocket Column 3 Row 4
i.column_4_row_1 FloatSocket Column 4 Row 1
i.column_4_row_2 FloatSocket Column 4 Row 2
i.column_4_row_3 FloatSocket Column 4 Row 3
i.column_4_row_4 FloatSocket Column 4 Row 4

Outputs

Attribute Type Description
o.matrix MatrixSocket Matrix

CombineTransform

CombineTransform(translation=None, rotation=None, scale=None)

Combine a translation vector, a rotation, and a scale vector into a transformation matrix

Parameters

Name Type Description Default
translation InputVector Translation None
rotation InputRotation Rotation None
scale InputVector Scale None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.translation VectorSocket Translation
i.rotation RotationSocket Rotation
i.scale VectorSocket Scale

Outputs

Attribute Type Description
o.transform MatrixSocket Transform

CombineXYZ

CombineXYZ(x=0.0, y=0.0, z=0.0)

Create a vector from X, Y, and Z components

Parameters

Name Type Description Default
x InputFloat X 0.0
y InputFloat Y 0.0
z InputFloat Z 0.0

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.x FloatSocket X
i.y FloatSocket Y
i.z FloatSocket Z

Outputs

Attribute Type Description
o.vector VectorSocket Vector

EulerToRotation

EulerToRotation(euler=None)

Build a rotation from separate angles around each axis

Parameters

Name Type Description Default
euler InputVector Euler None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.euler VectorSocket Euler

Outputs

Attribute Type Description
o.rotation RotationSocket Rotation

FindInString

FindInString(string='', search='')

Find the number of times a given string occurs in another string and the position of the first match

Parameters

Name Type Description Default
string InputString String ''
search InputString Search ''

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.string StringSocket String
i.search StringSocket Search

Outputs

Attribute Type Description
o.first_found IntegerSocket First Found
o.count IntegerSocket Count

FloatCurve

FloatCurve(factor=1.0, value=1.0)

Map an input float to a curve and outputs a float value

Parameters

Name Type Description Default
factor InputFloat Factor 1.0
value InputFloat Value 1.0

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.factor FloatSocket Factor
i.value FloatSocket Value

Outputs

Attribute Type Description
o.value FloatSocket Value

FloatToInteger

FloatToInteger(float=0.0, *, rounding_mode='ROUND')

Convert the given floating-point number to an integer, with a choice of methods

Parameters

Name Type Description Default
float InputFloat Float 0.0

Attributes

Name Description
i
inputs
name
node
o
outputs
rounding_mode
tree
type

Inputs

Attribute Type Description
i.float FloatSocket Float

Outputs

Attribute Type Description
o.integer IntegerSocket Integer

HashValue

HashValue(value=0, seed=0, *, data_type='INT')

Generate a randomized integer using the given input value as a seed

Parameters

Name Type Description Default
value InputInteger Value 0
seed InputInteger Seed 0

Attributes

Name Description
data_type
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
color Create Hash Value with operation ‘Color’.
float Create Hash Value with operation ‘Float’.
integer Create Hash Value with operation ‘Integer’.
matrix Create Hash Value with operation ‘Matrix’.
rotation Create Hash Value with operation ‘Rotation’.
string Create Hash Value with operation ‘String’.
vector Create Hash Value with operation ‘Vector’.
color
color(value=None, seed=0)

Create Hash Value with operation ‘Color’.

float
float(value=0.0, seed=0)

Create Hash Value with operation ‘Float’.

integer
integer(value=0, seed=0)

Create Hash Value with operation ‘Integer’.

matrix
matrix(value=None, seed=0)

Create Hash Value with operation ‘Matrix’.

rotation
rotation(value=None, seed=0)

Create Hash Value with operation ‘Rotation’.

string
string(value='', seed=0)

Create Hash Value with operation ‘String’.

vector
vector(value=None, seed=0)

Create Hash Value with operation ‘Vector’.

Inputs

Attribute Type Description
i.value IntegerSocket Value
i.seed IntegerSocket Seed

Outputs

Attribute Type Description
o.hash IntegerSocket Hash

IndexOfNearest

IndexOfNearest(position=None, group_id=0)

Find the nearest element in a group. Similar to the “Sample Nearest” node

Parameters

Name Type Description Default
position InputVector Position None
group_id InputInteger Group ID 0

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.position VectorSocket Position
i.group_id IntegerSocket Group ID

Outputs

Attribute Type Description
o.index IntegerSocket Index
o.has_neighbor BooleanSocket Has Neighbor

IntegerMath

IntegerMath(value=0, value_001=0, value_002=0, *, operation='ADD')

Perform various math operations on the given integer inputs

Parameters

Name Type Description Default
value InputInteger Value 0
value_001 InputInteger Value 0
value_002 InputInteger Value 0

Attributes

Name Description
i
inputs
name
node
o
operation
outputs
tree
type

Methods

Name Description
absolute Create Integer Math with operation ‘Absolute’. Non-negative value of A, abs(A)
add Create Integer Math with operation ‘Add’. A + B
divide Create Integer Math with operation ‘Divide’. A / B
divide_ceiling Create Integer Math with operation ‘Divide Ceiling’. Divide and ceil result, the smallest integer greater than or equal A
divide_floor Create Integer Math with operation ‘Divide Floor’. Divide and floor result, the largest integer smaller than or equal A
divide_round Create Integer Math with operation ‘Divide Round’. Divide and round result toward zero
floored_modulo Create Integer Math with operation ‘Floored Modulo’. Modulo that is periodic for both negative and positive operands
greatest_common_divisor Create Integer Math with operation ‘Greatest Common Divisor’. The largest positive integer that divides into each of the values A and B, e.g. GCD(8,12) = 4
least_common_multiple Create Integer Math with operation ‘Least Common Multiple’. The smallest positive integer that is divisible by both A and B, e.g. LCM(6,10) = 30
maximum Create Integer Math with operation ‘Maximum’. The maximum value from A and B, max(A,B)
minimum Create Integer Math with operation ‘Minimum’. The minimum value from A and B, min(A,B)
modulo Create Integer Math with operation ‘Modulo’. Modulo which is the remainder of A / B
multiply Create Integer Math with operation ‘Multiply’. A * B
multiply_add Create Integer Math with operation ‘Multiply Add’. A * B + C
negate Create Integer Math with operation ‘Negate’. -A
power Create Integer Math with operation ‘Power’. A power B, pow(A,B)
sign Create Integer Math with operation ‘Sign’. Return the sign of A, sign(A)
subtract Create Integer Math with operation ‘Subtract’. A - B
absolute
absolute(value=0)

Create Integer Math with operation ‘Absolute’. Non-negative value of A, abs(A)

add
add(value=0, value_001=0)

Create Integer Math with operation ‘Add’. A + B

divide
divide(value=0, value_001=0)

Create Integer Math with operation ‘Divide’. A / B

divide_ceiling
divide_ceiling(value=0, value_001=0)

Create Integer Math with operation ‘Divide Ceiling’. Divide and ceil result, the smallest integer greater than or equal A

divide_floor
divide_floor(value=0, value_001=0)

Create Integer Math with operation ‘Divide Floor’. Divide and floor result, the largest integer smaller than or equal A

divide_round
divide_round(value=0, value_001=0)

Create Integer Math with operation ‘Divide Round’. Divide and round result toward zero

floored_modulo
floored_modulo(value=0, value_001=0)

Create Integer Math with operation ‘Floored Modulo’. Modulo that is periodic for both negative and positive operands

greatest_common_divisor
greatest_common_divisor(value=0, value_001=0)

Create Integer Math with operation ‘Greatest Common Divisor’. The largest positive integer that divides into each of the values A and B, e.g. GCD(8,12) = 4

least_common_multiple
least_common_multiple(value=0, value_001=0)

Create Integer Math with operation ‘Least Common Multiple’. The smallest positive integer that is divisible by both A and B, e.g. LCM(6,10) = 30

maximum
maximum(value=0, value_001=0)

Create Integer Math with operation ‘Maximum’. The maximum value from A and B, max(A,B)

minimum
minimum(value=0, value_001=0)

Create Integer Math with operation ‘Minimum’. The minimum value from A and B, min(A,B)

modulo
modulo(value=0, value_001=0)

Create Integer Math with operation ‘Modulo’. Modulo which is the remainder of A / B

multiply
multiply(value=0, value_001=0)

Create Integer Math with operation ‘Multiply’. A * B

multiply_add
multiply_add(value=0, value_001=0, value_002=0)

Create Integer Math with operation ‘Multiply Add’. A * B + C

negate
negate(value=0)

Create Integer Math with operation ‘Negate’. -A

power
power(value=0, value_001=0)

Create Integer Math with operation ‘Power’. A power B, pow(A,B)

sign
sign(value=0)

Create Integer Math with operation ‘Sign’. Return the sign of A, sign(A)

subtract
subtract(value=0, value_001=0)

Create Integer Math with operation ‘Subtract’. A - B

Inputs

Attribute Type Description
i.value IntegerSocket Value
i.value_001 IntegerSocket Value
i.value_002 IntegerSocket Value

Outputs

Attribute Type Description
o.value IntegerSocket Value

InvertMatrix

InvertMatrix(matrix=None)

Compute the inverse of the given matrix, if one exists

Parameters

Name Type Description Default
matrix InputMatrix Matrix None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.matrix MatrixSocket Matrix

Outputs

Attribute Type Description
o.matrix MatrixSocket Matrix
o.invertible BooleanSocket Invertible

InvertRotation

InvertRotation(rotation=None)

Compute the inverse of the given rotation

Parameters

Name Type Description Default
rotation InputRotation Rotation None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.rotation RotationSocket Rotation

Outputs

Attribute Type Description
o.rotation RotationSocket Rotation

JoinBundle

JoinBundle(bundle=None)

Join multiple bundles together

Parameters

Name Type Description Default
bundle InputBundle Bundle None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.bundle BundleSocket Bundle

Outputs

Attribute Type Description
o.bundle BundleSocket Bundle

MapRange

MapRange(
    value=1.0,
    from_min=0.0,
    from_max=1.0,
    to_min=0.0,
    to_max=1.0,
    steps=4.0,
    vector=None,
    from_min_float3=None,
    from_max_float3=None,
    to_min_float3=None,
    to_max_float3=None,
    steps_float3=None,
    *,
    clamp=False,
    interpolation_type='LINEAR',
    data_type='FLOAT',
)

Remap a value from a range to a target range

Parameters

Name Type Description Default
value InputFloat Value 1.0
from_min InputFloat From Min 0.0
from_max InputFloat From Max 1.0
to_min InputFloat To Min 0.0
to_max InputFloat To Max 1.0
steps InputFloat Steps 4.0
vector InputVector Vector None
from_min_float3 InputVector From Min None
from_max_float3 InputVector From Max None
to_min_float3 InputVector To Min None
to_max_float3 InputVector To Max None
steps_float3 InputVector Steps None

Attributes

Name Description
clamp
data_type
i
inputs
interpolation_type
name
node
o
outputs
tree
type

Methods

Name Description
float Create Map Range with operation ‘Float’. Floating-point value
linear Create Map Range with operation ‘Linear’. Linear interpolation between From Min and From Max values
smooth_step Create Map Range with operation ‘Smooth Step’. Smooth Hermite edge interpolation between From Min and From Max values
smoother_step Create Map Range with operation ‘Smoother Step’. Smoother Hermite edge interpolation between From Min and From Max values
stepped_linear Create Map Range with operation ‘Stepped Linear’. Stepped linear interpolation between From Min and From Max values
vector Create Map Range with operation ‘Vector’. 3D vector with floating-point values
float
float(value=1.0, from_min=0.0, from_max=1.0, to_min=0.0, to_max=1.0)

Create Map Range with operation ‘Float’. Floating-point value

linear
linear(value=1.0, from_min=0.0, from_max=1.0, to_min=0.0, to_max=1.0)

Create Map Range with operation ‘Linear’. Linear interpolation between From Min and From Max values

smooth_step
smooth_step(value=1.0, from_min=0.0, from_max=1.0, to_min=0.0, to_max=1.0)

Create Map Range with operation ‘Smooth Step’. Smooth Hermite edge interpolation between From Min and From Max values

smoother_step
smoother_step(value=1.0, from_min=0.0, from_max=1.0, to_min=0.0, to_max=1.0)

Create Map Range with operation ‘Smoother Step’. Smoother Hermite edge interpolation between From Min and From Max values

stepped_linear
stepped_linear(
    value=1.0,
    from_min=0.0,
    from_max=1.0,
    to_min=0.0,
    to_max=1.0,
    steps=4.0,
)

Create Map Range with operation ‘Stepped Linear’. Stepped linear interpolation between From Min and From Max values

vector
vector(vector=None, from_min3=None, from_max3=None, to_min3=None, to_max3=None)

Create Map Range with operation ‘Vector’. 3D vector with floating-point values

Inputs

Attribute Type Description
i.value FloatSocket Value
i.from_min FloatSocket From Min
i.from_max FloatSocket From Max
i.to_min FloatSocket To Min
i.to_max FloatSocket To Max
i.steps FloatSocket Steps
i.vector VectorSocket Vector
i.from_min_float3 VectorSocket From Min
i.from_max_float3 VectorSocket From Max
i.to_min_float3 VectorSocket To Min
i.to_max_float3 VectorSocket To Max
i.steps_float3 VectorSocket Steps

Outputs

Attribute Type Description
o.result FloatSocket Result
o.vector VectorSocket Vector

MatchString

MatchString(string='', operation='Starts With', key='')

Check if a given string exists within another string

Parameters

Name Type Description Default
string InputString String ''
operation InputMenu | Literal['Starts With', 'Ends With', 'Contains'] Operation 'Starts With'
key InputString Key ''

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.string StringSocket String
i.operation MenuSocket Operation
i.key StringSocket Key

Outputs

Attribute Type Description
o.result BooleanSocket Result

Math

Math(
    value=0.5,
    value_001=0.5,
    value_002=0.5,
    *,
    operation='ADD',
    use_clamp=False,
)

Perform math operations

Parameters

Name Type Description Default
value InputFloat Value 0.5
value_001 InputFloat Value 0.5
value_002 InputFloat Value 0.5

Attributes

Name Description
i
inputs
name
node
o
operation
outputs
tree
type
use_clamp

Methods

Name Description
absolute Create Math with operation ‘Absolute’. Magnitude of A
add Create Math with operation ‘Add’. A + B
arccosine Create Math with operation ‘Arccosine’. arccos(A)
arcsine Create Math with operation ‘Arcsine’. arcsin(A)
arctan2 Create Math with operation ‘Arctan2’. The signed angle arctan(A / B)
arctangent Create Math with operation ‘Arctangent’. arctan(A)
ceil Create Math with operation ‘Ceil’. The smallest integer greater than or equal A
compare Create Math with operation ‘Compare’. 1 if (A == B) within tolerance C else 0
cosine Create Math with operation ‘Cosine’. cos(A)
divide Create Math with operation ‘Divide’. A / B
exponent Create Math with operation ‘Exponent’. exp(A)
floor Create Math with operation ‘Floor’. The largest integer smaller than or equal A
floored_modulo Create Math with operation ‘Floored Modulo’. The remainder of floored division
fraction Create Math with operation ‘Fraction’. The fraction part of A
greater_than Create Math with operation ‘Greater Than’. 1 if A > B else 0
hyperbolic_cosine Create Math with operation ‘Hyperbolic Cosine’. cosh(A)
hyperbolic_sine Create Math with operation ‘Hyperbolic Sine’. sinh(A)
hyperbolic_tangent Create Math with operation ‘Hyperbolic Tangent’. tanh(A)
inverse_square_root Create Math with operation ‘Inverse Square Root’. 1 / Square root of A
less_than Create Math with operation ‘Less Than’. 1 if A < B else 0
logarithm Create Math with operation ‘Logarithm’. Logarithm A base B
maximum Create Math with operation ‘Maximum’. The maximum from A and B
minimum Create Math with operation ‘Minimum’. The minimum from A and B
multiply Create Math with operation ‘Multiply’. A * B
multiply_add Create Math with operation ‘Multiply Add’. A * B + C
ping_pong Create Math with operation ‘Ping-Pong’. Wraps a value and reverses every other cycle (A,B)
power Create Math with operation ‘Power’. A power B
round Create Math with operation ‘Round’. Round A to the nearest integer. Round upward if the fraction part is 0.5
sign Create Math with operation ‘Sign’. Returns the sign of A
sine Create Math with operation ‘Sine’. sin(A)
smooth_maximum Create Math with operation ‘Smooth Maximum’. The maximum from A and B with smoothing C
smooth_minimum Create Math with operation ‘Smooth Minimum’. The minimum from A and B with smoothing C
snap Create Math with operation ‘Snap’. Snap to increment, snap(A,B)
square_root Create Math with operation ‘Square Root’. Square root of A
subtract Create Math with operation ‘Subtract’. A - B
tangent Create Math with operation ‘Tangent’. tan(A)
to_degrees Create Math with operation ‘To Degrees’. Convert from radians to degrees
to_radians Create Math with operation ‘To Radians’. Convert from degrees to radians
truncate Create Math with operation ‘Truncate’. The integer part of A, removing fractional digits
truncated_modulo Create Math with operation ‘Truncated Modulo’. The remainder of truncated division using fmod(A,B)
wrap Create Math with operation ‘Wrap’. Wrap value to range, wrap(A,B)
absolute
absolute(value=0.5)

Create Math with operation ‘Absolute’. Magnitude of A

add
add(value=0.5, value_001=0.5)

Create Math with operation ‘Add’. A + B

arccosine
arccosine(value=0.5)

Create Math with operation ‘Arccosine’. arccos(A)

arcsine
arcsine(value=0.5)

Create Math with operation ‘Arcsine’. arcsin(A)

arctan2
arctan2(value=0.5, value_001=0.5)

Create Math with operation ‘Arctan2’. The signed angle arctan(A / B)

arctangent
arctangent(value=0.5)

Create Math with operation ‘Arctangent’. arctan(A)

ceil
ceil(value=0.5)

Create Math with operation ‘Ceil’. The smallest integer greater than or equal A

compare
compare(value=0.5, value_001=0.5, value_002=0.5)

Create Math with operation ‘Compare’. 1 if (A == B) within tolerance C else 0

cosine
cosine(value=0.5)

Create Math with operation ‘Cosine’. cos(A)

divide
divide(value=0.5, value_001=0.5)

Create Math with operation ‘Divide’. A / B

exponent
exponent(value=0.5)

Create Math with operation ‘Exponent’. exp(A)

floor
floor(value=0.5)

Create Math with operation ‘Floor’. The largest integer smaller than or equal A

floored_modulo
floored_modulo(value=0.5, value_001=0.5)

Create Math with operation ‘Floored Modulo’. The remainder of floored division

fraction
fraction(value=0.5)

Create Math with operation ‘Fraction’. The fraction part of A

greater_than
greater_than(value=0.5, value_001=0.5)

Create Math with operation ‘Greater Than’. 1 if A > B else 0

hyperbolic_cosine
hyperbolic_cosine(value=0.5)

Create Math with operation ‘Hyperbolic Cosine’. cosh(A)

hyperbolic_sine
hyperbolic_sine(value=0.5)

Create Math with operation ‘Hyperbolic Sine’. sinh(A)

hyperbolic_tangent
hyperbolic_tangent(value=0.5)

Create Math with operation ‘Hyperbolic Tangent’. tanh(A)

inverse_square_root
inverse_square_root(value=0.5)

Create Math with operation ‘Inverse Square Root’. 1 / Square root of A

less_than
less_than(value=0.5, value_001=0.5)

Create Math with operation ‘Less Than’. 1 if A < B else 0

logarithm
logarithm(value=0.5, value_001=0.5)

Create Math with operation ‘Logarithm’. Logarithm A base B

maximum
maximum(value=0.5, value_001=0.5)

Create Math with operation ‘Maximum’. The maximum from A and B

minimum
minimum(value=0.5, value_001=0.5)

Create Math with operation ‘Minimum’. The minimum from A and B

multiply
multiply(value=0.5, value_001=0.5)

Create Math with operation ‘Multiply’. A * B

multiply_add
multiply_add(value=0.5, value_001=0.5, value_002=0.5)

Create Math with operation ‘Multiply Add’. A * B + C

ping_pong
ping_pong(value=0.5, value_001=0.5)

Create Math with operation ‘Ping-Pong’. Wraps a value and reverses every other cycle (A,B)

power
power(value=0.5, value_001=0.5)

Create Math with operation ‘Power’. A power B

round
round(value=0.5)

Create Math with operation ‘Round’. Round A to the nearest integer. Round upward if the fraction part is 0.5

sign
sign(value=0.5)

Create Math with operation ‘Sign’. Returns the sign of A

sine
sine(value=0.5)

Create Math with operation ‘Sine’. sin(A)

smooth_maximum
smooth_maximum(value=0.5, value_001=0.5, value_002=0.5)

Create Math with operation ‘Smooth Maximum’. The maximum from A and B with smoothing C

smooth_minimum
smooth_minimum(value=0.5, value_001=0.5, value_002=0.5)

Create Math with operation ‘Smooth Minimum’. The minimum from A and B with smoothing C

snap
snap(value=0.5, value_001=0.5)

Create Math with operation ‘Snap’. Snap to increment, snap(A,B)

square_root
square_root(value=0.5)

Create Math with operation ‘Square Root’. Square root of A

subtract
subtract(value=0.5, value_001=0.5)

Create Math with operation ‘Subtract’. A - B

tangent
tangent(value=0.5)

Create Math with operation ‘Tangent’. tan(A)

to_degrees
to_degrees(value=0.5)

Create Math with operation ‘To Degrees’. Convert from radians to degrees

to_radians
to_radians(value=0.5)

Create Math with operation ‘To Radians’. Convert from degrees to radians

truncate
truncate(value=0.5)

Create Math with operation ‘Truncate’. The integer part of A, removing fractional digits

truncated_modulo
truncated_modulo(value=0.5, value_001=0.5)

Create Math with operation ‘Truncated Modulo’. The remainder of truncated division using fmod(A,B)

wrap
wrap(value=0.5, value_001=0.5, value_002=0.5)

Create Math with operation ‘Wrap’. Wrap value to range, wrap(A,B)

Inputs

Attribute Type Description
i.value FloatSocket Value
i.value_001 FloatSocket Value
i.value_002 FloatSocket Value

Outputs

Attribute Type Description
o.value FloatSocket Value

MatrixDeterminant

MatrixDeterminant(matrix=None)

Compute the determinant of the given matrix

Parameters

Name Type Description Default
matrix InputMatrix Matrix None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.matrix MatrixSocket Matrix

Outputs

Attribute Type Description
o.determinant FloatSocket Determinant

Mix

Mix(
    factor_float=0.5,
    factor_vector=None,
    a_float=0.0,
    b_float=0.0,
    a_vector=None,
    b_vector=None,
    a_color=None,
    b_color=None,
    a_rotation=None,
    b_rotation=None,
    *,
    data_type='FLOAT',
    factor_mode='UNIFORM',
    blend_type='MIX',
    clamp_factor=False,
    clamp_result=False,
)

Mix values by a factor

Parameters

Name Type Description Default
factor_float InputFloat Factor 0.5
factor_vector InputVector Factor None
a_float InputFloat A 0.0
b_float InputFloat B 0.0
a_vector InputVector A None
b_vector InputVector B None
a_color InputColor A None
b_color InputColor B None
a_rotation InputRotation A None
b_rotation InputRotation B None

Attributes

Name Description
blend_type
clamp_factor
clamp_result
data_type
factor_mode
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
color Create Mix with operation ‘Color’.
float Create Mix with operation ‘Float’.
rotation Create Mix with operation ‘Rotation’.
vector Create Mix with operation ‘Vector’.
color
color(factor=0.5, a_color=None, b_color=None)

Create Mix with operation ‘Color’.

float
float(factor=0.5, a=0.0, b=0.0)

Create Mix with operation ‘Float’.

rotation
rotation(factor=0.5, a_rotation=None, b_rotation=None)

Create Mix with operation ‘Rotation’.

vector
vector(factor=0.5, a=None, b=None)

Create Mix with operation ‘Vector’.

Inputs

Attribute Type Description
i.factor_float FloatSocket Factor
i.factor_vector VectorSocket Factor
i.a_float FloatSocket A
i.b_float FloatSocket B
i.a_vector VectorSocket A
i.b_vector VectorSocket B
i.a_color ColorSocket A
i.b_color ColorSocket B
i.a_rotation RotationSocket A
i.b_rotation RotationSocket B

Outputs

Attribute Type Description
o.result_float FloatSocket Result
o.result_vector VectorSocket Result
o.result_color ColorSocket Result
o.result_rotation RotationSocket Result

MultiplyMatrices

MultiplyMatrices(matrix=None, matrix_001=None)

Perform a matrix multiplication on two input matrices

Parameters

Name Type Description Default
matrix InputMatrix Matrix None
matrix_001 InputMatrix Matrix None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.matrix MatrixSocket Matrix
i.matrix_001 MatrixSocket Matrix

Outputs

Attribute Type Description
o.matrix MatrixSocket Matrix

PackUVIslands

PackUVIslands(
    uv=None,
    selection=True,
    margin=0.001,
    rotate=True,
    method='Bounding Box',
)

Scale islands of a UV map and move them so they fill the UV space as much as possible

Parameters

Name Type Description Default
uv InputVector UV None
selection InputBoolean Selection True
margin InputFloat Margin 0.001
rotate InputBoolean Rotate True
method InputMenu | Literal['Bounding Box', 'Convex Hull', 'Exact Shape'] Method 'Bounding Box'

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.uv VectorSocket UV
i.selection BooleanSocket Selection
i.margin FloatSocket Margin
i.rotate BooleanSocket Rotate
i.method MenuSocket Method

Outputs

Attribute Type Description
o.uv VectorSocket UV

ProjectPoint

ProjectPoint(vector=None, transform=None)

Project a point using a matrix, using location, rotation, scale, and perspective divide

Parameters

Name Type Description Default
vector InputVector Vector None
transform InputMatrix Transform None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.vector VectorSocket Vector
i.transform MatrixSocket Transform

Outputs

Attribute Type Description
o.vector VectorSocket Vector

QuaternionToRotation

QuaternionToRotation(w=1.0, x=0.0, y=0.0, z=0.0)

Build a rotation from quaternion components

Parameters

Name Type Description Default
w InputFloat W 1.0
x InputFloat X 0.0
y InputFloat Y 0.0
z InputFloat Z 0.0

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.w FloatSocket W
i.x FloatSocket X
i.y FloatSocket Y
i.z FloatSocket Z

Outputs

Attribute Type Description
o.rotation RotationSocket Rotation

RandomValue

RandomValue(
    min=None,
    max=None,
    min_001=0.0,
    max_001=1.0,
    min_002=0,
    max_002=100,
    probability=0.5,
    id=0,
    seed=0,
    *,
    data_type='FLOAT',
)

Output a randomized value

Parameters

Name Type Description Default
min InputVector Min None
max InputVector Max None
min_001 InputFloat Min 0.0
max_001 InputFloat Max 1.0
min_002 InputInteger Min 0
max_002 InputInteger Max 100
probability InputFloat Probability 0.5
id InputInteger ID 0
seed InputInteger Seed 0

Attributes

Name Description
data_type
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
boolean Create Random Value with operation ‘Boolean’. True or false
float Create Random Value with operation ‘Float’. Floating-point value
integer Create Random Value with operation ‘Integer’. 32-bit integer
vector Create Random Value with operation ‘Vector’. 3D vector with floating-point values
boolean
boolean(probability=0.5, id=0, seed=0)

Create Random Value with operation ‘Boolean’. True or false

float
float(min=0.0, max=1.0, id=0, seed=0)

Create Random Value with operation ‘Float’. Floating-point value

integer
integer(min=0, max=100, id=0, seed=0)

Create Random Value with operation ‘Integer’. 32-bit integer

vector
vector(min=None, max=None, id=0, seed=0)

Create Random Value with operation ‘Vector’. 3D vector with floating-point values

Inputs

Attribute Type Description
i.min VectorSocket Min
i.max VectorSocket Max
i.min_001 FloatSocket Min
i.max_001 FloatSocket Max
i.min_002 IntegerSocket Min
i.max_002 IntegerSocket Max
i.probability FloatSocket Probability
i.id IntegerSocket ID
i.seed IntegerSocket Seed

Outputs

Attribute Type Description
o.value VectorSocket Value
o.value_001 FloatSocket Value
o.value_002 IntegerSocket Value
o.value_003 BooleanSocket Value

ReplaceString

ReplaceString(string='', find='', replace='')

Replace a given string segment with another

Parameters

Name Type Description Default
string InputString String ''
find InputString Find ''
replace InputString Replace ''

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.string StringSocket String
i.find StringSocket Find
i.replace StringSocket Replace

Outputs

Attribute Type Description
o.string StringSocket String

RotateEuler

RotateEuler(
    rotation=None,
    rotate_by=None,
    axis=None,
    angle=0.0,
    *,
    rotation_type='EULER',
    space='OBJECT',
)

Apply a secondary Euler rotation to a given Euler rotation

Parameters

Name Type Description Default
rotation InputVector Rotation None
rotate_by InputVector Rotate By None
axis InputVector Axis None
angle InputFloat Angle 0.0

Attributes

Name Description
i
inputs
name
node
o
outputs
rotation_type
space
tree
type

Methods

Name Description
axis_angle Create Rotate Euler with operation ‘Axis Angle’. Rotate around an axis by an angle
euler Create Rotate Euler with operation ‘Euler’. Rotate around the X, Y, and Z axes
axis_angle
axis_angle(rotation=None, axis=None, angle=0.0)

Create Rotate Euler with operation ‘Axis Angle’. Rotate around an axis by an angle

euler
euler(rotation=None, rotate_by=None)

Create Rotate Euler with operation ‘Euler’. Rotate around the X, Y, and Z axes

Inputs

Attribute Type Description
i.rotation VectorSocket Rotation
i.rotate_by VectorSocket Rotate By
i.axis VectorSocket Axis
i.angle FloatSocket Angle

Outputs

Attribute Type Description
o.rotation VectorSocket Rotation

RotateRotation

RotateRotation(rotation=None, rotate_by=None, *, rotation_space='GLOBAL')

Apply a secondary rotation to a given rotation value

Parameters

Name Type Description Default
rotation InputRotation Rotation None
rotate_by InputRotation Rotate By None

Attributes

Name Description
i
inputs
name
node
o
outputs
rotation_space
tree
type

Inputs

Attribute Type Description
i.rotation RotationSocket Rotation
i.rotate_by RotationSocket Rotate By

Outputs

Attribute Type Description
o.rotation RotationSocket Rotation

RotateVector

RotateVector(vector=None, rotation=None)

Apply a rotation to a given vector

Parameters

Name Type Description Default
vector InputVector Vector None
rotation InputRotation Rotation None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.vector VectorSocket Vector
i.rotation RotationSocket Rotation

Outputs

Attribute Type Description
o.vector VectorSocket Vector

RotationToAxisAngle

RotationToAxisAngle(rotation=None)

Convert a rotation to axis angle components

Parameters

Name Type Description Default
rotation InputRotation Rotation None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.rotation RotationSocket Rotation

Outputs

Attribute Type Description
o.axis VectorSocket Axis
o.angle FloatSocket Angle

RotationToEuler

RotationToEuler(rotation=None)

Convert a standard rotation value to an Euler rotation

Parameters

Name Type Description Default
rotation InputRotation Rotation None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.rotation RotationSocket Rotation

Outputs

Attribute Type Description
o.euler VectorSocket Euler

RotationToQuaternion

RotationToQuaternion(rotation=None)

Retrieve the quaternion components representing a rotation

Parameters

Name Type Description Default
rotation InputRotation Rotation None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.rotation RotationSocket Rotation

Outputs

Attribute Type Description
o.w FloatSocket W
o.x FloatSocket X
o.y FloatSocket Y
o.z FloatSocket Z

SeparateBundle

SeparateBundle(bundle=None, *, define_signature=False)

Split a bundle into multiple sockets.

Parameters

Name Type Description Default
bundle InputBundle Bundle None

Attributes

Name Description
define_signature
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.bundle BundleSocket Bundle

SeparateColor

SeparateColor(color=None, *, mode='RGB')

Split a color into separate channels, based on a particular color model

Parameters

Name Type Description Default
color InputColor Color None

Attributes

Name Description
i
inputs
mode
name
node
o
outputs
tree
type

Methods

Name Description
hsl Create Separate Color with operation ‘HSL’. Use HSL (Hue, Saturation, Lightness) color processing
hsv Create Separate Color with operation ‘HSV’. Use HSV (Hue, Saturation, Value) color processing
rgb Create Separate Color with operation ‘RGB’. Use RGB (Red, Green, Blue) color processing
hsl
hsl(color=None)

Create Separate Color with operation ‘HSL’. Use HSL (Hue, Saturation, Lightness) color processing

hsv
hsv(color=None)

Create Separate Color with operation ‘HSV’. Use HSV (Hue, Saturation, Value) color processing

rgb
rgb(color=None)

Create Separate Color with operation ‘RGB’. Use RGB (Red, Green, Blue) color processing

Inputs

Attribute Type Description
i.color ColorSocket Color

Outputs

Attribute Type Description
o.red FloatSocket Red
o.green FloatSocket Green
o.blue FloatSocket Blue
o.alpha FloatSocket Alpha

SeparateMatrix

SeparateMatrix(matrix=None)

Split a 4x4 matrix into its individual values

Parameters

Name Type Description Default
matrix InputMatrix Matrix None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.matrix MatrixSocket Matrix

Outputs

Attribute Type Description
o.column_1_row_1 FloatSocket Column 1 Row 1
o.column_1_row_2 FloatSocket Column 1 Row 2
o.column_1_row_3 FloatSocket Column 1 Row 3
o.column_1_row_4 FloatSocket Column 1 Row 4
o.column_2_row_1 FloatSocket Column 2 Row 1
o.column_2_row_2 FloatSocket Column 2 Row 2
o.column_2_row_3 FloatSocket Column 2 Row 3
o.column_2_row_4 FloatSocket Column 2 Row 4
o.column_3_row_1 FloatSocket Column 3 Row 1
o.column_3_row_2 FloatSocket Column 3 Row 2
o.column_3_row_3 FloatSocket Column 3 Row 3
o.column_3_row_4 FloatSocket Column 3 Row 4
o.column_4_row_1 FloatSocket Column 4 Row 1
o.column_4_row_2 FloatSocket Column 4 Row 2
o.column_4_row_3 FloatSocket Column 4 Row 3
o.column_4_row_4 FloatSocket Column 4 Row 4

SeparateTransform

SeparateTransform(transform=None)

Split a transformation matrix into a translation vector, a rotation, and a scale vector

Parameters

Name Type Description Default
transform InputMatrix Transform None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.transform MatrixSocket Transform

Outputs

Attribute Type Description
o.translation VectorSocket Translation
o.rotation RotationSocket Rotation
o.scale VectorSocket Scale

SeparateXYZ

SeparateXYZ(vector=None)

Split a vector into its X, Y, and Z components

Parameters

Name Type Description Default
vector InputVector Vector None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.vector VectorSocket Vector

Outputs

Attribute Type Description
o.x FloatSocket X
o.y FloatSocket Y
o.z FloatSocket Z

SliceString

SliceString(string='', position=0, length=10)

Extract a string segment from a larger string

Parameters

Name Type Description Default
string InputString String ''
position InputInteger Position 0
length InputInteger Length 10

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.string StringSocket String
i.position IntegerSocket Position
i.length IntegerSocket Length

Outputs

Attribute Type Description
o.string StringSocket String

StringLength

StringLength(string='')

Output the number of characters in the given string

Parameters

Name Type Description Default
string InputString String ''

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.string StringSocket String

Outputs

Attribute Type Description
o.length IntegerSocket Length

StringToValue

StringToValue(string='', *, data_type='FLOAT')

Derive a numeric value from a given string representation

Parameters

Name Type Description Default
string InputString String ''

Attributes

Name Description
data_type
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
float Create String to Value with operation ‘Float’. Floating-point value
integer Create String to Value with operation ‘Integer’. 32-bit integer
float
float(string='')

Create String to Value with operation ‘Float’. Floating-point value

integer
integer(string='')

Create String to Value with operation ‘Integer’. 32-bit integer

Inputs

Attribute Type Description
i.string StringSocket String

Outputs

Attribute Type Description
o.value FloatSocket Value
o.length IntegerSocket Length

Switch

Switch(switch=False, false=None, true=None, *, input_type='GEOMETRY')

Switch between two inputs

Parameters

Name Type Description Default
switch InputBoolean Switch False
false InputGeometry False None
true InputGeometry True None

Attributes

Name Description
i
input_type
inputs
name
node
o
outputs
tree
type

Methods

Name Description
boolean Create Switch with operation ‘Boolean’.
bundle Create Switch with operation ‘Bundle’.
closure Create Switch with operation ‘Closure’.
collection Create Switch with operation ‘Collection’.
color Create Switch with operation ‘Color’.
float Create Switch with operation ‘Float’.
geometry Create Switch with operation ‘Geometry’.
image Create Switch with operation ‘Image’.
integer Create Switch with operation ‘Integer’.
material Create Switch with operation ‘Material’.
matrix Create Switch with operation ‘Matrix’.
menu Create Switch with operation ‘Menu’.
object Create Switch with operation ‘Object’.
rotation Create Switch with operation ‘Rotation’.
string Create Switch with operation ‘String’.
vector Create Switch with operation ‘Vector’.
boolean
boolean(switch=False, false=False, true=False)

Create Switch with operation ‘Boolean’.

bundle
bundle(switch=False, false=None, true=None)

Create Switch with operation ‘Bundle’.

closure
closure(switch=False, false=None, true=None)

Create Switch with operation ‘Closure’.

collection
collection(switch=False, false=None, true=None)

Create Switch with operation ‘Collection’.

color
color(switch=False, false=None, true=None)

Create Switch with operation ‘Color’.

float
float(switch=False, false=0.0, true=0.0)

Create Switch with operation ‘Float’.

geometry
geometry(switch=False, false=None, true=None)

Create Switch with operation ‘Geometry’.

image
image(switch=False, false=None, true=None)

Create Switch with operation ‘Image’.

integer
integer(switch=False, false=0, true=0)

Create Switch with operation ‘Integer’.

material
material(switch=False, false=None, true=None)

Create Switch with operation ‘Material’.

matrix
matrix(switch=False, false=None, true=None)

Create Switch with operation ‘Matrix’.

menu
menu(switch=False, false=None, true=None)

Create Switch with operation ‘Menu’.

object
object(switch=False, false=None, true=None)

Create Switch with operation ‘Object’.

rotation
rotation(switch=False, false=None, true=None)

Create Switch with operation ‘Rotation’.

string
string(switch=False, false='', true='')

Create Switch with operation ‘String’.

vector
vector(switch=False, false=None, true=None)

Create Switch with operation ‘Vector’.

Inputs

Attribute Type Description
i.switch BooleanSocket Switch
i.false GeometrySocket False
i.true GeometrySocket True

Outputs

Attribute Type Description
o.output GeometrySocket Output

TransformDirection

TransformDirection(direction=None, transform=None)

Apply a transformation matrix (excluding translation) to the given vector

Parameters

Name Type Description Default
direction InputVector Direction None
transform InputMatrix Transform None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.direction VectorSocket Direction
i.transform MatrixSocket Transform

Outputs

Attribute Type Description
o.direction VectorSocket Direction

TransformPoint

TransformPoint(vector=None, transform=None)

Apply a transformation matrix to the given vector

Parameters

Name Type Description Default
vector InputVector Vector None
transform InputMatrix Transform None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.vector VectorSocket Vector
i.transform MatrixSocket Transform

Outputs

Attribute Type Description
o.vector VectorSocket Vector

TransposeMatrix

TransposeMatrix(matrix=None)

Flip a matrix over its diagonal, turning columns into rows and vice-versa

Parameters

Name Type Description Default
matrix InputMatrix Matrix None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.matrix MatrixSocket Matrix

Outputs

Attribute Type Description
o.matrix MatrixSocket Matrix

UVUnwrap

UVUnwrap(
    selection=True,
    seam=False,
    margin=0.001,
    fill_holes=True,
    method='Angle Based',
)

Generate a UV map based on seam edges

Parameters

Name Type Description Default
selection InputBoolean Selection True
seam InputBoolean Seam False
margin InputFloat Margin 0.001
fill_holes InputBoolean Fill Holes True
method InputMenu | Literal['Angle Based', 'Conformal'] Method 'Angle Based'

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.selection BooleanSocket Selection
i.seam BooleanSocket Seam
i.margin FloatSocket Margin
i.fill_holes BooleanSocket Fill Holes
i.method MenuSocket Method

Outputs

Attribute Type Description
o.uv VectorSocket UV

ValueToString

ValueToString(value=0.0, decimals=0, *, data_type='FLOAT')

Generate a string representation of the given input value

Parameters

Name Type Description Default
value InputFloat Value 0.0
decimals InputInteger Decimals 0

Attributes

Name Description
data_type
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
float Create Value to String with operation ‘Float’. Floating-point value
integer Create Value to String with operation ‘Integer’. 32-bit integer
float
float(value=0.0, decimals=0)

Create Value to String with operation ‘Float’. Floating-point value

integer
integer(value=0)

Create Value to String with operation ‘Integer’. 32-bit integer

Inputs

Attribute Type Description
i.value FloatSocket Value
i.decimals IntegerSocket Decimals

Outputs

Attribute Type Description
o.string StringSocket String