nodes.geometry.grid

grid

Classes

Name Description
AdvectGrid Move grid values through a velocity field using numerical integration. Supports multiple integration schemes for different accuracy and performance trade-offs
DistributePointsInGrid Generate points inside a volume grid
DistributePointsInVolume Generate points inside a volume
GetNamedGrid Get volume grid from a volume geometry with the specified name
GridCurl Calculate the magnitude and direction of circulation of a directional vector grid
GridDivergence Calculate the flow into and out of each point of a directional vector grid
GridGradient Calculate the direction and magnitude of the change in values of a scalar grid
GridInfo Retrieve information about a volume grid
GridLaplacian Compute the divergence of the gradient of the input grid
GridToMesh Generate a mesh on the “surface” of a volume grid
MeshToDensityGrid Create a filled volume grid from a mesh
MeshToSDFGrid Create a signed distance volume grid from a mesh
MeshToVolume Create a fog volume with the shape of the input mesh’s surface
PointsToSDFGrid Create a signed distance volume grid from points
PointsToVolume Generate a fog volume sphere around every point
PruneGrid Make the storage of a volume grid more efficient by collapsing data into tiles or inner nodes
SDFGridFillet Round off concave internal corners in a signed distance field. Only affects areas with negative principal curvature, creating smoother transitions between surfaces
SDFGridLaplacian Apply Laplacian flow smoothing to a signed distance field. Computationally efficient alternative to mean curvature flow, ideal when combined with SDF normalization
SDFGridMean Apply mean (box) filter smoothing to a signed distance field. Fast separable averaging filter for general smoothing of the distance field
SDFGridMeanCurvature Apply mean curvature flow smoothing to a signed distance field. Evolves the surface based on its mean curvature, naturally smoothing high-curvature regions more than flat areas
SDFGridMedian Apply median filter to a signed distance field. Reduces noise while preserving sharp features and edges in the distance field
SDFGridOffset Offset a signed distance field surface by a world-space distance. Dilates (positive) or erodes (negative) while maintaining the signed distance property
SampleGrid Retrieve values from the specified volume grid
SampleGridIndex Retrieve volume grid values at specific voxels
SetGridBackground Set the background value used for inactive voxels and tiles
SetGridTransform Set the transform for the grid from index space into object space.
StoreNamedGrid Store grid data in a volume geometry with the specified name
VolumeCube Generate a dense volume with a field that controls the density at each grid voxel based on its position
VolumeToMesh Generate a mesh on the “surface” of a volume
VoxelizeGrid Remove sparseness from a volume grid by making the active tiles into voxels

AdvectGrid

AdvectGrid(
    grid=0.0,
    velocity=None,
    time_step=1.0,
    integration_scheme='Runge-Kutta 3',
    limiter='Clamp',
    *,
    data_type='FLOAT',
)

Move grid values through a velocity field using numerical integration. Supports multiple integration schemes for different accuracy and performance trade-offs

Parameters

Name Type Description Default
grid InputFloat Grid 0.0
velocity InputVector Velocity None
time_step InputFloat Time Step 1.0
integration_scheme InputMenu | Literal['Semi-Lagrangian', 'Midpoint', 'Runge-Kutta 3', 'Runge-Kutta 4', 'MacCormack', 'BFECC'] Integration Scheme 'Runge-Kutta 3'
limiter InputMenu | Literal['None', 'Clamp', 'Revert'] Limiter 'Clamp'

Attributes

Name Description
data_type
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
float Create Advect Grid with operation ‘Float’.
integer Create Advect Grid with operation ‘Integer’.
vector Create Advect Grid with operation ‘Vector’.
float
float(
    grid=0.0,
    velocity=None,
    time_step=1.0,
    integration_scheme='Runge-Kutta 3',
    limiter='Clamp',
)

Create Advect Grid with operation ‘Float’.

integer
integer(
    grid=0,
    velocity=None,
    time_step=1.0,
    integration_scheme='Runge-Kutta 3',
    limiter='Clamp',
)

Create Advect Grid with operation ‘Integer’.

vector
vector(
    grid=None,
    velocity=None,
    time_step=1.0,
    integration_scheme='Runge-Kutta 3',
    limiter='Clamp',
)

Create Advect Grid with operation ‘Vector’.

Inputs

Attribute Type Description
i.grid FloatSocket Grid
i.velocity VectorSocket Velocity
i.time_step FloatSocket Time Step
i.integration_scheme MenuSocket Integration Scheme
i.limiter MenuSocket Limiter

Outputs

Attribute Type Description
o.grid FloatSocket Grid

DistributePointsInGrid

DistributePointsInGrid(
    grid=0.0,
    density=1.0,
    seed=0,
    spacing=None,
    threshold=0.1,
    *,
    mode='DENSITY_RANDOM',
)

Generate points inside a volume grid

Parameters

Name Type Description Default
grid InputFloat Grid 0.0
density InputFloat Density 1.0
seed InputInteger Seed 0
spacing InputVector Spacing None
threshold InputFloat Threshold 0.1

Attributes

Name Description
i
inputs
mode
name
node
o
outputs
tree
type

Methods

Name Description
grid Create Distribute Points in Grid with operation ‘Grid’. Distribute the points in a grid pattern inside of the volume
random Create Distribute Points in Grid with operation ‘Random’. Distribute points randomly inside of the volume
grid
grid(grid=0.0, spacing=None, threshold=0.1)

Create Distribute Points in Grid with operation ‘Grid’. Distribute the points in a grid pattern inside of the volume

random
random(grid=0.0, density=1.0, seed=0)

Create Distribute Points in Grid with operation ‘Random’. Distribute points randomly inside of the volume

Inputs

Attribute Type Description
i.grid FloatSocket Grid
i.density FloatSocket Density
i.seed IntegerSocket Seed
i.spacing VectorSocket Spacing
i.threshold FloatSocket Threshold

Outputs

Attribute Type Description
o.points GeometrySocket Points

DistributePointsInVolume

DistributePointsInVolume(
    volume=None,
    mode='Random',
    density=1.0,
    seed=0,
    spacing=None,
    threshold=0.1,
)

Generate points inside a volume

Parameters

Name Type Description Default
volume InputGeometry Volume None
mode InputMenu | Literal['Random', 'Grid'] Mode 'Random'
density InputFloat Density 1.0
seed InputInteger Seed 0
spacing InputVector Spacing None
threshold InputFloat Threshold 0.1

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.volume GeometrySocket Volume
i.mode MenuSocket Mode
i.density FloatSocket Density
i.seed IntegerSocket Seed
i.spacing VectorSocket Spacing
i.threshold FloatSocket Threshold

Outputs

Attribute Type Description
o.points GeometrySocket Points

GetNamedGrid

GetNamedGrid(volume=None, name='', remove=True, *, data_type='FLOAT')

Get volume grid from a volume geometry with the specified name

Parameters

Name Type Description Default
volume InputGeometry Volume None
name InputString Name ''
remove InputBoolean Remove True

Attributes

Name Description
data_type
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
boolean Create Get Named Grid with operation ‘Boolean’.
float Create Get Named Grid with operation ‘Float’.
integer Create Get Named Grid with operation ‘Integer’.
vector Create Get Named Grid with operation ‘Vector’.
boolean
boolean(volume=None, name='', remove=True)

Create Get Named Grid with operation ‘Boolean’.

float
float(volume=None, name='', remove=True)

Create Get Named Grid with operation ‘Float’.

integer
integer(volume=None, name='', remove=True)

Create Get Named Grid with operation ‘Integer’.

vector
vector(volume=None, name='', remove=True)

Create Get Named Grid with operation ‘Vector’.

Inputs

Attribute Type Description
i.volume GeometrySocket Volume
i.name StringSocket Name
i.remove BooleanSocket Remove

Outputs

Attribute Type Description
o.volume GeometrySocket Volume
o.grid FloatSocket Grid

GridCurl

GridCurl(grid=None)

Calculate the magnitude and direction of circulation of a directional vector grid

Parameters

Name Type Description Default
grid InputVector Grid None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.grid VectorSocket Grid

Outputs

Attribute Type Description
o.curl VectorSocket Curl

GridDivergence

GridDivergence(grid=None)

Calculate the flow into and out of each point of a directional vector grid

Parameters

Name Type Description Default
grid InputVector Grid None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.grid VectorSocket Grid

Outputs

Attribute Type Description
o.divergence FloatSocket Divergence

GridGradient

GridGradient(grid=0.0)

Calculate the direction and magnitude of the change in values of a scalar grid

Parameters

Name Type Description Default
grid InputFloat Grid 0.0

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.grid FloatSocket Grid

Outputs

Attribute Type Description
o.gradient VectorSocket Gradient

GridInfo

GridInfo(grid=0.0, *, data_type='FLOAT')

Retrieve information about a volume grid

Parameters

Name Type Description Default
grid InputFloat Grid 0.0

Attributes

Name Description
data_type
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
boolean Create Grid Info with operation ‘Boolean’.
float Create Grid Info with operation ‘Float’.
integer Create Grid Info with operation ‘Integer’.
vector Create Grid Info with operation ‘Vector’.
boolean
boolean(grid=False)

Create Grid Info with operation ‘Boolean’.

float
float(grid=0.0)

Create Grid Info with operation ‘Float’.

integer
integer(grid=0)

Create Grid Info with operation ‘Integer’.

vector
vector(grid=None)

Create Grid Info with operation ‘Vector’.

Inputs

Attribute Type Description
i.grid FloatSocket Grid

Outputs

Attribute Type Description
o.transform MatrixSocket Transform
o.background_value FloatSocket Background Value

GridLaplacian

GridLaplacian(grid=0.0)

Compute the divergence of the gradient of the input grid

Parameters

Name Type Description Default
grid InputFloat Grid 0.0

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.grid FloatSocket Grid

Outputs

Attribute Type Description
o.laplacian FloatSocket Laplacian

GridToMesh

GridToMesh(grid=0.0, threshold=0.1, adaptivity=0.0)

Generate a mesh on the “surface” of a volume grid

Parameters

Name Type Description Default
grid InputFloat Grid 0.0
threshold InputFloat Threshold 0.1
adaptivity InputFloat Adaptivity 0.0

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.grid FloatSocket Grid
i.threshold FloatSocket Threshold
i.adaptivity FloatSocket Adaptivity

Outputs

Attribute Type Description
o.mesh GeometrySocket Mesh

MeshToDensityGrid

MeshToDensityGrid(mesh=None, density=1.0, voxel_size=0.3, gradient_width=0.2)

Create a filled volume grid from a mesh

Parameters

Name Type Description Default
mesh InputGeometry Mesh None
density InputFloat Density 1.0
voxel_size InputFloat Voxel Size 0.3
gradient_width InputFloat Gradient Width 0.2

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.mesh GeometrySocket Mesh
i.density FloatSocket Density
i.voxel_size FloatSocket Voxel Size
i.gradient_width FloatSocket Gradient Width

Outputs

Attribute Type Description
o.density_grid FloatSocket Density Grid

MeshToSDFGrid

MeshToSDFGrid(mesh=None, voxel_size=0.3, band_width=3)

Create a signed distance volume grid from a mesh

Parameters

Name Type Description Default
mesh InputGeometry Mesh None
voxel_size InputFloat Voxel Size 0.3
band_width InputInteger Band Width 3

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.mesh GeometrySocket Mesh
i.voxel_size FloatSocket Voxel Size
i.band_width IntegerSocket Band Width

Outputs

Attribute Type Description
o.sdf_grid FloatSocket SDF Grid

MeshToVolume

MeshToVolume(
    mesh=None,
    density=1.0,
    resolution_mode='Amount',
    voxel_size=0.3,
    voxel_amount=64.0,
    interior_band_width=0.2,
)

Create a fog volume with the shape of the input mesh’s surface

Parameters

Name Type Description Default
mesh InputGeometry Mesh None
density InputFloat Density 1.0
resolution_mode InputMenu | Literal['Amount', 'Size'] Resolution Mode 'Amount'
voxel_size InputFloat Voxel Size 0.3
voxel_amount InputFloat Voxel Amount 64.0
interior_band_width InputFloat Interior Band Width 0.2

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.mesh GeometrySocket Mesh
i.density FloatSocket Density
i.resolution_mode MenuSocket Resolution Mode
i.voxel_size FloatSocket Voxel Size
i.voxel_amount FloatSocket Voxel Amount
i.interior_band_width FloatSocket Interior Band Width

Outputs

Attribute Type Description
o.volume GeometrySocket Volume

PointsToSDFGrid

PointsToSDFGrid(points=None, radius=0.5, voxel_size=0.3)

Create a signed distance volume grid from points

Parameters

Name Type Description Default
points InputGeometry Points None
radius InputFloat Radius 0.5
voxel_size InputFloat Voxel Size 0.3

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.points GeometrySocket Points
i.radius FloatSocket Radius
i.voxel_size FloatSocket Voxel Size

Outputs

Attribute Type Description
o.sdf_grid FloatSocket SDF Grid

PointsToVolume

PointsToVolume(
    points=None,
    density=1.0,
    resolution_mode='Amount',
    voxel_size=0.3,
    voxel_amount=64.0,
    radius=0.5,
)

Generate a fog volume sphere around every point

Parameters

Name Type Description Default
points InputGeometry Points None
density InputFloat Density 1.0
resolution_mode InputMenu | Literal['Amount', 'Size'] Resolution Mode 'Amount'
voxel_size InputFloat Voxel Size 0.3
voxel_amount InputFloat Voxel Amount 64.0
radius InputFloat Radius 0.5

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.points GeometrySocket Points
i.density FloatSocket Density
i.resolution_mode MenuSocket Resolution Mode
i.voxel_size FloatSocket Voxel Size
i.voxel_amount FloatSocket Voxel Amount
i.radius FloatSocket Radius

Outputs

Attribute Type Description
o.volume GeometrySocket Volume

PruneGrid

PruneGrid(grid=0.0, mode='Threshold', threshold=0.01, *, data_type='FLOAT')

Make the storage of a volume grid more efficient by collapsing data into tiles or inner nodes

Parameters

Name Type Description Default
grid InputFloat Grid 0.0
mode InputMenu | Literal['Inactive', 'Threshold', 'SDF'] Mode 'Threshold'
threshold InputFloat Threshold 0.01

Attributes

Name Description
data_type
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
boolean Create Prune Grid with operation ‘Boolean’.
float Create Prune Grid with operation ‘Float’.
integer Create Prune Grid with operation ‘Integer’.
vector Create Prune Grid with operation ‘Vector’.
boolean
boolean(grid=False, mode='Threshold')

Create Prune Grid with operation ‘Boolean’.

float
float(grid=0.0, mode='Threshold', threshold=0.01)

Create Prune Grid with operation ‘Float’.

integer
integer(grid=0, mode='Threshold', threshold=0)

Create Prune Grid with operation ‘Integer’.

vector
vector(grid=None, mode='Threshold', threshold=None)

Create Prune Grid with operation ‘Vector’.

Inputs

Attribute Type Description
i.grid FloatSocket Grid
i.mode MenuSocket Mode
i.threshold FloatSocket Threshold

Outputs

Attribute Type Description
o.grid FloatSocket Grid

SDFGridFillet

SDFGridFillet(grid=0.0, iterations=1)

Round off concave internal corners in a signed distance field. Only affects areas with negative principal curvature, creating smoother transitions between surfaces

Parameters

Name Type Description Default
grid InputFloat Grid 0.0
iterations InputInteger Iterations 1

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.grid FloatSocket Grid
i.iterations IntegerSocket Iterations

Outputs

Attribute Type Description
o.grid FloatSocket Grid

SDFGridLaplacian

SDFGridLaplacian(grid=0.0, iterations=1)

Apply Laplacian flow smoothing to a signed distance field. Computationally efficient alternative to mean curvature flow, ideal when combined with SDF normalization

Parameters

Name Type Description Default
grid InputFloat Grid 0.0
iterations InputInteger Iterations 1

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.grid FloatSocket Grid
i.iterations IntegerSocket Iterations

Outputs

Attribute Type Description
o.grid FloatSocket Grid

SDFGridMean

SDFGridMean(grid=0.0, width=1, iterations=1)

Apply mean (box) filter smoothing to a signed distance field. Fast separable averaging filter for general smoothing of the distance field

Parameters

Name Type Description Default
grid InputFloat Grid 0.0
width InputInteger Width 1
iterations InputInteger Iterations 1

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.grid FloatSocket Grid
i.width IntegerSocket Width
i.iterations IntegerSocket Iterations

Outputs

Attribute Type Description
o.grid FloatSocket Grid

SDFGridMeanCurvature

SDFGridMeanCurvature(grid=0.0, iterations=1)

Apply mean curvature flow smoothing to a signed distance field. Evolves the surface based on its mean curvature, naturally smoothing high-curvature regions more than flat areas

Parameters

Name Type Description Default
grid InputFloat Grid 0.0
iterations InputInteger Iterations 1

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.grid FloatSocket Grid
i.iterations IntegerSocket Iterations

Outputs

Attribute Type Description
o.grid FloatSocket Grid

SDFGridMedian

SDFGridMedian(grid=0.0, width=1, iterations=1)

Apply median filter to a signed distance field. Reduces noise while preserving sharp features and edges in the distance field

Parameters

Name Type Description Default
grid InputFloat Grid 0.0
width InputInteger Width 1
iterations InputInteger Iterations 1

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.grid FloatSocket Grid
i.width IntegerSocket Width
i.iterations IntegerSocket Iterations

Outputs

Attribute Type Description
o.grid FloatSocket Grid

SDFGridOffset

SDFGridOffset(grid=0.0, distance=0.1)

Offset a signed distance field surface by a world-space distance. Dilates (positive) or erodes (negative) while maintaining the signed distance property

Parameters

Name Type Description Default
grid InputFloat Grid 0.0
distance InputFloat Distance 0.1

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.grid FloatSocket Grid
i.distance FloatSocket Distance

Outputs

Attribute Type Description
o.grid FloatSocket Grid

SampleGrid

SampleGrid(
    grid=0.0,
    position=None,
    interpolation='Trilinear',
    *,
    data_type='FLOAT',
)

Retrieve values from the specified volume grid

Parameters

Name Type Description Default
grid InputFloat Grid 0.0
position InputVector Position None
interpolation InputMenu | Literal['Nearest Neighbor', 'Trilinear', 'Triquadratic'] Interpolation 'Trilinear'

Attributes

Name Description
data_type
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
boolean Create Sample Grid with operation ‘Boolean’.
float Create Sample Grid with operation ‘Float’.
integer Create Sample Grid with operation ‘Integer’.
vector Create Sample Grid with operation ‘Vector’.
boolean
boolean(grid=False, position=None, interpolation='Trilinear')

Create Sample Grid with operation ‘Boolean’.

float
float(grid=0.0, position=None, interpolation='Trilinear')

Create Sample Grid with operation ‘Float’.

integer
integer(grid=0, position=None, interpolation='Trilinear')

Create Sample Grid with operation ‘Integer’.

vector
vector(grid=None, position=None, interpolation='Trilinear')

Create Sample Grid with operation ‘Vector’.

Inputs

Attribute Type Description
i.grid FloatSocket Grid
i.position VectorSocket Position
i.interpolation MenuSocket Interpolation

Outputs

Attribute Type Description
o.value FloatSocket Value

SampleGridIndex

SampleGridIndex(grid=0.0, x=0, y=0, z=0, *, data_type='FLOAT')

Retrieve volume grid values at specific voxels

Parameters

Name Type Description Default
grid InputFloat Grid 0.0
x InputInteger X 0
y InputInteger Y 0
z InputInteger Z 0

Attributes

Name Description
data_type
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
boolean Create Sample Grid Index with operation ‘Boolean’.
float Create Sample Grid Index with operation ‘Float’.
integer Create Sample Grid Index with operation ‘Integer’.
vector Create Sample Grid Index with operation ‘Vector’.
boolean
boolean(grid=False, x=0, y=0, z=0)

Create Sample Grid Index with operation ‘Boolean’.

float
float(grid=0.0, x=0, y=0, z=0)

Create Sample Grid Index with operation ‘Float’.

integer
integer(grid=0, x=0, y=0, z=0)

Create Sample Grid Index with operation ‘Integer’.

vector
vector(grid=None, x=0, y=0, z=0)

Create Sample Grid Index with operation ‘Vector’.

Inputs

Attribute Type Description
i.grid FloatSocket Grid
i.x IntegerSocket X
i.y IntegerSocket Y
i.z IntegerSocket Z

Outputs

Attribute Type Description
o.value FloatSocket Value

SetGridBackground

SetGridBackground(grid=0.0, background=0.0, *, data_type='FLOAT')

Set the background value used for inactive voxels and tiles

Parameters

Name Type Description Default
grid InputFloat Grid 0.0
background InputFloat Background 0.0

Attributes

Name Description
data_type
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
boolean Create Set Grid Background with operation ‘Boolean’.
float Create Set Grid Background with operation ‘Float’.
integer Create Set Grid Background with operation ‘Integer’.
vector Create Set Grid Background with operation ‘Vector’.
boolean
boolean(grid=False, background=False)

Create Set Grid Background with operation ‘Boolean’.

float
float(grid=0.0, background=0.0)

Create Set Grid Background with operation ‘Float’.

integer
integer(grid=0, background=0)

Create Set Grid Background with operation ‘Integer’.

vector
vector(grid=None, background=None)

Create Set Grid Background with operation ‘Vector’.

Inputs

Attribute Type Description
i.grid FloatSocket Grid
i.background FloatSocket Background

Outputs

Attribute Type Description
o.grid FloatSocket Grid

SetGridTransform

SetGridTransform(grid=0.0, transform=None, *, data_type='FLOAT')

Set the transform for the grid from index space into object space.

Parameters

Name Type Description Default
grid InputFloat Grid 0.0
transform InputMatrix Transform None

Attributes

Name Description
data_type
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
boolean Create Set Grid Transform with operation ‘Boolean’.
float Create Set Grid Transform with operation ‘Float’.
integer Create Set Grid Transform with operation ‘Integer’.
vector Create Set Grid Transform with operation ‘Vector’.
boolean
boolean(grid=False, transform=None)

Create Set Grid Transform with operation ‘Boolean’.

float
float(grid=0.0, transform=None)

Create Set Grid Transform with operation ‘Float’.

integer
integer(grid=0, transform=None)

Create Set Grid Transform with operation ‘Integer’.

vector
vector(grid=None, transform=None)

Create Set Grid Transform with operation ‘Vector’.

Inputs

Attribute Type Description
i.grid FloatSocket Grid
i.transform MatrixSocket Transform

Outputs

Attribute Type Description
o.is_valid BooleanSocket Is Valid
o.grid FloatSocket Grid

StoreNamedGrid

StoreNamedGrid(volume=None, name='', grid=0.0, *, data_type='FLOAT')

Store grid data in a volume geometry with the specified name

Parameters

Name Type Description Default
volume InputGeometry Volume None
name InputString Name ''
grid InputFloat Grid 0.0

Attributes

Name Description
data_type
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
boolean Create Store Named Grid with operation ‘Boolean’. Boolean
float Create Store Named Grid with operation ‘Float’. Single precision float
integer Create Store Named Grid with operation ‘Integer’. 32-bit integer
vector Create Store Named Grid with operation ‘Vector’. 3D float vector
boolean
boolean(volume=None, name='', grid=False)

Create Store Named Grid with operation ‘Boolean’. Boolean

float
float(volume=None, name='', grid=0.0)

Create Store Named Grid with operation ‘Float’. Single precision float

integer
integer(volume=None, name='', grid=0)

Create Store Named Grid with operation ‘Integer’. 32-bit integer

vector
vector(volume=None, name='', grid=None)

Create Store Named Grid with operation ‘Vector’. 3D float vector

Inputs

Attribute Type Description
i.volume GeometrySocket Volume
i.name StringSocket Name
i.grid FloatSocket Grid

Outputs

Attribute Type Description
o.volume GeometrySocket Volume

VolumeCube

VolumeCube(
    density=1.0,
    background=0.0,
    min=None,
    max=None,
    resolution_x=32,
    resolution_y=32,
    resolution_z=32,
)

Generate a dense volume with a field that controls the density at each grid voxel based on its position

Parameters

Name Type Description Default
density InputFloat Density 1.0
background InputFloat Background 0.0
min InputVector Min None
max InputVector Max None
resolution_x InputInteger Resolution X 32
resolution_y InputInteger Resolution Y 32
resolution_z InputInteger Resolution Z 32

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.density FloatSocket Density
i.background FloatSocket Background
i.min VectorSocket Min
i.max VectorSocket Max
i.resolution_x IntegerSocket Resolution X
i.resolution_y IntegerSocket Resolution Y
i.resolution_z IntegerSocket Resolution Z

Outputs

Attribute Type Description
o.volume GeometrySocket Volume

VolumeToMesh

VolumeToMesh(
    volume=None,
    resolution_mode='Grid',
    voxel_size=0.3,
    voxel_amount=64.0,
    threshold=0.1,
    adaptivity=0.0,
)

Generate a mesh on the “surface” of a volume

Parameters

Name Type Description Default
volume InputGeometry Volume None
resolution_mode InputMenu | Literal['Grid', 'Amount', 'Size'] Resolution Mode 'Grid'
voxel_size InputFloat Voxel Size 0.3
voxel_amount InputFloat Voxel Amount 64.0
threshold InputFloat Threshold 0.1
adaptivity InputFloat Adaptivity 0.0

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.volume GeometrySocket Volume
i.resolution_mode MenuSocket Resolution Mode
i.voxel_size FloatSocket Voxel Size
i.voxel_amount FloatSocket Voxel Amount
i.threshold FloatSocket Threshold
i.adaptivity FloatSocket Adaptivity

Outputs

Attribute Type Description
o.mesh GeometrySocket Mesh

VoxelizeGrid

VoxelizeGrid(grid=0.0, *, data_type='FLOAT')

Remove sparseness from a volume grid by making the active tiles into voxels

Parameters

Name Type Description Default
grid InputFloat Grid 0.0

Attributes

Name Description
data_type
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
boolean Create Voxelize Grid with operation ‘Boolean’.
float Create Voxelize Grid with operation ‘Float’.
integer Create Voxelize Grid with operation ‘Integer’.
vector Create Voxelize Grid with operation ‘Vector’.
boolean
boolean(grid=False)

Create Voxelize Grid with operation ‘Boolean’.

float
float(grid=0.0)

Create Voxelize Grid with operation ‘Float’.

integer
integer(grid=0)

Create Voxelize Grid with operation ‘Integer’.

vector
vector(grid=None)

Create Voxelize Grid with operation ‘Vector’.

Inputs

Attribute Type Description
i.grid FloatSocket Grid

Outputs

Attribute Type Description
o.grid FloatSocket Grid