nodes.geometry.groups

groups

Classes

Name Description
ClipFieldToBox
GeometryPrincipalComponents
OffsetVector Evaluate a given vector field at an offset to the current Index.
OtherVertex Given a vertex and an edge number from that vertex, returns the other
PrincipalComponents Compute PCA on a given vector field.
SliceToIndices Converts a python slice to a list of indices.

ClipFieldToBox

ClipFieldToBox(box_object=None, invert=False)

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
name The name of the node being wrapped by this instance.
node
node_tree
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Methods

Name Description
create_group Build this group’s node tree and return it, reusing an existing tree
create_group
create_group()

Build this group’s node tree and return it, reusing an existing tree of the same name.

Unlike instantiating the class, this needs no active TreeBuilder context — it opens its own — so a group can be pre-built and reused directly (e.g. assigned to a node’s node_tree) instead of being created by constructing the class inside a tree.

GeometryPrincipalComponents

GeometryPrincipalComponents(geometry=None, position=None)

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
node_tree
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Methods

Name Description
create_group Build this group’s node tree and return it, reusing an existing tree
create_group
create_group()

Build this group’s node tree and return it, reusing an existing tree of the same name.

Unlike instantiating the class, this needs no active TreeBuilder context — it opens its own — so a group can be pre-built and reused directly (e.g. assigned to a node’s node_tree) instead of being created by constructing the class inside a tree.

OffsetVector

OffsetVector(index=None, vector=None, offset=0)

Evaluate a given vector field at an offset to the current Index.

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
node_tree
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Methods

Name Description
create_group Build this group’s node tree and return it, reusing an existing tree
create_group
create_group()

Build this group’s node tree and return it, reusing an existing tree of the same name.

Unlike instantiating the class, this needs no active TreeBuilder context — it opens its own — so a group can be pre-built and reused directly (e.g. assigned to a node’s node_tree) instead of being created by constructing the class inside a tree.

OtherVertex

OtherVertex(vertex_index=None, edge_number=0)

Given a vertex and an edge number from that vertex, returns the other vertex of that edge.

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
node_tree
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Methods

Name Description
create_group Build this group’s node tree and return it, reusing an existing tree
create_group
create_group()

Build this group’s node tree and return it, reusing an existing tree of the same name.

Unlike instantiating the class, this needs no active TreeBuilder context — it opens its own — so a group can be pre-built and reused directly (e.g. assigned to a node’s node_tree) instead of being created by constructing the class inside a tree.

PrincipalComponents

PrincipalComponents(position=None, group_id=None)

Compute PCA on a given vector field.

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
node_tree
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Methods

Name Description
create_group Build this group’s node tree and return it, reusing an existing tree
create_group
create_group()

Build this group’s node tree and return it, reusing an existing tree of the same name.

Unlike instantiating the class, this needs no active TreeBuilder context — it opens its own — so a group can be pre-built and reused directly (e.g. assigned to a node’s node_tree) instead of being created by constructing the class inside a tree.

SliceToIndices

SliceToIndices(start=0, stop=0, step=1)

Converts a python slice to a list of indices.

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
node_tree
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Methods

Name Description
create_group Build this group’s node tree and return it, reusing an existing tree
create_group
create_group()

Build this group’s node tree and return it, reusing an existing tree of the same name.

Unlike instantiating the class, this needs no active TreeBuilder context — it opens its own — so a group can be pre-built and reused directly (e.g. assigned to a node’s node_tree) instead of being created by constructing the class inside a tree.