nodes.geometry.input
input
Classes
| Name | Description |
|---|---|
| ActiveCamera | Retrieve the scene’s active camera |
| ActiveElement | Active element indices of the edited geometry, for tool execution |
| BoneInfo | Retrieve information of armature bones |
| Boolean | Provide a True/False value that can be connected to other nodes in the tree |
| CameraInfo | Retrieve information from a camera object |
| CollectionChildren | Retrieve a collection’s object and collection children, in a name-based order |
| CollectionInfo | Retrieve geometry instances from a collection |
| Color | Output a color value chosen with the color picker widget |
| CornersOfEdge | Retrieve face corners connected to edges |
| CornersOfFace | Retrieve corners that make up a face |
| CornersOfVertex | Retrieve face corners connected to vertices |
| Cursor3D | The scene’s 3D cursor location and rotation |
| CurveHandlePositions | Retrieve the position of each Bézier control point’s handles |
| CurveOfPoint | Retrieve the curve a control point is part of |
| CurveTangent | Retrieve the direction of curves at each control point |
| CurveTilt | Retrieve the angle at each control point used to twist the curve’s normal around its tangent |
| EdgeAngle | The angle between the normals of connected manifold faces |
| EdgeNeighbors | Retrieve the number of faces that use each edge as one of their sides |
| EdgePathsToSelection | Output a selection of edges by following paths across mesh edges |
| EdgeVertices | Retrieve topology information relating to each edge of a mesh |
| EdgesOfCorner | Retrieve the edges on both sides of a face corner |
| EdgesOfVertex | Retrieve the edges connected to each vertex |
| EdgesToFaceGroups | Group faces into regions surrounded by the selected boundary edges |
| EndpointSelection | Provide a selection for an arbitrary number of endpoints in each spline |
| FaceArea | Calculate the surface area of a mesh’s faces |
| FaceGroupBoundaries | Find edges on the boundaries between groups of faces with the same ID value |
| FaceNeighbors | Retrieve topology information relating to each face of a mesh |
| FaceOfCorner | Retrieve the face each face corner is part of |
| FaceSet | Each face’s sculpt face set value |
| Font | Output a font |
| HandleTypeSelection | Provide a selection based on the handle types of Bézier control points |
| ID | Retrieve a stable random identifier value from the “id” attribute on the point domain, or the index if the attribute does not exist |
| Image | Input an image data-block |
| ImageInfo | Retrieve information about an image |
| ImportCSV | Import geometry from an CSV file |
| ImportOBJ | Import geometry from an OBJ file |
| ImportPLY | Import a point cloud from a PLY file |
| ImportSTL | Import a mesh from an STL file |
| ImportText | Import a string from a text file |
| ImportVDB | Import volume data from a .vdb file |
| Index | Retrieve an integer value indicating the position of each element in the list, starting at zero |
| InstanceBounds | Calculate position bounds of each instance’s geometry set |
| InstanceReference | Output the reference index of the instance |
| InstanceRotation | Retrieve the rotation of each instance in the geometry |
| InstanceScale | Retrieve the scale of each instance in the geometry |
| InstanceTransform | Retrieve the full transformation of each instance in the geometry |
| Integer | Provide an integer value that can be connected to other nodes in the tree |
| IsEdgeSmooth | Retrieve whether each edge is marked for smooth or split normals |
| IsFacePlanar | Retrieve whether all triangles in a face are on the same plane, i.e. whether they have the same normal |
| IsFaceSmooth | Retrieve whether each face is marked for smooth or sharp normals |
| IsSplineCyclic | Retrieve whether each spline endpoint connects to the beginning |
| IsViewport | Retrieve whether the nodes are being evaluated for the viewport rather than the final render |
| MaterialIndex | Retrieve the index of the material used for each element in the geometry’s list of materials |
| MeshIsland | Retrieve information about separate connected regions in a mesh |
| MousePosition | Retrieve the position of the mouse cursor |
| NamedAttribute | Retrieve the data of a specified attribute |
| NamedLayerSelection | Output a selection of a Grease Pencil layer |
| Normal | Retrieve a unit length vector indicating the direction pointing away from the geometry at each element |
| ObjectInfo | Retrieve information from an object |
| OffsetCornerInFace | Retrieve corners in the same face as another |
| OffsetPointInCurve | Offset a control point index within its curve |
| PointsOfCurve | Retrieve a point index within a curve |
| Position | Retrieve a vector indicating the location of each element |
| Radius | Retrieve the radius at each point on curve or point cloud geometry |
| Rotation | Provide a rotation value that can be connected to other nodes in the tree |
| SceneTime | Retrieve the current time in the scene’s animation in units of seconds or frames |
| Selection | User selection of the edited geometry, for tool execution |
| SelfObject | Retrieve the object that contains the geometry nodes modifier currently being executed |
| ShortestEdgePaths | Find the shortest paths along mesh edges to selected end vertices, with customizable cost per edge |
| SpecialCharacters | Output string characters that cannot be typed directly with the keyboard |
| SplineLength | Retrieve the total length of each spline, as a distance or as a number of points |
| SplineParameter | Retrieve how far along each spline a control point is |
| SplineResolution | Retrieve the number of evaluated points that will be generated for every control point on curves |
| String | Provide a string value that can be connected to other nodes in the tree |
| UVTangent | Generate tangent directions based on a UV map |
| Vector | Provide a vector value that can be connected to other nodes in the tree |
| VertexNeighbors | Retrieve topology information relating to each vertex of a mesh |
| VertexOfCorner | Retrieve the vertex each face corner is attached to |
| ViewportTransform | Retrieve the view direction and location of the 3D viewport |
| VoxelIndex | Retrieve the integer coordinates of the voxel that the field is evaluated on |
ActiveCamera
ActiveCamera()Retrieve the scene’s active camera
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.active_camera |
ObjectSocket |
Active Camera |
ActiveElement
ActiveElement(domain='POINT')Active element indices of the edited geometry, for tool execution
Attributes
| Name | Description |
|---|---|
domain |
|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Methods
| Name | Description |
|---|---|
| edge | Create Active Element with operation ‘Edge’. |
| face | Create Active Element with operation ‘Face’. |
| layer | Create Active Element with operation ‘Layer’. |
| point | Create Active Element with operation ‘Point’. |
edge
edge()Create Active Element with operation ‘Edge’.
face
face()Create Active Element with operation ‘Face’.
layer
layer()Create Active Element with operation ‘Layer’.
point
point()Create Active Element with operation ‘Point’.
Outputs
| Attribute | Type | Description |
|---|---|---|
o.index |
IntegerSocket |
Index |
o.exists |
BooleanSocket |
Exists |
BoneInfo
BoneInfo(armature=None, bone_name='', *, transform_space='ORIGINAL')Retrieve information of armature bones
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| armature | InputObject | Armature | None |
| bone_name | InputString | Bone Name | '' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
transform_space |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.armature |
ObjectSocket |
Armature |
i.bone_name |
StringSocket |
Bone Name |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.pose |
MatrixSocket |
Pose |
o.local_pose |
MatrixSocket |
Local Pose |
o.transform_pose |
MatrixSocket |
Transform Pose |
o.rest_pose |
MatrixSocket |
Rest Pose |
o.rest_length |
FloatSocket |
Rest Length |
o.exists |
BooleanSocket |
Exists |
Boolean
Boolean(boolean=False)Provide a True/False value that can be connected to other nodes in the tree
Attributes
| Name | Description |
|---|---|
boolean |
|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.boolean |
BooleanSocket |
Boolean |
CameraInfo
CameraInfo(camera=None)Retrieve information from a camera object
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| camera | InputObject | Camera | None |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.camera |
ObjectSocket |
Camera |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.projection_matrix |
MatrixSocket |
Projection Matrix |
o.focal_length |
FloatSocket |
Focal Length |
o.sensor |
VectorSocket |
Sensor |
o.shift |
VectorSocket |
Shift |
o.clip_start |
FloatSocket |
Clip Start |
o.clip_end |
FloatSocket |
Clip End |
o.focus_distance |
FloatSocket |
Focus Distance |
o.is_orthographic |
BooleanSocket |
Is Orthographic |
o.orthographic_scale |
FloatSocket |
Orthographic Scale |
CollectionChildren
CollectionChildren(collection=None, recursive=False)Retrieve a collection’s object and collection children, in a name-based order
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| collection | InputCollection | Collection | None |
| recursive | InputBoolean | Recursive | False |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.collection |
CollectionSocket |
Collection |
i.recursive |
BooleanSocket |
Recursive |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.collections |
CollectionSocket |
Collections |
o.objects |
ObjectSocket |
Objects |
CollectionInfo
CollectionInfo(
collection=None,
separate_children=False,
reset_children=False,
*,
transform_space='ORIGINAL',
)Retrieve geometry instances from a collection
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| collection | InputCollection | Collection | None |
| separate_children | InputBoolean | Separate Children | False |
| reset_children | InputBoolean | Reset Children | False |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
transform_space |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.collection |
CollectionSocket |
Collection |
i.separate_children |
BooleanSocket |
Separate Children |
i.reset_children |
BooleanSocket |
Reset Children |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.instances |
GeometrySocket |
Instances |
Color
Color(value=(0.735, 0.735, 0.735, 1.0))Output a color value chosen with the color picker widget
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
value |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.color |
ColorSocket |
Color |
CornersOfEdge
CornersOfEdge(edge_index=0, weights=0.0, sort_index=0)Retrieve face corners connected to edges
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| edge_index | InputInteger | Edge Index | 0 |
| weights | InputFloat | Weights | 0.0 |
| sort_index | InputInteger | Sort Index | 0 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.edge_index |
IntegerSocket |
Edge Index |
i.weights |
FloatSocket |
Weights |
i.sort_index |
IntegerSocket |
Sort Index |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.corner_index |
IntegerSocket |
Corner Index |
o.total |
IntegerSocket |
Total |
CornersOfFace
CornersOfFace(face_index=0, weights=0.0, sort_index=0)Retrieve corners that make up a face
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| face_index | InputInteger | Face Index | 0 |
| weights | InputFloat | Weights | 0.0 |
| sort_index | InputInteger | Sort Index | 0 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.face_index |
IntegerSocket |
Face Index |
i.weights |
FloatSocket |
Weights |
i.sort_index |
IntegerSocket |
Sort Index |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.corner_index |
IntegerSocket |
Corner Index |
o.total |
IntegerSocket |
Total |
CornersOfVertex
CornersOfVertex(vertex_index=0, weights=0.0, sort_index=0)Retrieve face corners connected to vertices
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vertex_index | InputInteger | Vertex Index | 0 |
| weights | InputFloat | Weights | 0.0 |
| sort_index | InputInteger | Sort Index | 0 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vertex_index |
IntegerSocket |
Vertex Index |
i.weights |
FloatSocket |
Weights |
i.sort_index |
IntegerSocket |
Sort Index |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.corner_index |
IntegerSocket |
Corner Index |
o.total |
IntegerSocket |
Total |
Cursor3D
Cursor3D()The scene’s 3D cursor location and rotation
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.location |
VectorSocket |
Location |
o.rotation |
RotationSocket |
Rotation |
CurveHandlePositions
CurveHandlePositions(relative=False)Retrieve the position of each Bézier control point’s handles
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| relative | InputBoolean | Relative | False |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.relative |
BooleanSocket |
Relative |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.left |
VectorSocket |
Left |
o.right |
VectorSocket |
Right |
CurveOfPoint
CurveOfPoint(point_index=0)Retrieve the curve a control point is part of
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| point_index | InputInteger | Point Index | 0 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.point_index |
IntegerSocket |
Point Index |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.curve_index |
IntegerSocket |
Curve Index |
o.index_in_curve |
IntegerSocket |
Index in Curve |
CurveTangent
CurveTangent()Retrieve the direction of curves at each control point
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.tangent |
VectorSocket |
Tangent |
CurveTilt
CurveTilt()Retrieve the angle at each control point used to twist the curve’s normal around its tangent
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.tilt |
FloatSocket |
Tilt |
EdgeAngle
EdgeAngle()The angle between the normals of connected manifold faces
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.unsigned_angle |
FloatSocket |
Unsigned Angle |
o.signed_angle |
FloatSocket |
Signed Angle |
EdgeNeighbors
EdgeNeighbors()Retrieve the number of faces that use each edge as one of their sides
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.face_count |
IntegerSocket |
Face Count |
EdgePathsToSelection
EdgePathsToSelection(start_vertices=True, next_vertex_index=-1)Output a selection of edges by following paths across mesh edges
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| start_vertices | InputBoolean | Start Vertices | True |
| next_vertex_index | InputInteger | Next Vertex Index | -1 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.start_vertices |
BooleanSocket |
Start Vertices |
i.next_vertex_index |
IntegerSocket |
Next Vertex Index |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.selection |
BooleanSocket |
Selection |
EdgeVertices
EdgeVertices()Retrieve topology information relating to each edge of a mesh
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.vertex_index_1 |
IntegerSocket |
Vertex Index 1 |
o.vertex_index_2 |
IntegerSocket |
Vertex Index 2 |
o.position_1 |
VectorSocket |
Position 1 |
o.position_2 |
VectorSocket |
Position 2 |
EdgesOfCorner
EdgesOfCorner(corner_index=0)Retrieve the edges on both sides of a face corner
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| corner_index | InputInteger | Corner Index | 0 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.corner_index |
IntegerSocket |
Corner Index |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.next_edge_index |
IntegerSocket |
Next Edge Index |
o.previous_edge_index |
IntegerSocket |
Previous Edge Index |
EdgesOfVertex
EdgesOfVertex(vertex_index=0, weights=0.0, sort_index=0)Retrieve the edges connected to each vertex
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vertex_index | InputInteger | Vertex Index | 0 |
| weights | InputFloat | Weights | 0.0 |
| sort_index | InputInteger | Sort Index | 0 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vertex_index |
IntegerSocket |
Vertex Index |
i.weights |
FloatSocket |
Weights |
i.sort_index |
IntegerSocket |
Sort Index |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.edge_index |
IntegerSocket |
Edge Index |
o.total |
IntegerSocket |
Total |
EdgesToFaceGroups
EdgesToFaceGroups(boundary_edges=True)Group faces into regions surrounded by the selected boundary edges
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| boundary_edges | InputBoolean | Boundary Edges | True |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.boundary_edges |
BooleanSocket |
Boundary Edges |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.face_group_id |
IntegerSocket |
Face Group ID |
EndpointSelection
EndpointSelection(start_size=1, end_size=1)Provide a selection for an arbitrary number of endpoints in each spline
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| start_size | InputInteger | Start Size | 1 |
| end_size | InputInteger | End Size | 1 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.start_size |
IntegerSocket |
Start Size |
i.end_size |
IntegerSocket |
End Size |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.selection |
BooleanSocket |
Selection |
FaceArea
FaceArea()Calculate the surface area of a mesh’s faces
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.area |
FloatSocket |
Area |
FaceGroupBoundaries
FaceGroupBoundaries(face_set=0)Find edges on the boundaries between groups of faces with the same ID value
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| face_set | InputInteger | Face Group ID | 0 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.face_set |
IntegerSocket |
Face Group ID |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.boundary_edges |
BooleanSocket |
Boundary Edges |
FaceNeighbors
FaceNeighbors()Retrieve topology information relating to each face of a mesh
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.vertex_count |
IntegerSocket |
Vertex Count |
o.face_count |
IntegerSocket |
Face Count |
FaceOfCorner
FaceOfCorner(corner_index=0)Retrieve the face each face corner is part of
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| corner_index | InputInteger | Corner Index | 0 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.corner_index |
IntegerSocket |
Corner Index |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.face_index |
IntegerSocket |
Face Index |
o.index_in_face |
IntegerSocket |
Index in Face |
FaceSet
FaceSet()Each face’s sculpt face set value
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.face_set |
IntegerSocket |
Face Set |
o.exists |
BooleanSocket |
Exists |
Font
Font()Output a font
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.font |
FontSocket |
Font |
HandleTypeSelection
HandleTypeSelection(handle_type='AUTO', left=True, right=True)Provide a selection based on the handle types of Bézier control points
Attributes
| Name | Description |
|---|---|
handle_type |
|
i |
|
left |
|
mode |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
right |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Methods
| Name | Description |
|---|---|
| align | Create Handle Type Selection with operation ‘Align’. The location is constrained to point in the opposite direction as the other handle |
| auto | Create Handle Type Selection with operation ‘Auto’. The location is automatically calculated to be smooth |
| free | Create Handle Type Selection with operation ‘Free’. The handle can be moved anywhere, and does not influence the point’s other handle |
| vector | Create Handle Type Selection with operation ‘Vector’. The location is calculated to point to the next/previous control point |
align
align()Create Handle Type Selection with operation ‘Align’. The location is constrained to point in the opposite direction as the other handle
auto
auto()Create Handle Type Selection with operation ‘Auto’. The location is automatically calculated to be smooth
free
free()Create Handle Type Selection with operation ‘Free’. The handle can be moved anywhere, and does not influence the point’s other handle
vector
vector()Create Handle Type Selection with operation ‘Vector’. The location is calculated to point to the next/previous control point
Outputs
| Attribute | Type | Description |
|---|---|---|
o.selection |
BooleanSocket |
Selection |
ID
ID()Retrieve a stable random identifier value from the “id” attribute on the point domain, or the index if the attribute does not exist
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.id |
IntegerSocket |
ID |
Image
Image()Input an image data-block
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ImageSocket |
Image |
ImageInfo
ImageInfo(image=None, frame=0)Retrieve information about an image
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputImage | Image | None |
| frame | InputInteger | Frame | 0 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ImageSocket |
Image |
i.frame |
IntegerSocket |
Frame |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.width |
IntegerSocket |
Width |
o.height |
IntegerSocket |
Height |
o.has_alpha |
BooleanSocket |
Has Alpha |
o.frame_count |
IntegerSocket |
Frame Count |
o.fps |
FloatSocket |
FPS |
ImportCSV
ImportCSV(path='', delimiter=',')Import geometry from an CSV file
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| path | InputString | Path | '' |
| delimiter | InputString | Delimiter | ',' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.path |
StringSocket |
Path |
i.delimiter |
StringSocket |
Delimiter |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.point_cloud |
GeometrySocket |
Point Cloud |
ImportOBJ
ImportOBJ(path='')Import geometry from an OBJ file
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| path | InputString | Path | '' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.path |
StringSocket |
Path |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.instances |
GeometrySocket |
Instances |
ImportPLY
ImportPLY(path='')Import a point cloud from a PLY file
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| path | InputString | Path | '' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.path |
StringSocket |
Path |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.mesh |
GeometrySocket |
Mesh |
ImportSTL
ImportSTL(path='')Import a mesh from an STL file
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| path | InputString | Path | '' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.path |
StringSocket |
Path |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.mesh |
GeometrySocket |
Mesh |
ImportText
ImportText(path='')Import a string from a text file
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| path | InputString | Path | '' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.path |
StringSocket |
Path |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.string |
StringSocket |
String |
ImportVDB
ImportVDB(path='')Import volume data from a .vdb file
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| path | InputString | Path | '' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.path |
StringSocket |
Path |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.volume |
GeometrySocket |
Volume |
Index
Index()Retrieve an integer value indicating the position of each element in the list, starting at zero
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.index |
IntegerSocket |
Index |
InstanceBounds
InstanceBounds(use_radius=True)Calculate position bounds of each instance’s geometry set
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| use_radius | InputBoolean | Use Radius | True |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.use_radius |
BooleanSocket |
Use Radius |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.min |
VectorSocket |
Min |
o.max |
VectorSocket |
Max |
InstanceReference
InstanceReference()Output the reference index of the instance
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.reference_index |
IntegerSocket |
Reference Index |
InstanceRotation
InstanceRotation()Retrieve the rotation of each instance in the geometry
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.rotation |
RotationSocket |
Rotation |
InstanceScale
InstanceScale()Retrieve the scale of each instance in the geometry
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.scale |
VectorSocket |
Scale |
InstanceTransform
InstanceTransform()Retrieve the full transformation of each instance in the geometry
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.transform |
MatrixSocket |
Transform |
Integer
Integer(integer=1)Provide an integer value that can be connected to other nodes in the tree
Attributes
| Name | Description |
|---|---|
i |
|
integer |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.integer |
IntegerSocket |
Integer |
IsEdgeSmooth
IsEdgeSmooth()Retrieve whether each edge is marked for smooth or split normals
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.smooth |
BooleanSocket |
Smooth |
IsFacePlanar
IsFacePlanar(threshold=0.01)Retrieve whether all triangles in a face are on the same plane, i.e. whether they have the same normal
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| threshold | InputFloat | Threshold | 0.01 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.threshold |
FloatSocket |
Threshold |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.planar |
BooleanSocket |
Planar |
IsFaceSmooth
IsFaceSmooth()Retrieve whether each face is marked for smooth or sharp normals
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.smooth |
BooleanSocket |
Smooth |
IsSplineCyclic
IsSplineCyclic()Retrieve whether each spline endpoint connects to the beginning
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.cyclic |
BooleanSocket |
Cyclic |
IsViewport
IsViewport()Retrieve whether the nodes are being evaluated for the viewport rather than the final render
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.is_viewport |
BooleanSocket |
Is Viewport |
MaterialIndex
MaterialIndex()Retrieve the index of the material used for each element in the geometry’s list of materials
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.material_index |
IntegerSocket |
Material Index |
MeshIsland
MeshIsland()Retrieve information about separate connected regions in a mesh
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.island_index |
IntegerSocket |
Island Index |
o.island_count |
IntegerSocket |
Island Count |
MousePosition
MousePosition()Retrieve the position of the mouse cursor
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.mouse_x |
IntegerSocket |
Mouse X |
o.mouse_y |
IntegerSocket |
Mouse Y |
o.region_width |
IntegerSocket |
Region Width |
o.region_height |
IntegerSocket |
Region Height |
NamedAttribute
NamedAttribute(name='', *, data_type='FLOAT')Retrieve the data of a specified attribute
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| name | InputString | Name | '' |
Attributes
| Name | Description |
|---|---|
data_type |
|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Methods
| Name | Description |
|---|---|
| boolean | Create Named Attribute with operation ‘Boolean’. True or false |
| color | Create Named Attribute with operation ‘Color’. RGBA color with 32-bit floating-point values |
| float | Create Named Attribute with operation ‘Float’. Floating-point value |
| input_4x4_matrix | Create Named Attribute with operation ‘4x4 Matrix’. Floating point matrix |
| integer | Create Named Attribute with operation ‘Integer’. 32-bit integer |
| quaternion | Create Named Attribute with operation ‘Quaternion’. Floating point quaternion rotation |
| vector | Create Named Attribute with operation ‘Vector’. 3D vector with floating-point values |
boolean
boolean(name='')Create Named Attribute with operation ‘Boolean’. True or false
color
color(name='')Create Named Attribute with operation ‘Color’. RGBA color with 32-bit floating-point values
float
float(name='')Create Named Attribute with operation ‘Float’. Floating-point value
input_4x4_matrix
input_4x4_matrix(name='')Create Named Attribute with operation ‘4x4 Matrix’. Floating point matrix
integer
integer(name='')Create Named Attribute with operation ‘Integer’. 32-bit integer
quaternion
quaternion(name='')Create Named Attribute with operation ‘Quaternion’. Floating point quaternion rotation
vector
vector(name='')Create Named Attribute with operation ‘Vector’. 3D vector with floating-point values
Inputs
| Attribute | Type | Description |
|---|---|---|
i.name |
StringSocket |
Name |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.attribute |
FloatSocket |
Attribute |
o.exists |
BooleanSocket |
Exists |
NamedLayerSelection
NamedLayerSelection(name='')Output a selection of a Grease Pencil layer
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| name | InputString | Name | '' |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.name |
StringSocket |
Name |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.selection |
BooleanSocket |
Selection |
Normal
Normal(legacy_corner_normals=False)Retrieve a unit length vector indicating the direction pointing away from the geometry at each element
Attributes
| Name | Description |
|---|---|
i |
|
legacy_corner_normals |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.normal |
VectorSocket |
Normal |
o.true_normal |
VectorSocket |
True Normal |
ObjectInfo
ObjectInfo(object=None, as_instance=False, *, transform_space='ORIGINAL')Retrieve information from an object
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| object | InputObject | Object | None |
| as_instance | InputBoolean | As Instance | False |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
transform_space |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.object |
ObjectSocket |
Object |
i.as_instance |
BooleanSocket |
As Instance |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.transform |
MatrixSocket |
Transform |
o.location |
VectorSocket |
Location |
o.rotation |
RotationSocket |
Rotation |
o.scale |
VectorSocket |
Scale |
o.geometry |
GeometrySocket |
Geometry |
OffsetCornerInFace
OffsetCornerInFace(corner_index=0, offset=0)Retrieve corners in the same face as another
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| corner_index | InputInteger | Corner Index | 0 |
| offset | InputInteger | Offset | 0 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.corner_index |
IntegerSocket |
Corner Index |
i.offset |
IntegerSocket |
Offset |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.corner_index |
IntegerSocket |
Corner Index |
OffsetPointInCurve
OffsetPointInCurve(point_index=0, offset=0)Offset a control point index within its curve
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| point_index | InputInteger | Point Index | 0 |
| offset | InputInteger | Offset | 0 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.point_index |
IntegerSocket |
Point Index |
i.offset |
IntegerSocket |
Offset |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.is_valid_offset |
BooleanSocket |
Is Valid Offset |
o.point_index |
IntegerSocket |
Point Index |
PointsOfCurve
PointsOfCurve(curve_index=0, weights=0.0, sort_index=0)Retrieve a point index within a curve
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| curve_index | InputInteger | Curve Index | 0 |
| weights | InputFloat | Weights | 0.0 |
| sort_index | InputInteger | Sort Index | 0 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.curve_index |
IntegerSocket |
Curve Index |
i.weights |
FloatSocket |
Weights |
i.sort_index |
IntegerSocket |
Sort Index |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.point_index |
IntegerSocket |
Point Index |
o.total |
IntegerSocket |
Total |
Position
Position()Retrieve a vector indicating the location of each element
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.position |
VectorSocket |
Position |
Radius
Radius()Retrieve the radius at each point on curve or point cloud geometry
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.radius |
FloatSocket |
Radius |
Rotation
Rotation(rotation_euler=(0.0, 0.0, 0.0))Provide a rotation value that can be connected to other nodes in the tree
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
rotation_euler |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.rotation |
RotationSocket |
Rotation |
SceneTime
SceneTime()Retrieve the current time in the scene’s animation in units of seconds or frames
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.seconds |
FloatSocket |
Seconds |
o.frame |
FloatSocket |
Frame |
Selection
Selection()User selection of the edited geometry, for tool execution
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.selection |
BooleanSocket |
Boolean |
o.float |
FloatSocket |
Float |
SelfObject
SelfObject()Retrieve the object that contains the geometry nodes modifier currently being executed
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.self_object |
ObjectSocket |
Self Object |
ShortestEdgePaths
ShortestEdgePaths(end_vertex=False, edge_cost=1.0)Find the shortest paths along mesh edges to selected end vertices, with customizable cost per edge
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| end_vertex | InputBoolean | End Vertex | False |
| edge_cost | InputFloat | Edge Cost | 1.0 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.end_vertex |
BooleanSocket |
End Vertex |
i.edge_cost |
FloatSocket |
Edge Cost |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.next_vertex_index |
IntegerSocket |
Next Vertex Index |
o.total_cost |
FloatSocket |
Total Cost |
SpecialCharacters
SpecialCharacters()Output string characters that cannot be typed directly with the keyboard
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.line_break |
StringSocket |
Line Break |
o.tab |
StringSocket |
Tab |
SplineLength
SplineLength()Retrieve the total length of each spline, as a distance or as a number of points
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.length |
FloatSocket |
Length |
o.point_count |
IntegerSocket |
Point Count |
SplineParameter
SplineParameter()Retrieve how far along each spline a control point is
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.factor |
FloatSocket |
Factor |
o.length |
FloatSocket |
Length |
o.index |
IntegerSocket |
Index |
SplineResolution
SplineResolution()Retrieve the number of evaluated points that will be generated for every control point on curves
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.resolution |
IntegerSocket |
Resolution |
String
String(string='')Provide a string value that can be connected to other nodes in the tree
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
string |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.string |
StringSocket |
String |
UVTangent
UVTangent(method='Exact', uv=None)Generate tangent directions based on a UV map
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| method | InputMenu | Literal['Exact', 'Fast'] | Method | 'Exact' |
| uv | InputVector | UV | None |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.method |
MenuSocket |
Method |
i.uv |
VectorSocket |
UV |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.tangent |
VectorSocket |
Tangent |
Vector
Vector(vector=(0.0, 0.0, 0.0), vector_dimensions=3)Provide a vector value that can be connected to other nodes in the tree
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
vector |
|
vector_dimensions |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.vector |
VectorSocket |
Vector |
VertexNeighbors
VertexNeighbors()Retrieve topology information relating to each vertex of a mesh
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.vertex_count |
IntegerSocket |
Vertex Count |
o.face_count |
IntegerSocket |
Face Count |
VertexOfCorner
VertexOfCorner(corner_index=0)Retrieve the vertex each face corner is attached to
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| corner_index | InputInteger | Corner Index | 0 |
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.corner_index |
IntegerSocket |
Corner Index |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.vertex_index |
IntegerSocket |
Vertex Index |
ViewportTransform
ViewportTransform()Retrieve the view direction and location of the 3D viewport
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.projection |
MatrixSocket |
Projection |
o.view |
MatrixSocket |
View |
o.is_orthographic |
BooleanSocket |
Is Orthographic |
VoxelIndex
VoxelIndex()Retrieve the integer coordinates of the voxel that the field is evaluated on
Attributes
| Name | Description |
|---|---|
i |
|
name |
The name of the node being wrapped by this instance. |
node |
|
o |
|
outputs |
|
tree |
The TreeBuilder instance this node belongs to and is being built within. |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.x |
IntegerSocket |
X |
o.y |
IntegerSocket |
Y |
o.z |
IntegerSocket |
Z |
o.is_tile |
BooleanSocket |
Is Tile |
o.extent_x |
IntegerSocket |
Extent X |
o.extent_y |
IntegerSocket |
Extent Y |
o.extent_z |
IntegerSocket |
Extent Z |