nodes.geometry.zone

zone

Classes

Name Description
BaseRepeatZone
BaseSimulationZone
BaseZone
BaseZoneInput Base class for zone input nodes
BaseZoneOutput Base class for zone output nodes
ClosureInput Closure Input node
ClosureOutput Closure Output node
ClosureZone
ForEachGeometryElementInput For Each Geometry Element Input node
ForEachGeometryElementOutput For Each Geometry Element Output node
ForEachGeometryElementZone
RepeatInput Repeat Input node
RepeatOutput Repeat Output node
RepeatZone
SimulationInput Simulation Input node
SimulationOutput Simulation Output node
SimulationZone
ZoneItem Handle for a simulation/repeat state item (four sockets per item).

BaseRepeatZone

BaseRepeatZone(node=None)

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
items The bpy item collection driving this zone’s sockets.
name The name of the node being wrapped by this instance.
node
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
outputs
tree

Methods

Name Description
add_item Add a single item and return its handle.
add_items Add an item per mapping entry and return their handles by name.
capture Add an item linked from value and return its output socket.
add_item
add_item(name, value=None, *, type=None)

Add a single item and return its handle.

value may be a linkable (linked to the item’s input) or a plain default value; otherwise type (a socket-type string such as "FLOAT") declares the item unlinked.

add_items
add_items(items)

Add an item per mapping entry and return their handles by name.

Values may be linkables (linked to the new item’s input) or socket-type strings such as "FLOAT" (declare an unlinked item).

capture
capture(value, *, name=None)

Add an item linked from value and return its output socket.

The item is auto-named after the source socket unless name is given.

BaseSimulationZone

BaseSimulationZone(node=None)

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
items The bpy item collection driving this zone’s sockets.
name The name of the node being wrapped by this instance.
node
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
outputs
tree

Methods

Name Description
add_item Add a single item and return its handle.
add_items Add an item per mapping entry and return their handles by name.
capture Add an item linked from value and return its output socket.
add_item
add_item(name, value=None, *, type=None)

Add a single item and return its handle.

value may be a linkable (linked to the item’s input) or a plain default value; otherwise type (a socket-type string such as "FLOAT") declares the item unlinked.

add_items
add_items(items)

Add an item per mapping entry and return their handles by name.

Values may be linkables (linked to the new item’s input) or socket-type strings such as "FLOAT" (declare an unlinked item).

capture
capture(value, *, name=None)

Add an item linked from value and return its output socket.

The item is auto-named after the source socket unless name is given.

BaseZone

BaseZone(node=None)

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
items The bpy item collection driving this zone’s sockets.
name The name of the node being wrapped by this instance.
node
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
outputs
tree

Methods

Name Description
add_item Add a single item and return its handle.
add_items Add an item per mapping entry and return their handles by name.
capture Add an item linked from value and return its output socket.
add_item
add_item(name, value=None, *, type=None)

Add a single item and return its handle.

value may be a linkable (linked to the item’s input) or a plain default value; otherwise type (a socket-type string such as "FLOAT") declares the item unlinked.

add_items
add_items(items)

Add an item per mapping entry and return their handles by name.

Values may be linkables (linked to the new item’s input) or socket-type strings such as "FLOAT" (declare an unlinked item).

capture
capture(value, *, name=None)

Add an item linked from value and return its output socket.

The item is auto-named after the source socket unless name is given.

BaseZoneInput

BaseZoneInput(node=None)

Base class for zone input nodes

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
items The bpy item collection driving this zone’s sockets.
name The name of the node being wrapped by this instance.
node
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
output
outputs
tree

Methods

Name Description
add_item Add a single item and return its handle.
add_items Add an item per mapping entry and return their handles by name.
capture Add an item linked from value and return its output socket.
add_item
add_item(name, value=None, *, type=None)

Add a single item and return its handle.

value may be a linkable (linked to the item’s input) or a plain default value; otherwise type (a socket-type string such as "FLOAT") declares the item unlinked.

add_items
add_items(items)

Add an item per mapping entry and return their handles by name.

Values may be linkables (linked to the new item’s input) or socket-type strings such as "FLOAT" (declare an unlinked item).

capture
capture(value, *, name=None)

Add an item linked from value and return its output socket.

The item is auto-named after the source socket unless name is given.

BaseZoneOutput

BaseZoneOutput(node=None)

Base class for zone output nodes

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
items The bpy item collection driving this zone’s sockets.
name The name of the node being wrapped by this instance.
node
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
outputs
tree

Methods

Name Description
add_item Add a single item and return its handle.
add_items Add an item per mapping entry and return their handles by name.
capture Add an item linked from value and return its output socket.
add_item
add_item(name, value=None, *, type=None)

Add a single item and return its handle.

value may be a linkable (linked to the item’s input) or a plain default value; otherwise type (a socket-type string such as "FLOAT") declares the item unlinked.

add_items
add_items(items)

Add an item per mapping entry and return their handles by name.

Values may be linkables (linked to the new item’s input) or socket-type strings such as "FLOAT" (declare an unlinked item).

capture
capture(value, *, name=None)

Add an item linked from value and return its output socket.

The item is auto-named after the source socket unless name is given.

ClosureInput

ClosureInput()

Closure Input node

Attributes

Name Description
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Methods

Name Description
link

ClosureOutput

ClosureOutput(define_signature=False)

Closure Output node

Attributes

Name Description
define_signature
i
name The name of the node being wrapped by this instance.
node
o
outputs
tree The TreeBuilder instance this node belongs to and is being built within.

Methods

Name Description
link
sync_signature
sync_signature
sync_signature(node)

Outputs

Attribute Type Description
o.closure ClosureSocket Closure

ClosureZone

ClosureZone()

Attributes

Name Description
closure The closure produced by the zone.
input
output

Methods

Name Description
input_item Declare a closure input and return the socket to read in the body.
output_item Declare a closure output and return the target to feed with >>.
input_item
input_item(name, type='GEOMETRY')

Declare a closure input and return the socket to read in the body.

type is a socket-type string ("GEOMETRY", "MATRIX", "VECTOR", …); the item collection lives on the output node and drives the matching output socket on the input node.

output_item
output_item(name, type='GEOMETRY')

Declare a closure output and return the target to feed with >>.

ForEachGeometryElementInput

ForEachGeometryElementInput(geometry=None, selection=True)

For Each Geometry Element Input node

Attributes

Name Description
i
items The bpy item collection driving this zone’s sockets.
name The name of the node being wrapped by this instance.
node
o
output
outputs
tree

Methods

Name Description
add_item Add a single item and return its handle.
add_items Add an item per mapping entry and return their handles by name.
capture Add an item linked from value and return its output socket.
add_item
add_item(name, value=None, *, type=None)

Add a single item and return its handle.

value may be a linkable (linked to the item’s input) or a plain default value; otherwise type (a socket-type string such as "FLOAT") declares the item unlinked.

add_items
add_items(items)

Add an item per mapping entry and return their handles by name.

Values may be linkables (linked to the new item’s input) or socket-type strings such as "FLOAT" (declare an unlinked item).

capture
capture(value, *, name=None)

Add an item linked from value and return its output socket.

The item is auto-named after the source socket unless name is given.

ForEachGeometryElementOutput

ForEachGeometryElementOutput(domain='POINT', **kwargs)

For Each Geometry Element Output node

Attributes

Name Description
domain
i
items The bpy item collection driving this zone’s sockets.
items_generated
name The name of the node being wrapped by this instance.
node
o
outputs
tree

Methods

Name Description
add_generated_item Add a generation item and return its handle.
add_item Add a single item and return its handle.
add_items Add an item per mapping entry and return their handles by name.
capture Add an item linked from value and return its output socket.
capture_generated Capture value as a generated-geometry item evaluated on the
add_generated_item
add_generated_item(name, value=None, *, type=None, domain='POINT')

Add a generation item and return its handle.

value may be a linkable (linked to the item’s input) or a plain default value; otherwise type declares the item unlinked.

add_item
add_item(name, value=None, *, type=None)

Add a single item and return its handle.

value may be a linkable (linked to the item’s input) or a plain default value; otherwise type (a socket-type string such as "FLOAT") declares the item unlinked.

add_items
add_items(items)

Add an item per mapping entry and return their handles by name.

Values may be linkables (linked to the new item’s input) or socket-type strings such as "FLOAT" (declare an unlinked item).

capture
capture(value, *, name=None)

Add an item linked from value and return its output socket.

The item is auto-named after the source socket unless name is given.

capture_generated
capture_generated(value, *, name=None, domain='POINT')

Capture value as a generated-geometry item evaluated on the given domain, and return its output socket.

ForEachGeometryElementZone

ForEachGeometryElementZone(geometry=None, selection=True, *, domain='POINT')

Attributes

Name Description
generation Handle for the default generation item (the generated geometry).
index
input
output

Methods

Name Description
generated_item Declare a generation item — a value stored on the generated
item Declare an input item — a per-element field made available
main_item Declare a main item — a per-element result written back onto
generated_item
generated_item(name, value=None, *, type=None, domain='POINT')

Declare a generation item — a value stored on the generated geometry with the given domain.

item
item(name, value=None, *, type=None)

Declare an input item — a per-element field made available inside the zone.

main_item
main_item(name, value=None, *, type=None)

Declare a main item — a per-element result written back onto the input geometry.

RepeatInput

RepeatInput(iterations=1)

Repeat Input node

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
items The bpy item collection driving this zone’s sockets.
name The name of the node being wrapped by this instance.
node
o
output
outputs
tree

Methods

Name Description
add_item Add a single item and return its handle.
add_items Add an item per mapping entry and return their handles by name.
capture Add an item linked from value and return its output socket.
add_item
add_item(name, value=None, *, type=None)

Add a single item and return its handle.

value may be a linkable (linked to the item’s input) or a plain default value; otherwise type (a socket-type string such as "FLOAT") declares the item unlinked.

add_items
add_items(items)

Add an item per mapping entry and return their handles by name.

Values may be linkables (linked to the new item’s input) or socket-type strings such as "FLOAT" (declare an unlinked item).

capture
capture(value, *, name=None)

Add an item linked from value and return its output socket.

The item is auto-named after the source socket unless name is given.

RepeatOutput

RepeatOutput(node=None)

Repeat Output node

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
items The bpy item collection driving this zone’s sockets.
name The name of the node being wrapped by this instance.
node
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
outputs
tree

Methods

Name Description
add_item Add a single item and return its handle.
add_items Add an item per mapping entry and return their handles by name.
capture Add an item linked from value and return its output socket.
add_item
add_item(name, value=None, *, type=None)

Add a single item and return its handle.

value may be a linkable (linked to the item’s input) or a plain default value; otherwise type (a socket-type string such as "FLOAT") declares the item unlinked.

add_items
add_items(items)

Add an item per mapping entry and return their handles by name.

Values may be linkables (linked to the new item’s input) or socket-type strings such as "FLOAT" (declare an unlinked item).

capture
capture(value, *, name=None)

Add an item linked from value and return its output socket.

The item is auto-named after the source socket unless name is given.

RepeatZone

RepeatZone(iterations=1, items=None)

Attributes

Name Description
input
iteration The current iteration index.
output

Methods

Name Description
item Declare a state item and return its handle.
item
item(name, initial=None, *, type=None)

Declare a state item and return its handle.

initial may be a linkable (linked as the item’s starting value), a plain default value, or a socket-type string such as "FLOAT" (declares the item without linking).

SimulationInput

SimulationInput(node=None)

Simulation Input node

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
items The bpy item collection driving this zone’s sockets.
name The name of the node being wrapped by this instance.
node
o
output
outputs
tree

Methods

Name Description
add_item Add a single item and return its handle.
add_items Add an item per mapping entry and return their handles by name.
capture Add an item linked from value and return its output socket.
add_item
add_item(name, value=None, *, type=None)

Add a single item and return its handle.

value may be a linkable (linked to the item’s input) or a plain default value; otherwise type (a socket-type string such as "FLOAT") declares the item unlinked.

add_items
add_items(items)

Add an item per mapping entry and return their handles by name.

Values may be linkables (linked to the new item’s input) or socket-type strings such as "FLOAT" (declare an unlinked item).

capture
capture(value, *, name=None)

Add an item linked from value and return its output socket.

The item is auto-named after the source socket unless name is given.

SimulationOutput

SimulationOutput(node=None)

Simulation Output node

Attributes

Name Description
i
items The bpy item collection driving this zone’s sockets.
name The name of the node being wrapped by this instance.
node
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
outputs
tree

Methods

Name Description
add_item Add a single item and return its handle.
add_items Add an item per mapping entry and return their handles by name.
capture Add an item linked from value and return its output socket.
add_item
add_item(name, value=None, *, type=None)

Add a single item and return its handle.

value may be a linkable (linked to the item’s input) or a plain default value; otherwise type (a socket-type string such as "FLOAT") declares the item unlinked.

add_items
add_items(items)

Add an item per mapping entry and return their handles by name.

Values may be linkables (linked to the new item’s input) or socket-type strings such as "FLOAT" (declare an unlinked item).

capture
capture(value, *, name=None)

Add an item linked from value and return its output socket.

The item is auto-named after the source socket unless name is given.

SimulationZone

SimulationZone(items=None)

Attributes

Name Description
delta_time
input
output

Methods

Name Description
item Declare a state item and return its handle.
item
item(name, initial=None, *, type=None)

Declare a state item and return its handle.

initial may be a linkable (linked as the item’s starting value), a plain default value, or a socket-type string such as "FLOAT" (declares the item without linking).

ZoneItem

ZoneItem(input_node, output_node, item)

Handle for a simulation/repeat state item (four sockets per item).

Attributes

Name Description
current Input-node output socket — read the item inside the zone body.
initial Input-node input socket — set the item’s starting value.
input The node’s input socket for this item.
name
next Output-node input socket — write the item’s per-iteration result.
output The node’s output socket for this item.
result Output-node output socket — read the item after the zone.
socket_type