nodes.shader.color
color
Classes
| Name | Description |
|---|---|
| Brightnesscontrast | Control the brightness and contrast of the input color |
| Huesaturationvalue | Apply a color transformation in the HSV color model |
| InvertColor | Invert a color, producing a negative |
| LightFalloff | Manipulate how light intensity decreases over distance. Typically used for non-physically-based effects; in reality light always falls off quadratically |
Brightnesscontrast
Brightnesscontrast(color=None, bright=0.0, contrast=0.0)Control the brightness and contrast of the input color
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| color | InputColor | Color | None |
| bright | InputFloat | Brightness | 0.0 |
| contrast | InputFloat | Contrast | 0.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.color |
ColorSocket |
Color |
i.bright |
FloatSocket |
Brightness |
i.contrast |
FloatSocket |
Contrast |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.color |
ColorSocket |
Color |
Huesaturationvalue
Huesaturationvalue(hue=0.5, saturation=1.0, value=1.0, fac=1.0, color=None)Apply a color transformation in the HSV color model
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| hue | InputFloat | Hue | 0.5 |
| saturation | InputFloat | Saturation | 1.0 |
| value | InputFloat | Value | 1.0 |
| fac | InputFloat | Factor | 1.0 |
| color | InputColor | Color | None |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.hue |
FloatSocket |
Hue |
i.saturation |
FloatSocket |
Saturation |
i.value |
FloatSocket |
Value |
i.fac |
FloatSocket |
Factor |
i.color |
ColorSocket |
Color |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.color |
ColorSocket |
Color |
InvertColor
InvertColor(fac=1.0, color=None)Invert a color, producing a negative
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| fac | InputFloat | Factor | 1.0 |
| color | InputColor | Color | None |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.fac |
FloatSocket |
Factor |
i.color |
ColorSocket |
Color |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.color |
ColorSocket |
Color |
LightFalloff
LightFalloff(strength=100.0, smooth=0.0)Manipulate how light intensity decreases over distance. Typically used for non-physically-based effects; in reality light always falls off quadratically
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| strength | InputFloat | Strength | 100.0 |
| smooth | InputFloat | Smooth | 0.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.strength |
FloatSocket |
Strength |
i.smooth |
FloatSocket |
Smooth |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.quadratic |
FloatSocket |
Quadratic |
o.linear |
FloatSocket |
Linear |
o.constant |
FloatSocket |
Constant |