nodes.shader.converter

converter

Classes

Name Description
CombineColor Create a color from individual components using multiple models
EvaluateClosure Execute a given closure
Mix Mix values by a factor
RGBToBw Convert a color’s luminance to a grayscale value
SeparateColor Split a color into its individual components using multiple models
ShaderToRGB Convert rendering effect (such as light and shadow) to color. Typically used for non-photorealistic rendering, to apply additional effects on the output of BSDFs.
Wavelength Convert a wavelength value to an RGB value

CombineColor

CombineColor(red=0.0, green=0.0, blue=0.0, *, mode='RGB')

Create a color from individual components using multiple models

Parameters

Name Type Description Default
red InputFloat Red 0.0
green InputFloat Green 0.0
blue InputFloat Blue 0.0

Attributes

Name Description
i
inputs
mode
name
node
o
outputs
tree
type

Methods

Name Description
hsl Create Combine Color with operation ‘HSL’. Use HSL (Hue, Saturation, Lightness) color processing
hsv Create Combine Color with operation ‘HSV’. Use HSV (Hue, Saturation, Value) color processing
rgb Create Combine Color with operation ‘RGB’. Use RGB (Red, Green, Blue) color processing
hsl
hsl(red=0.0, green=0.0, blue=0.0)

Create Combine Color with operation ‘HSL’. Use HSL (Hue, Saturation, Lightness) color processing

hsv
hsv(red=0.0, green=0.0, blue=0.0)

Create Combine Color with operation ‘HSV’. Use HSV (Hue, Saturation, Value) color processing

rgb
rgb(red=0.0, green=0.0, blue=0.0)

Create Combine Color with operation ‘RGB’. Use RGB (Red, Green, Blue) color processing

Inputs

Attribute Type Description
i.red FloatSocket Red
i.green FloatSocket Green
i.blue FloatSocket Blue

Outputs

Attribute Type Description
o.color ColorSocket Color

EvaluateClosure

EvaluateClosure(
    closure=None,
    *,
    active_input_index=0,
    active_output_index=0,
    define_signature=False,
)

Execute a given closure

Parameters

Name Type Description Default
closure InputClosure Closure None

Attributes

Name Description
active_input_index
active_output_index
define_signature
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.closure ClosureSocket Closure

Mix

Mix(
    factor_float=0.5,
    factor_vector=None,
    a_float=0.0,
    b_float=0.0,
    a_vector=None,
    b_vector=None,
    a_color=None,
    b_color=None,
    a_rotation=None,
    b_rotation=None,
    *,
    data_type='FLOAT',
    factor_mode='UNIFORM',
    blend_type='MIX',
    clamp_factor=False,
    clamp_result=False,
)

Mix values by a factor

Parameters

Name Type Description Default
factor_float InputFloat Factor 0.5
factor_vector InputVector Factor None
a_float InputFloat A 0.0
b_float InputFloat B 0.0
a_vector InputVector A None
b_vector InputVector B None
a_color InputColor A None
b_color InputColor B None
a_rotation InputRotation A None
b_rotation InputRotation B None

Attributes

Name Description
blend_type
clamp_factor
clamp_result
data_type
factor_mode
i
inputs
name
node
o
outputs
tree
type

Methods

Name Description
color Create Mix with operation ‘Color’.
float Create Mix with operation ‘Float’.
vector Create Mix with operation ‘Vector’.
color
color(factor=0.5, a_color=None, b_color=None)

Create Mix with operation ‘Color’.

float
float(factor=0.5, a=0.0, b=0.0)

Create Mix with operation ‘Float’.

vector
vector(factor=0.5, a=None, b=None)

Create Mix with operation ‘Vector’.

Inputs

Attribute Type Description
i.factor_float FloatSocket Factor
i.factor_vector VectorSocket Factor
i.a_float FloatSocket A
i.b_float FloatSocket B
i.a_vector VectorSocket A
i.b_vector VectorSocket B
i.a_color ColorSocket A
i.b_color ColorSocket B
i.a_rotation RotationSocket A
i.b_rotation RotationSocket B

Outputs

Attribute Type Description
o.result_float FloatSocket Result
o.result_vector VectorSocket Result
o.result_color ColorSocket Result
o.result_rotation RotationSocket Result

RGBToBw

RGBToBw(color=None)

Convert a color’s luminance to a grayscale value

Parameters

Name Type Description Default
color InputColor Color None

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.color ColorSocket Color

Outputs

Attribute Type Description
o.val FloatSocket Val

SeparateColor

SeparateColor(color=None, *, mode='RGB')

Split a color into its individual components using multiple models

Parameters

Name Type Description Default
color InputColor Color None

Attributes

Name Description
i
inputs
mode
name
node
o
outputs
tree
type

Methods

Name Description
hsl Create Separate Color with operation ‘HSL’. Use HSL (Hue, Saturation, Lightness) color processing
hsv Create Separate Color with operation ‘HSV’. Use HSV (Hue, Saturation, Value) color processing
rgb Create Separate Color with operation ‘RGB’. Use RGB (Red, Green, Blue) color processing
hsl
hsl(color=None)

Create Separate Color with operation ‘HSL’. Use HSL (Hue, Saturation, Lightness) color processing

hsv
hsv(color=None)

Create Separate Color with operation ‘HSV’. Use HSV (Hue, Saturation, Value) color processing

rgb
rgb(color=None)

Create Separate Color with operation ‘RGB’. Use RGB (Red, Green, Blue) color processing

Inputs

Attribute Type Description
i.color ColorSocket Color

Outputs

Attribute Type Description
o.red FloatSocket Red
o.green FloatSocket Green
o.blue FloatSocket Blue

ShaderToRGB

ShaderToRGB(shader=None)
Convert rendering effect (such as light and shadow) to color. Typically used for non-photorealistic rendering, to apply additional effects on the output of BSDFs.

Note: only supported in EEVEE

Parameters

shader : InputShader
    Shader

Inputs

i.shader : ShaderSocket
    Shader

Outputs

o.color : ColorSocket
    Color
o.alpha : FloatSocket
    Alpha

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Wavelength

Wavelength(wavelength=500.0)

Convert a wavelength value to an RGB value

Parameters

Name Type Description Default
wavelength InputFloat Wavelength 500.0

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.wavelength FloatSocket Wavelength

Outputs

Attribute Type Description
o.color ColorSocket Color