nodes.shader.texture

texture

Classes

Name Description
EnvironmentTexture Sample an image file as an environment texture. Typically used to light the scene with the background node
IesTexture Match real world lights with IES files, which store the directional intensity distribution of light sources
ImageTexture Sample an image file as a texture
SkyTexture Generate a procedural sky texture

EnvironmentTexture

EnvironmentTexture(
    vector=None,
    *,
    projection='EQUIRECTANGULAR',
    interpolation='Linear',
)

Sample an image file as an environment texture. Typically used to light the scene with the background node

Parameters

Name Type Description Default
vector InputVector Vector None

Attributes

Name Description
i
inputs
interpolation
name
node
o
outputs
projection
tree
type

Inputs

Attribute Type Description
i.vector VectorSocket Vector

Outputs

Attribute Type Description
o.color ColorSocket Color

IesTexture

IesTexture(vector=None, strength=1.0, *, filepath='', mode='INTERNAL')

Match real world lights with IES files, which store the directional intensity distribution of light sources

Parameters

Name Type Description Default
vector InputVector Vector None
strength InputFloat Strength 1.0

Attributes

Name Description
filepath
i
inputs
mode
name
node
o
outputs
tree
type

Methods

Name Description
external Create IES Texture with operation ‘External’. Use external .ies file
internal Create IES Texture with operation ‘Internal’. Use internal text data-block
external
external(vector=None, strength=1.0)

Create IES Texture with operation ‘External’. Use external .ies file

internal
internal(vector=None, strength=1.0)

Create IES Texture with operation ‘Internal’. Use internal text data-block

Inputs

Attribute Type Description
i.vector VectorSocket Vector
i.strength FloatSocket Strength

Outputs

Attribute Type Description
o.fac FloatSocket Factor

ImageTexture

ImageTexture(
    vector=None,
    *,
    projection='FLAT',
    interpolation='Linear',
    projection_blend=0.0,
    extension='REPEAT',
)

Sample an image file as a texture

Parameters

Name Type Description Default
vector InputVector Vector None

Attributes

Name Description
extension
i
inputs
interpolation
name
node
o
outputs
projection
projection_blend
tree
type

Inputs

Attribute Type Description
i.vector VectorSocket Vector

Outputs

Attribute Type Description
o.color ColorSocket Color
o.alpha FloatSocket Alpha

SkyTexture

SkyTexture(
    vector=None,
    *,
    sky_type='MULTIPLE_SCATTERING',
    sun_disc=True,
    sun_size=0.01,
    sun_intensity=1.0,
    sun_elevation=0.262,
    sun_rotation=0.0,
    altitude=100.0,
    air_density=1.0,
    aerosol_density=1.0,
    ozone_density=1.0,
    sun_direction=(0.0, 0.0, 1.0),
    turbidity=0.0,
    ground_albedo=0.0,
)

Generate a procedural sky texture

Parameters

Name Type Description Default
vector InputVector Vector None

Attributes

Name Description
aerosol_density
air_density
altitude
ground_albedo
i
inputs
name
node
o
outputs
ozone_density
sky_type
sun_direction
sun_disc
sun_elevation
sun_intensity
sun_rotation
sun_size
tree
turbidity
type

Methods

Name Description
hosek_wilkie Create Sky Texture with operation ‘Hosek / Wilkie’. Hosek / Wilkie 2012 (Legacy)
multiple_scattering Create Sky Texture with operation ‘Multiple Scattering’. Multiple scattering sky model (more accurate)
preetham Create Sky Texture with operation ‘Preetham’. Preetham 1999 (Legacy)
single_scattering Create Sky Texture with operation ‘Single Scattering’. Single scattering sky model
hosek_wilkie
hosek_wilkie(vector=None)

Create Sky Texture with operation ‘Hosek / Wilkie’. Hosek / Wilkie 2012 (Legacy)

multiple_scattering
multiple_scattering()

Create Sky Texture with operation ‘Multiple Scattering’. Multiple scattering sky model (more accurate)

preetham
preetham(vector=None)

Create Sky Texture with operation ‘Preetham’. Preetham 1999 (Legacy)

single_scattering
single_scattering()

Create Sky Texture with operation ‘Single Scattering’. Single scattering sky model

Inputs

Attribute Type Description
i.vector VectorSocket Vector

Outputs

Attribute Type Description
o.color ColorSocket Color