live.RunResult
RunResult(tree, created, namespace)What :func:run_source produced.
Attributes
| Name | Description |
|---|---|
created |
Every node group that exists after the run and did not before. |
namespace |
The globals the code ran in. |
tree |
The tree the run produced, or None if it made no tree. |