nodes.compositor.color
color
Classes
| Name | Description |
|---|---|
| AlphaOver | Overlay a foreground image onto a background image |
| Brightnesscontrast | Adjust brightness and contrast |
| ColorBalance | Adjust color and values |
| ColorCorrection | Adjust the color of an image, separately in several tonal ranges (highlights, midtones and shadows) |
| DepthCombine | Combine two images using depth maps |
| Exposure | Adjust brightness using a camera exposure parameter |
| HueCorrect | Adjust hue, saturation, and value with a curve |
| Huesaturationvalue | Apply a color transformation in the HSV color model |
| InvertColor | Invert colors, producing a negative |
| Posterize | Reduce number of colors in an image, converting smooth gradients into sharp transitions |
| RGBCurves | Perform level adjustments on each color channel of an image |
| Tonemap | Map one set of colors to another in order to approximate the appearance of high dynamic range |
AlphaOver
AlphaOver(
background=None,
foreground=None,
fac=1.0,
type='Over',
straight_alpha=False,
)Overlay a foreground image onto a background image
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| background | InputColor | Background | None |
| foreground | InputColor | Foreground | None |
| fac | InputFloat | Factor | 1.0 |
| type | InputMenu | Literal['Over', 'Disjoint Over', 'Conjoint Over'] | Type | 'Over' |
| straight_alpha | InputBoolean | Straight Alpha | False |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| conjoint_over | Create Alpha Over node with type ‘Conjoint Over’. |
| disjoint_over | Create Alpha Over node with type ‘Disjoint Over’. |
| over | Create Alpha Over node with type ‘Over’. |
conjoint_over
conjoint_over(background=None, foreground=None, fac=1.0, straight_alpha=False)Create Alpha Over node with type ‘Conjoint Over’.
disjoint_over
disjoint_over(background=None, foreground=None, fac=1.0, straight_alpha=False)Create Alpha Over node with type ‘Disjoint Over’.
over
over(background=None, foreground=None, fac=1.0, straight_alpha=False)Create Alpha Over node with type ‘Over’.
Inputs
| Attribute | Type | Description |
|---|---|---|
i.background |
ColorSocket |
Background |
i.foreground |
ColorSocket |
Foreground |
i.fac |
FloatSocket |
Factor |
i.type |
MenuSocket |
Type |
i.straight_alpha |
BooleanSocket |
Straight Alpha |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Brightnesscontrast
Brightnesscontrast(image=None, bright=0.0, contrast=0.0)Adjust brightness and contrast
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| bright | InputFloat | Brightness | 0.0 |
| contrast | InputFloat | Contrast | 0.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.bright |
FloatSocket |
Brightness |
i.contrast |
FloatSocket |
Contrast |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
ColorBalance
ColorBalance(
image=None,
fac=1.0,
type='Lift/Gamma/Gain',
base_lift=0.0,
color_lift=None,
base_gamma=1.0,
color_gamma=None,
base_gain=1.0,
color_gain=None,
base_offset=0.0,
color_offset=None,
base_power=1.0,
color_power=None,
base_slope=1.0,
color_slope=None,
input_temperature=6500.0,
input_tint=10.0,
output_temperature=6500.0,
output_tint=10.0,
*,
input_whitepoint=(0.735, 0.735, 0.735),
output_whitepoint=(0.735, 0.735, 0.735),
)Adjust color and values
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| fac | InputFloat | Factor | 1.0 |
| type | InputMenu | Literal['Lift/Gamma/Gain', 'Offset/Power/Slope (ASC-CDL)', 'White Point'] | Type | 'Lift/Gamma/Gain' |
| base_lift | InputFloat | Lift | 0.0 |
| color_lift | InputColor | Lift | None |
| base_gamma | InputFloat | Gamma | 1.0 |
| color_gamma | InputColor | Gamma | None |
| base_gain | InputFloat | Gain | 1.0 |
| color_gain | InputColor | Gain | None |
| base_offset | InputFloat | Offset | 0.0 |
| color_offset | InputColor | Offset | None |
| base_power | InputFloat | Power | 1.0 |
| color_power | InputColor | Power | None |
| base_slope | InputFloat | Slope | 1.0 |
| color_slope | InputColor | Slope | None |
| input_temperature | InputFloat | Temperature | 6500.0 |
| input_tint | InputFloat | Tint | 10.0 |
| output_temperature | InputFloat | Temperature | 6500.0 |
| output_tint | InputFloat | Tint | 10.0 |
Attributes
| Name | Description |
|---|---|
i |
|
input_whitepoint |
|
inputs |
|
name |
|
node |
|
o |
|
output_whitepoint |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| lift_gamma_gain | Create Color Balance node with type ‘Lift/Gamma/Gain’. |
| offset_power_slope_asc_cdl | Create Color Balance node with type ‘Offset/Power/Slope (ASC-CDL)’. |
| white_point | Create Color Balance node with type ‘White Point’. |
lift_gamma_gain
lift_gamma_gain(
image=None,
fac=1.0,
base_lift=0.0,
color_lift=None,
base_gamma=1.0,
color_gamma=None,
base_gain=1.0,
color_gain=None,
)Create Color Balance node with type ‘Lift/Gamma/Gain’.
offset_power_slope_asc_cdl
offset_power_slope_asc_cdl(
image=None,
fac=1.0,
base_offset=0.0,
color_offset=None,
base_power=1.0,
color_power=None,
base_slope=1.0,
color_slope=None,
)Create Color Balance node with type ‘Offset/Power/Slope (ASC-CDL)’.
white_point
white_point(
image=None,
fac=1.0,
input_temperature=6500.0,
input_tint=10.0,
output_temperature=6500.0,
output_tint=10.0,
)Create Color Balance node with type ‘White Point’.
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.fac |
FloatSocket |
Factor |
i.type |
MenuSocket |
Type |
i.base_lift |
FloatSocket |
Lift |
i.color_lift |
ColorSocket |
Lift |
i.base_gamma |
FloatSocket |
Gamma |
i.color_gamma |
ColorSocket |
Gamma |
i.base_gain |
FloatSocket |
Gain |
i.color_gain |
ColorSocket |
Gain |
i.base_offset |
FloatSocket |
Offset |
i.color_offset |
ColorSocket |
Offset |
i.base_power |
FloatSocket |
Power |
i.color_power |
ColorSocket |
Power |
i.base_slope |
FloatSocket |
Slope |
i.color_slope |
ColorSocket |
Slope |
i.input_temperature |
FloatSocket |
Temperature |
i.input_tint |
FloatSocket |
Tint |
i.output_temperature |
FloatSocket |
Temperature |
i.output_tint |
FloatSocket |
Tint |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
ColorCorrection
ColorCorrection(
image=None,
mask=1.0,
master_saturation=1.0,
master_contrast=1.0,
master_gamma=1.0,
master_gain=1.0,
master_offset=0.0,
highlights_saturation=1.0,
highlights_contrast=1.0,
highlights_gamma=1.0,
highlights_gain=1.0,
highlights_offset=0.0,
midtones_saturation=1.0,
midtones_contrast=1.0,
midtones_gamma=1.0,
midtones_gain=1.0,
midtones_offset=0.0,
shadows_saturation=1.0,
shadows_contrast=1.0,
shadows_gamma=1.0,
shadows_gain=1.0,
shadows_offset=0.0,
midtones_start=0.2,
midtones_end=0.7,
apply_on_red=True,
apply_on_green=True,
apply_on_blue=True,
)Adjust the color of an image, separately in several tonal ranges (highlights, midtones and shadows)
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| mask | InputFloat | Mask | 1.0 |
| master_saturation | InputFloat | Saturation | 1.0 |
| master_contrast | InputFloat | Contrast | 1.0 |
| master_gamma | InputFloat | Gamma | 1.0 |
| master_gain | InputFloat | Gain | 1.0 |
| master_offset | InputFloat | Offset | 0.0 |
| highlights_saturation | InputFloat | Saturation | 1.0 |
| highlights_contrast | InputFloat | Contrast | 1.0 |
| highlights_gamma | InputFloat | Gamma | 1.0 |
| highlights_gain | InputFloat | Gain | 1.0 |
| highlights_offset | InputFloat | Offset | 0.0 |
| midtones_saturation | InputFloat | Saturation | 1.0 |
| midtones_contrast | InputFloat | Contrast | 1.0 |
| midtones_gamma | InputFloat | Gamma | 1.0 |
| midtones_gain | InputFloat | Gain | 1.0 |
| midtones_offset | InputFloat | Offset | 0.0 |
| shadows_saturation | InputFloat | Saturation | 1.0 |
| shadows_contrast | InputFloat | Contrast | 1.0 |
| shadows_gamma | InputFloat | Gamma | 1.0 |
| shadows_gain | InputFloat | Gain | 1.0 |
| shadows_offset | InputFloat | Offset | 0.0 |
| midtones_start | InputFloat | Midtones Start | 0.2 |
| midtones_end | InputFloat | Midtones End | 0.7 |
| apply_on_red | InputBoolean | Red | True |
| apply_on_green | InputBoolean | Green | True |
| apply_on_blue | InputBoolean | Blue | True |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.mask |
FloatSocket |
Mask |
i.master_saturation |
FloatSocket |
Saturation |
i.master_contrast |
FloatSocket |
Contrast |
i.master_gamma |
FloatSocket |
Gamma |
i.master_gain |
FloatSocket |
Gain |
i.master_offset |
FloatSocket |
Offset |
i.highlights_saturation |
FloatSocket |
Saturation |
i.highlights_contrast |
FloatSocket |
Contrast |
i.highlights_gamma |
FloatSocket |
Gamma |
i.highlights_gain |
FloatSocket |
Gain |
i.highlights_offset |
FloatSocket |
Offset |
i.midtones_saturation |
FloatSocket |
Saturation |
i.midtones_contrast |
FloatSocket |
Contrast |
i.midtones_gamma |
FloatSocket |
Gamma |
i.midtones_gain |
FloatSocket |
Gain |
i.midtones_offset |
FloatSocket |
Offset |
i.shadows_saturation |
FloatSocket |
Saturation |
i.shadows_contrast |
FloatSocket |
Contrast |
i.shadows_gamma |
FloatSocket |
Gamma |
i.shadows_gain |
FloatSocket |
Gain |
i.shadows_offset |
FloatSocket |
Offset |
i.midtones_start |
FloatSocket |
Midtones Start |
i.midtones_end |
FloatSocket |
Midtones End |
i.apply_on_red |
BooleanSocket |
Red |
i.apply_on_green |
BooleanSocket |
Green |
i.apply_on_blue |
BooleanSocket |
Blue |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
DepthCombine
DepthCombine(
a=None,
depth_a=1.0,
b=None,
depth_b=1.0,
use_alpha=False,
anti_alias=True,
)Combine two images using depth maps
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| a | InputColor | A | None |
| depth_a | InputFloat | Depth A | 1.0 |
| b | InputColor | B | None |
| depth_b | InputFloat | Depth B | 1.0 |
| use_alpha | InputBoolean | Use Alpha | False |
| anti_alias | InputBoolean | Anti-Alias | True |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.a |
ColorSocket |
A |
i.depth_a |
FloatSocket |
Depth A |
i.b |
ColorSocket |
B |
i.depth_b |
FloatSocket |
Depth B |
i.use_alpha |
BooleanSocket |
Use Alpha |
i.anti_alias |
BooleanSocket |
Anti-Alias |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.result |
ColorSocket |
Result |
o.depth |
FloatSocket |
Depth |
Exposure
Exposure(image=None, exposure=0.0)Adjust brightness using a camera exposure parameter
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| exposure | InputFloat | Exposure | 0.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.exposure |
FloatSocket |
Exposure |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
HueCorrect
HueCorrect(image=None, fac=1.0)Adjust hue, saturation, and value with a curve
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| fac | InputFloat | Factor | 1.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.fac |
FloatSocket |
Factor |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Huesaturationvalue
Huesaturationvalue(image=None, hue=0.5, saturation=1.0, value=1.0, fac=1.0)Apply a color transformation in the HSV color model
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| hue | InputFloat | Hue | 0.5 |
| saturation | InputFloat | Saturation | 1.0 |
| value | InputFloat | Value | 1.0 |
| fac | InputFloat | Factor | 1.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.hue |
FloatSocket |
Hue |
i.saturation |
FloatSocket |
Saturation |
i.value |
FloatSocket |
Value |
i.fac |
FloatSocket |
Factor |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
InvertColor
InvertColor(color=None, fac=1.0, invert_color=True, invert_alpha=False)Invert colors, producing a negative
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| color | InputColor | Color | None |
| fac | InputFloat | Factor | 1.0 |
| invert_color | InputBoolean | Invert Color | True |
| invert_alpha | InputBoolean | Invert Alpha | False |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.color |
ColorSocket |
Color |
i.fac |
FloatSocket |
Factor |
i.invert_color |
BooleanSocket |
Invert Color |
i.invert_alpha |
BooleanSocket |
Invert Alpha |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.color |
ColorSocket |
Color |
Posterize
Posterize(image=None, steps=8.0)Reduce number of colors in an image, converting smooth gradients into sharp transitions
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| steps | InputFloat | Steps | 8.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.steps |
FloatSocket |
Steps |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
RGBCurves
RGBCurves(image=None, fac=1.0, black_level=None, white_level=None)Perform level adjustments on each color channel of an image
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| fac | InputFloat | Factor | 1.0 |
| black_level | InputColor | Black Level | None |
| white_level | InputColor | White Level | None |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.fac |
FloatSocket |
Factor |
i.black_level |
ColorSocket |
Black Level |
i.white_level |
ColorSocket |
White Level |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Tonemap
Tonemap(
image=None,
type='R/D Photoreceptor',
key=0.18,
balance=1.0,
gamma=1.0,
intensity=0.0,
contrast=0.0,
light_adaptation=0.0,
chromatic_adaptation=0.0,
)Map one set of colors to another in order to approximate the appearance of high dynamic range
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| type | InputMenu | Literal['R/D Photoreceptor', 'Rh Simple'] | Type | 'R/D Photoreceptor' |
| key | InputFloat | Key | 0.18 |
| balance | InputFloat | Balance | 1.0 |
| gamma | InputFloat | Gamma | 1.0 |
| intensity | InputFloat | Intensity | 0.0 |
| contrast | InputFloat | Contrast | 0.0 |
| light_adaptation | InputFloat | Light Adaptation | 0.0 |
| chromatic_adaptation | InputFloat | Chromatic Adaptation | 0.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| r_d_photoreceptor | Create Tonemap node with type ‘R/D Photoreceptor’. |
| rh_simple | Create Tonemap node with type ‘Rh Simple’. |
r_d_photoreceptor
r_d_photoreceptor(
image=None,
intensity=0.0,
contrast=0.0,
light_adaptation=0.0,
chromatic_adaptation=0.0,
)Create Tonemap node with type ‘R/D Photoreceptor’.
rh_simple
rh_simple(image=None, key=0.18, balance=1.0, gamma=1.0)Create Tonemap node with type ‘Rh Simple’.
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.type |
MenuSocket |
Type |
i.key |
FloatSocket |
Key |
i.balance |
FloatSocket |
Balance |
i.gamma |
FloatSocket |
Gamma |
i.intensity |
FloatSocket |
Intensity |
i.contrast |
FloatSocket |
Contrast |
i.light_adaptation |
FloatSocket |
Light Adaptation |
i.chromatic_adaptation |
FloatSocket |
Chromatic Adaptation |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |