nodes.compositor.filter
filter
Classes
| Name | Description |
|---|---|
| AntiAliasing | Smooth away jagged edges |
| BilateralBlur | Adaptively blur image, while retaining sharp edges |
| Blur | Blur an image, using several blur modes |
| BokehBlur | Generate a bokeh type blur similar to Defocus. Unlike defocus an in-focus region is defined in the compositor |
| Convolve | Convolves an image with a kernel |
| Defocus | Apply depth of field in 2D, using a Z depth map or mask |
| Denoise | Denoise renders from Cycles and other ray tracing renderers |
| Despeckle | Smooth areas of an image in which noise is noticeable, while leaving complex areas untouched |
| Dilateerode | Expand and shrink masks |
| DirectionalBlur | Blur an image along a direction |
| Filter | Apply common image enhancement filters |
| Glare | Add lens flares, fog and glows around bright parts of the image |
| Inpaint | Extend borders of an image into transparent or masked regions |
| Kuwahara | Apply smoothing filter that preserves edges, for stylized and painterly effects |
| Pixelate | Reduce detail in an image by making individual pixels more prominent, for a blocky or mosaic-like appearance |
| VectorBlur | Uses the vector speed render pass to blur the image pixels in 2D |
AntiAliasing
AntiAliasing(
image=None,
threshold=0.2,
contrast_limit=2.0,
corner_rounding=0.25,
)Smooth away jagged edges
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| threshold | InputFloat | Threshold | 0.2 |
| contrast_limit | InputFloat | Contrast Limit | 2.0 |
| corner_rounding | InputFloat | Corner Rounding | 0.25 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.threshold |
FloatSocket |
Threshold |
i.contrast_limit |
FloatSocket |
Contrast Limit |
i.corner_rounding |
FloatSocket |
Corner Rounding |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
BilateralBlur
BilateralBlur(image=None, determinator=None, size=0, threshold=0.1)Adaptively blur image, while retaining sharp edges
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| determinator | InputColor | Determinator | None |
| size | InputInteger | Size | 0 |
| threshold | InputFloat | Threshold | 0.1 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.determinator |
ColorSocket |
Determinator |
i.size |
IntegerSocket |
Size |
i.threshold |
FloatSocket |
Threshold |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Blur
Blur(
image=None,
size=None,
type='Gaussian',
extend_bounds=False,
separable=True,
)Blur an image, using several blur modes
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| size | InputVector | Size | None |
| type | InputMenu | Literal['Flat', 'Tent', 'Quadratic', 'Cubic', 'Gaussian', 'Fast Gaussian', 'Catrom', 'Mitch'] | Type | 'Gaussian' |
| extend_bounds | InputBoolean | Extend Bounds | False |
| separable | InputBoolean | Separable | True |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| catrom | Create Blur node with type ‘Catrom’. |
| cubic | Create Blur node with type ‘Cubic’. |
| fast_gaussian | Create Blur node with type ‘Fast Gaussian’. |
| flat | Create Blur node with type ‘Flat’. |
| gaussian | Create Blur node with type ‘Gaussian’. |
| mitch | Create Blur node with type ‘Mitch’. |
| quadratic | Create Blur node with type ‘Quadratic’. |
| tent | Create Blur node with type ‘Tent’. |
catrom
catrom(image=None, size=None, extend_bounds=False, separable=True)Create Blur node with type ‘Catrom’.
cubic
cubic(image=None, size=None, extend_bounds=False, separable=True)Create Blur node with type ‘Cubic’.
fast_gaussian
fast_gaussian(image=None, size=None, extend_bounds=False, separable=True)Create Blur node with type ‘Fast Gaussian’.
flat
flat(image=None, size=None, extend_bounds=False, separable=True)Create Blur node with type ‘Flat’.
gaussian
gaussian(image=None, size=None, extend_bounds=False, separable=True)Create Blur node with type ‘Gaussian’.
mitch
mitch(image=None, size=None, extend_bounds=False, separable=True)Create Blur node with type ‘Mitch’.
quadratic
quadratic(image=None, size=None, extend_bounds=False, separable=True)Create Blur node with type ‘Quadratic’.
tent
tent(image=None, size=None, extend_bounds=False, separable=True)Create Blur node with type ‘Tent’.
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.size |
VectorSocket |
Size |
i.type |
MenuSocket |
Type |
i.extend_bounds |
BooleanSocket |
Extend Bounds |
i.separable |
BooleanSocket |
Separable |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
BokehBlur
BokehBlur(image=None, bokeh=None, size=0.0, mask=1.0, extend_bounds=False)Generate a bokeh type blur similar to Defocus. Unlike defocus an in-focus region is defined in the compositor
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| bokeh | InputColor | Bokeh | None |
| size | InputFloat | Size | 0.0 |
| mask | InputFloat | Mask | 1.0 |
| extend_bounds | InputBoolean | Extend Bounds | False |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.bokeh |
ColorSocket |
Bokeh |
i.size |
FloatSocket |
Size |
i.mask |
FloatSocket |
Mask |
i.extend_bounds |
BooleanSocket |
Extend Bounds |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Convolve
Convolve(
image=None,
kernel_data_type='Float',
float_kernel=0.0,
color_kernel=None,
normalize_kernel=True,
)Convolves an image with a kernel
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| kernel_data_type | InputMenu | Literal['Float', 'Color'] | Kernel Data Type | 'Float' |
| float_kernel | InputFloat | Kernel | 0.0 |
| color_kernel | InputColor | Kernel | None |
| normalize_kernel | InputBoolean | Normalize Kernel | True |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.kernel_data_type |
MenuSocket |
Kernel Data Type |
i.float_kernel |
FloatSocket |
Kernel |
i.color_kernel |
ColorSocket |
Kernel |
i.normalize_kernel |
BooleanSocket |
Normalize Kernel |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Defocus
Defocus(
image=None,
z=1.0,
*,
bokeh='CIRCLE',
angle=0.0,
f_stop=0.0,
blur_max=0.0,
use_zbuffer=False,
z_scale=0.0,
)Apply depth of field in 2D, using a Z depth map or mask
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| z | InputFloat | Z | 1.0 |
Attributes
| Name | Description |
|---|---|
angle |
|
blur_max |
|
bokeh |
|
f_stop |
|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
|
use_zbuffer |
|
z_scale |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.z |
FloatSocket |
Z |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Denoise
Denoise(
image=None,
albedo=None,
normal=None,
hdr=True,
prefilter='Accurate',
quality='Follow Scene',
)Denoise renders from Cycles and other ray tracing renderers
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| albedo | InputColor | Albedo | None |
| normal | InputVector | Normal | None |
| hdr | InputBoolean | HDR | True |
| prefilter | InputMenu | Literal['None', 'Fast', 'Accurate'] | Prefilter | 'Accurate' |
| quality | InputMenu | Literal['Follow Scene', 'High', 'Balanced', 'Fast'] | Quality | 'Follow Scene' |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.albedo |
ColorSocket |
Albedo |
i.normal |
VectorSocket |
Normal |
i.hdr |
BooleanSocket |
HDR |
i.prefilter |
MenuSocket |
Prefilter |
i.quality |
MenuSocket |
Quality |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Despeckle
Despeckle(image=None, fac=1.0, color_threshold=0.5, neighbor_threshold=0.5)Smooth areas of an image in which noise is noticeable, while leaving complex areas untouched
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| fac | InputFloat | Factor | 1.0 |
| color_threshold | InputFloat | Color Threshold | 0.5 |
| neighbor_threshold | InputFloat | Neighbor Threshold | 0.5 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.fac |
FloatSocket |
Factor |
i.color_threshold |
FloatSocket |
Color Threshold |
i.neighbor_threshold |
FloatSocket |
Neighbor Threshold |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Dilateerode
Dilateerode(mask=0.0, size=0, type='Steps', falloff_size=0.0, falloff='Smooth')Expand and shrink masks
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| mask | InputFloat | Mask | 0.0 |
| size | InputInteger | Size | 0 |
| type | InputMenu | Literal['Steps', 'Threshold', 'Distance', 'Feather'] | Type | 'Steps' |
| falloff_size | InputFloat | Falloff Size | 0.0 |
| falloff | InputMenu | Literal['Smooth', 'Sphere', 'Root', 'Inverse Square', 'Sharp', 'Linear'] | Falloff | 'Smooth' |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| distance | Create Dilate/Erode node with type ‘Distance’. |
| feather | Create Dilate/Erode node with type ‘Feather’. |
| steps | Create Dilate/Erode node with type ‘Steps’. |
| threshold | Create Dilate/Erode node with type ‘Threshold’. |
distance
distance(mask=0.0, size=0)Create Dilate/Erode node with type ‘Distance’.
feather
feather(mask=0.0, size=0, falloff='Smooth')Create Dilate/Erode node with type ‘Feather’.
steps
steps(mask=0.0, size=0)Create Dilate/Erode node with type ‘Steps’.
threshold
threshold(mask=0.0, size=0, falloff_size=0.0)Create Dilate/Erode node with type ‘Threshold’.
Inputs
| Attribute | Type | Description |
|---|---|---|
i.mask |
FloatSocket |
Mask |
i.size |
IntegerSocket |
Size |
i.type |
MenuSocket |
Type |
i.falloff_size |
FloatSocket |
Falloff Size |
i.falloff |
MenuSocket |
Falloff |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.mask |
FloatSocket |
Mask |
DirectionalBlur
DirectionalBlur(
image=None,
samples=1,
center=None,
rotation=0.0,
scale=1.0,
translation_amount=0.0,
translation_direction=0.0,
)Blur an image along a direction
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| samples | InputInteger | Samples | 1 |
| center | InputVector | Center | None |
| rotation | InputFloat | Rotation | 0.0 |
| scale | InputFloat | Scale | 1.0 |
| translation_amount | InputFloat | Amount | 0.0 |
| translation_direction | InputFloat | Direction | 0.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.samples |
IntegerSocket |
Samples |
i.center |
VectorSocket |
Center |
i.rotation |
FloatSocket |
Rotation |
i.scale |
FloatSocket |
Scale |
i.translation_amount |
FloatSocket |
Amount |
i.translation_direction |
FloatSocket |
Direction |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Filter
Filter(image=None, fac=1.0, type='Soften')Apply common image enhancement filters
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| fac | InputFloat | Factor | 1.0 |
| type | InputMenu | Literal['Soften', 'Box Sharpen', 'Diamond Sharpen', 'Laplace', 'Sobel', 'Prewitt', 'Kirsch', 'Shadow'] | Type | 'Soften' |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| box_sharpen | Create Filter node with type ‘Box Sharpen’. |
| diamond_sharpen | Create Filter node with type ‘Diamond Sharpen’. |
| kirsch | Create Filter node with type ‘Kirsch’. |
| laplace | Create Filter node with type ‘Laplace’. |
| prewitt | Create Filter node with type ‘Prewitt’. |
| shadow | Create Filter node with type ‘Shadow’. |
| sobel | Create Filter node with type ‘Sobel’. |
| soften | Create Filter node with type ‘Soften’. |
box_sharpen
box_sharpen(image=None, fac=1.0)Create Filter node with type ‘Box Sharpen’.
diamond_sharpen
diamond_sharpen(image=None, fac=1.0)Create Filter node with type ‘Diamond Sharpen’.
kirsch
kirsch(image=None, fac=1.0)Create Filter node with type ‘Kirsch’.
laplace
laplace(image=None, fac=1.0)Create Filter node with type ‘Laplace’.
prewitt
prewitt(image=None, fac=1.0)Create Filter node with type ‘Prewitt’.
shadow
shadow(image=None, fac=1.0)Create Filter node with type ‘Shadow’.
sobel
sobel(image=None, fac=1.0)Create Filter node with type ‘Sobel’.
soften
soften(image=None, fac=1.0)Create Filter node with type ‘Soften’.
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.fac |
FloatSocket |
Factor |
i.type |
MenuSocket |
Type |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Glare
Glare(
image=None,
type='Streaks',
quality='Medium',
highlights_threshold=1.0,
highlights_smoothness=0.1,
clamp_highlights=False,
maximum_highlights=10.0,
strength=1.0,
saturation=1.0,
tint=None,
size=0.5,
streaks=4,
streaks_angle=0.0,
iterations=3,
fade=0.9,
color_modulation=0.25,
diagonal_star=True,
sun_position=None,
jitter=0.0,
kernel_data_type='Float',
float_kernel=0.0,
color_kernel=None,
)Add lens flares, fog and glows around bright parts of the image
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| type | InputMenu | Literal['Bloom', 'Ghosts', 'Streaks', 'Fog Glow', 'Simple Star', 'Sun Beams', 'Kernel'] | Type | 'Streaks' |
| quality | InputMenu | Literal['High', 'Medium', 'Low'] | Quality | 'Medium' |
| highlights_threshold | InputFloat | Threshold | 1.0 |
| highlights_smoothness | InputFloat | Smoothness | 0.1 |
| clamp_highlights | InputBoolean | Clamp | False |
| maximum_highlights | InputFloat | Maximum | 10.0 |
| strength | InputFloat | Strength | 1.0 |
| saturation | InputFloat | Saturation | 1.0 |
| tint | InputColor | Tint | None |
| size | InputFloat | Size | 0.5 |
| streaks | InputInteger | Streaks | 4 |
| streaks_angle | InputFloat | Streaks Angle | 0.0 |
| iterations | InputInteger | Iterations | 3 |
| fade | InputFloat | Fade | 0.9 |
| color_modulation | InputFloat | Color Modulation | 0.25 |
| diagonal_star | InputBoolean | Diagonal | True |
| sun_position | InputVector | Sun Position | None |
| jitter | InputFloat | Jitter | 0.0 |
| kernel_data_type | InputMenu | Literal['Float', 'Color'] | Kernel Data Type | 'Float' |
| float_kernel | InputFloat | Kernel | 0.0 |
| color_kernel | InputColor | Kernel | None |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| bloom | Create Glare node with type ‘Bloom’. |
| fog_glow | Create Glare node with type ‘Fog Glow’. |
| ghosts | Create Glare node with type ‘Ghosts’. |
| kernel | Create Glare node with type ‘Kernel’. |
| simple_star | Create Glare node with type ‘Simple Star’. |
| streaks | Create Glare node with type ‘Streaks’. |
| sun_beams | Create Glare node with type ‘Sun Beams’. |
bloom
bloom(
image=None,
quality='Medium',
highlights_threshold=1.0,
highlights_smoothness=0.1,
clamp_highlights=False,
max=10.0,
strength=1.0,
saturation=1.0,
tint=None,
size=0.5,
)Create Glare node with type ‘Bloom’.
fog_glow
fog_glow(
image=None,
quality='Medium',
highlights_threshold=1.0,
highlights_smoothness=0.1,
clamp_highlights=False,
max=10.0,
strength=1.0,
saturation=1.0,
tint=None,
size=0.5,
)Create Glare node with type ‘Fog Glow’.
ghosts
ghosts(
image=None,
quality='Medium',
highlights_threshold=1.0,
highlights_smoothness=0.1,
clamp_highlights=False,
max=10.0,
strength=1.0,
saturation=1.0,
tint=None,
iterations=3,
color_modulation=0.25,
)Create Glare node with type ‘Ghosts’.
kernel
kernel(
image=None,
quality='Medium',
highlights_threshold=1.0,
highlights_smoothness=0.1,
clamp_highlights=False,
max=10.0,
strength=1.0,
saturation=1.0,
tint=None,
kernel_data_type='Float',
float_kernel=0.0,
)Create Glare node with type ‘Kernel’.
simple_star
simple_star(
image=None,
quality='Medium',
highlights_threshold=1.0,
highlights_smoothness=0.1,
clamp_highlights=False,
max=10.0,
strength=1.0,
saturation=1.0,
tint=None,
iterations=3,
fade=0.9,
diagonal_star=True,
)Create Glare node with type ‘Simple Star’.
streaks
streaks(
image=None,
quality='Medium',
highlights_threshold=1.0,
highlights_smoothness=0.1,
clamp_highlights=False,
max=10.0,
strength=1.0,
saturation=1.0,
tint=None,
streaks=4,
streaks_angle=0.0,
iterations=3,
fade=0.9,
color_modulation=0.25,
)Create Glare node with type ‘Streaks’.
sun_beams
sun_beams(
image=None,
quality='Medium',
highlights_threshold=1.0,
highlights_smoothness=0.1,
clamp_highlights=False,
max=10.0,
strength=1.0,
saturation=1.0,
tint=None,
size=0.5,
sun_position=None,
jitter=0.0,
)Create Glare node with type ‘Sun Beams’.
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.type |
MenuSocket |
Type |
i.quality |
MenuSocket |
Quality |
i.highlights_threshold |
FloatSocket |
Threshold |
i.highlights_smoothness |
FloatSocket |
Smoothness |
i.clamp_highlights |
BooleanSocket |
Clamp |
i.maximum_highlights |
FloatSocket |
Maximum |
i.strength |
FloatSocket |
Strength |
i.saturation |
FloatSocket |
Saturation |
i.tint |
ColorSocket |
Tint |
i.size |
FloatSocket |
Size |
i.streaks |
IntegerSocket |
Streaks |
i.streaks_angle |
FloatSocket |
Streaks Angle |
i.iterations |
IntegerSocket |
Iterations |
i.fade |
FloatSocket |
Fade |
i.color_modulation |
FloatSocket |
Color Modulation |
i.diagonal_star |
BooleanSocket |
Diagonal |
i.sun_position |
VectorSocket |
Sun Position |
i.jitter |
FloatSocket |
Jitter |
i.kernel_data_type |
MenuSocket |
Kernel Data Type |
i.float_kernel |
FloatSocket |
Kernel |
i.color_kernel |
ColorSocket |
Kernel |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
o.glare |
ColorSocket |
Glare |
o.highlights |
ColorSocket |
Highlights |
Inpaint
Inpaint(image=None, size=0)Extend borders of an image into transparent or masked regions
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| size | InputInteger | Size | 0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.size |
IntegerSocket |
Size |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Kuwahara
Kuwahara(
image=None,
size=6.0,
type='Anisotropic',
uniformity=4,
sharpness=1.0,
eccentricity=1.0,
high_precision=False,
)Apply smoothing filter that preserves edges, for stylized and painterly effects
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| size | InputFloat | Size | 6.0 |
| type | InputMenu | Literal['Classic', 'Anisotropic'] | Type | 'Anisotropic' |
| uniformity | InputInteger | Uniformity | 4 |
| sharpness | InputFloat | Sharpness | 1.0 |
| eccentricity | InputFloat | Eccentricity | 1.0 |
| high_precision | InputBoolean | High Precision | False |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| anisotropic | Create Kuwahara node with type ‘Anisotropic’. |
| classic | Create Kuwahara node with type ‘Classic’. |
anisotropic
anisotropic(image=None, size=6.0, uniformity=4, sharpness=1.0, eccentricity=1.0)Create Kuwahara node with type ‘Anisotropic’.
classic
classic(image=None, size=6.0, high_precision=False)Create Kuwahara node with type ‘Classic’.
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.size |
FloatSocket |
Size |
i.type |
MenuSocket |
Type |
i.uniformity |
IntegerSocket |
Uniformity |
i.sharpness |
FloatSocket |
Sharpness |
i.eccentricity |
FloatSocket |
Eccentricity |
i.high_precision |
BooleanSocket |
High Precision |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
Pixelate
Pixelate(color=None, size=1)Reduce detail in an image by making individual pixels more prominent, for a blocky or mosaic-like appearance
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| color | InputColor | Color | None |
| size | InputInteger | Size | 1 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.color |
ColorSocket |
Color |
i.size |
IntegerSocket |
Size |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.color |
ColorSocket |
Color |
VectorBlur
VectorBlur(image=None, speed=None, z=0.0, samples=32, shutter=0.5)Uses the vector speed render pass to blur the image pixels in 2D
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputColor | Image | None |
| speed | InputVector | Speed | None |
| z | InputFloat | Z | 0.0 |
| samples | InputInteger | Samples | 32 |
| shutter | InputFloat | Shutter | 0.5 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ColorSocket |
Image |
i.speed |
VectorSocket |
Speed |
i.z |
FloatSocket |
Z |
i.samples |
IntegerSocket |
Samples |
i.shutter |
FloatSocket |
Shutter |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |