nodes.compositor.input
input
Classes
| Name | Description |
|---|---|
| Color | A color picker |
| Mask | Input mask from a mask data-block, created in the image editor |
| MovieClip | Input image or movie from a movie clip data-block, typically used for motion tracking |
| Normal | Input normalized normal values to other nodes in the tree |
| RenderLayers | Input render passes from a scene render |
| SceneTime | Input the current scene time in seconds or frames |
| TimeCurve | Generate a factor value (from 0.0 to 1.0) between scene start and end time, using a curve mapping |
| TrackPosition | Provide information about motion tracking points, such as x and y values |
Color
Color()A color picker
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.color |
ColorSocket |
Color |
Mask
Mask(
size_source='Scene Size',
size_x=256,
size_y=256,
feather=True,
motion_blur=False,
motion_blur_samples=16,
motion_blur_shutter=0.5,
)Input mask from a mask data-block, created in the image editor
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| size_source | InputMenu | Literal['Scene Size', 'Fixed', 'Fixed/Scene'] | Size Source | 'Scene Size' |
| size_x | InputInteger | Size X | 256 |
| size_y | InputInteger | Size Y | 256 |
| feather | InputBoolean | Feather | True |
| motion_blur | InputBoolean | Motion Blur | False |
| motion_blur_samples | InputInteger | Samples | 16 |
| motion_blur_shutter | InputFloat | Shutter | 0.5 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.size_source |
MenuSocket |
Size Source |
i.size_x |
IntegerSocket |
Size X |
i.size_y |
IntegerSocket |
Size Y |
i.feather |
BooleanSocket |
Feather |
i.motion_blur |
BooleanSocket |
Motion Blur |
i.motion_blur_samples |
IntegerSocket |
Samples |
i.motion_blur_shutter |
FloatSocket |
Shutter |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.mask |
FloatSocket |
Mask |
MovieClip
MovieClip()Input image or movie from a movie clip data-block, typically used for motion tracking
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
o.alpha |
FloatSocket |
Alpha |
o.offset_x |
FloatSocket |
Offset X |
o.offset_y |
FloatSocket |
Offset Y |
o.scale |
FloatSocket |
Scale |
o.angle |
FloatSocket |
Angle |
Normal
Normal()Input normalized normal values to other nodes in the tree
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.normal |
VectorSocket |
Normal |
RenderLayers
RenderLayers(layer='ViewLayer')Input render passes from a scene render
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
layer |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.image |
ColorSocket |
Image |
o.alpha |
FloatSocket |
Alpha |
o.depth |
FloatSocket |
Depth |
o.normal |
VectorSocket |
Normal |
o.uv |
VectorSocket |
UV |
o.vector |
VectorSocket |
Vector |
o.position |
VectorSocket |
Position |
o.deprecated |
ColorSocket |
Deprecated |
o.deprecated_001 |
ColorSocket |
Deprecated |
o.shadow |
ColorSocket |
Shadow |
o.ambient_occlusion |
ColorSocket |
Ambient Occlusion |
o.deprecated_002 |
ColorSocket |
Deprecated |
o.deprecated_003 |
ColorSocket |
Deprecated |
o.deprecated_004 |
ColorSocket |
Deprecated |
o.object_index |
FloatSocket |
Object Index |
o.material_index |
FloatSocket |
Material Index |
o.mist |
FloatSocket |
Mist |
o.emission |
ColorSocket |
Emission |
o.environment |
ColorSocket |
Environment |
o.diffuse_direct |
ColorSocket |
Diffuse Direct |
o.diffuse_indirect |
ColorSocket |
Diffuse Indirect |
o.diffuse_color |
ColorSocket |
Diffuse Color |
o.glossy_direct |
ColorSocket |
Glossy Direct |
o.glossy_indirect |
ColorSocket |
Glossy Indirect |
o.glossy_color |
ColorSocket |
Glossy Color |
o.transmission_direct |
ColorSocket |
Transmission Direct |
o.transmission_indirect |
ColorSocket |
Transmission Indirect |
o.transmission_color |
ColorSocket |
Transmission Color |
o.subsurface_direct |
ColorSocket |
Subsurface Direct |
o.subsurface_indirect |
ColorSocket |
Subsurface Indirect |
o.subsurface_color |
ColorSocket |
Subsurface Color |
SceneTime
SceneTime()Input the current scene time in seconds or frames
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.seconds |
FloatSocket |
Seconds |
o.frame |
FloatSocket |
Frame |
TimeCurve
TimeCurve(start_frame=1, end_frame=250)Generate a factor value (from 0.0 to 1.0) between scene start and end time, using a curve mapping
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| start_frame | InputInteger | Start Frame | 1 |
| end_frame | InputInteger | End Frame | 250 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.start_frame |
IntegerSocket |
Start Frame |
i.end_frame |
IntegerSocket |
End Frame |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.fac |
FloatSocket |
Factor |
TrackPosition
TrackPosition(mode='Absolute', frame=0, *, tracking_object='', track_name='')Provide information about motion tracking points, such as x and y values
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| mode | InputMenu | Literal['Absolute', 'Relative Start', 'Relative Frame', 'Absolute Frame'] | Mode | 'Absolute' |
| frame | InputInteger | Frame | 0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
track_name |
|
tracking_object |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.mode |
MenuSocket |
Mode |
i.frame |
IntegerSocket |
Frame |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.x |
FloatSocket |
X |
o.y |
FloatSocket |
Y |
o.speed |
VectorSocket |
Speed |