nodes.compositor.interface
interface
Classes
| Name | Description |
|---|---|
| EnableOutput | Either pass through the input value or output the fallback value |
EnableOutput
EnableOutput(enable=False, value=0.0, *, data_type='FLOAT')Either pass through the input value or output the fallback value
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| enable | InputBoolean | Enable | False |
| value | InputFloat | Value | 0.0 |
Attributes
| Name | Description |
|---|---|
data_type |
|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| boolean | Create Enable Output with operation ‘Boolean’. |
| color | Create Enable Output with operation ‘Color’. |
| float | Create Enable Output with operation ‘Float’. |
| integer | Create Enable Output with operation ‘Integer’. |
| menu | Create Enable Output with operation ‘Menu’. |
| string | Create Enable Output with operation ‘String’. |
| vector | Create Enable Output with operation ‘Vector’. |
boolean
boolean(enable=False, value=False)Create Enable Output with operation ‘Boolean’.
color
color(enable=False, value=None)Create Enable Output with operation ‘Color’.
float
float(enable=False, value=0.0)Create Enable Output with operation ‘Float’.
integer
integer(enable=False, value=0)Create Enable Output with operation ‘Integer’.
string
string(enable=False, value='')Create Enable Output with operation ‘String’.
vector
vector(enable=False, value=None)Create Enable Output with operation ‘Vector’.
Inputs
| Attribute | Type | Description |
|---|---|---|
i.enable |
BooleanSocket |
Enable |
i.value |
FloatSocket |
Value |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.value |
FloatSocket |
Value |