nodes.compositor.manual

manual

Classes

Name Description
MenuSwitch Node builder for the Menu Switch node (Compositor tree)

MenuSwitch

MenuSwitch(menu=None, items={}, *, data_type='FLOAT')

Node builder for the Menu Switch node (Compositor tree)

Attributes

Name Description
data_type Input socket: Data Type
i
name
node
o
outputs
tree
type

Methods

Name Description
boolean
color
float
integer
is_selected Gets the boolean output socket that is True when the named menu item is selected.
menu
string
vector
boolean
boolean(menu=None, items={})
color
color(menu=None, items={})
float
float(menu=None, items={})
integer
integer(menu=None, items={})
is_selected
is_selected(name)

Gets the boolean output socket that is True when the named menu item is selected.

Cannot be used with the “Output” name as this refers to the output socket itself.

Parameters
Name Type Description Default
name str The name of the menu item to get the selected socket for. required
Returns
Name Type Description
BooleanSocket The boolean output socket that is True when the named menu item is selected.
menu
menu(menu=None, items={})
string
string(menu=None, items={})
vector
vector(menu=None, items={})

Functions

Name Description
tree

tree

tree(
    name='Compositor Nodes',
    *,
    collapse=False,
    arrange='sugiyama',
    fake_user=False,
)