nodes.compositor.vector
vector
Classes
| Name | Description |
|---|---|
| Normalize | Map values to 0 to 1 range, based on the minimum and maximum pixel values |
Normalize
Normalize(value=1.0)Map values to 0 to 1 range, based on the minimum and maximum pixel values
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| value | InputFloat | Value | 1.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.value |
FloatSocket |
Value |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.value |
FloatSocket |
Value |