nodes.geometry.attribute

attribute

Classes

Name Description
BlurAttribute Mix attribute values of neighboring elements
DomainSize Retrieve the number of elements in a geometry for each attribute domain
RemoveNamedAttribute Delete an attribute with a specified name from a geometry. Typically used to optimize performance

BlurAttribute

BlurAttribute(value=0.0, iterations=1, weight=1.0, *, data_type='FLOAT')

Mix attribute values of neighboring elements

Parameters

Name Type Description Default
value InputFloat Value 0.0
iterations InputInteger Iterations 1
weight InputFloat Weight 1.0

Attributes

Name Description
data_type
i
name
node
o
outputs
tree
type

Methods

Name Description
color Create Blur Attribute with operation ‘Color’. RGBA color with 32-bit floating-point values
float Create Blur Attribute with operation ‘Float’. Floating-point value
integer Create Blur Attribute with operation ‘Integer’. 32-bit integer
vector Create Blur Attribute with operation ‘Vector’. 3D vector with floating-point values
color
color(value=None, iterations=1, weight=1.0)

Create Blur Attribute with operation ‘Color’. RGBA color with 32-bit floating-point values

float
float(value=0.0, iterations=1, weight=1.0)

Create Blur Attribute with operation ‘Float’. Floating-point value

integer
integer(value=0, iterations=1, weight=1.0)

Create Blur Attribute with operation ‘Integer’. 32-bit integer

vector
vector(value=None, iterations=1, weight=1.0)

Create Blur Attribute with operation ‘Vector’. 3D vector with floating-point values

Inputs

Attribute Type Description
i.value FloatSocket Value
i.iterations IntegerSocket Iterations
i.weight FloatSocket Weight

Outputs

Attribute Type Description
o.value FloatSocket Value

DomainSize

DomainSize(geometry=None, *, component='MESH')

Retrieve the number of elements in a geometry for each attribute domain

Parameters

Name Type Description Default
geometry InputGeometry Geometry None

Attributes

Name Description
component
i
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.geometry GeometrySocket Geometry

Outputs

Attribute Type Description
o.point_count IntegerSocket Point Count
o.edge_count IntegerSocket Edge Count
o.face_count IntegerSocket Face Count
o.face_corner_count IntegerSocket Face Corner Count
o.spline_count IntegerSocket Spline Count
o.instance_count IntegerSocket Instance Count
o.layer_count IntegerSocket Layer Count

RemoveNamedAttribute

RemoveNamedAttribute(geometry=None, pattern_mode='Exact', name='')

Delete an attribute with a specified name from a geometry. Typically used to optimize performance

Parameters

Name Type Description Default
geometry InputGeometry Geometry None
pattern_mode InputMenu | Literal['Exact', 'Wildcard'] Pattern Mode 'Exact'
name InputString Name ''

Attributes

Name Description
i
name
node
o
outputs
tree
type

Inputs

Attribute Type Description
i.geometry GeometrySocket Geometry
i.pattern_mode MenuSocket Pattern Mode
i.name StringSocket Name

Outputs

Attribute Type Description
o.geometry GeometrySocket Geometry