nodes.geometry.attribute
attribute
Classes
| Name | Description |
|---|---|
| BlurAttribute | Mix attribute values of neighboring elements |
| DomainSize | Retrieve the number of elements in a geometry for each attribute domain |
| RemoveNamedAttribute | Delete an attribute with a specified name from a geometry. Typically used to optimize performance |
| StoreNamedAttribute | Store the result of a field on a geometry as an attribute with the specified name |
BlurAttribute
BlurAttribute(value=0.0, iterations=1, weight=1.0, *, data_type='FLOAT')Mix attribute values of neighboring elements
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| value | InputFloat | Value | 0.0 |
| iterations | InputInteger | Iterations | 1 |
| weight | InputFloat | Weight | 1.0 |
Attributes
| Name | Description |
|---|---|
data_type |
|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| color | Create Blur Attribute with operation ‘Color’. RGBA color with 32-bit floating-point values |
| float | Create Blur Attribute with operation ‘Float’. Floating-point value |
| integer | Create Blur Attribute with operation ‘Integer’. 32-bit integer |
| vector | Create Blur Attribute with operation ‘Vector’. 3D vector with floating-point values |
color
color(value=None, iterations=1, weight=1.0)Create Blur Attribute with operation ‘Color’. RGBA color with 32-bit floating-point values
float
float(value=0.0, iterations=1, weight=1.0)Create Blur Attribute with operation ‘Float’. Floating-point value
integer
integer(value=0, iterations=1, weight=1.0)Create Blur Attribute with operation ‘Integer’. 32-bit integer
vector
vector(value=None, iterations=1, weight=1.0)Create Blur Attribute with operation ‘Vector’. 3D vector with floating-point values
Inputs
| Attribute | Type | Description |
|---|---|---|
i.value |
FloatSocket |
Value |
i.iterations |
IntegerSocket |
Iterations |
i.weight |
FloatSocket |
Weight |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.value |
FloatSocket |
Value |
DomainSize
DomainSize(geometry=None, *, component='MESH')Retrieve the number of elements in a geometry for each attribute domain
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| geometry | InputGeometry | Geometry | None |
Attributes
| Name | Description |
|---|---|
component |
|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.geometry |
GeometrySocket |
Geometry |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.point_count |
IntegerSocket |
Point Count |
o.edge_count |
IntegerSocket |
Edge Count |
o.face_count |
IntegerSocket |
Face Count |
o.face_corner_count |
IntegerSocket |
Face Corner Count |
o.spline_count |
IntegerSocket |
Spline Count |
o.instance_count |
IntegerSocket |
Instance Count |
o.layer_count |
IntegerSocket |
Layer Count |
RemoveNamedAttribute
RemoveNamedAttribute(geometry=None, pattern_mode='Exact', name='')Delete an attribute with a specified name from a geometry. Typically used to optimize performance
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| geometry | InputGeometry | Geometry | None |
| pattern_mode | InputMenu | Literal['Exact', 'Wildcard'] | Pattern Mode | 'Exact' |
| name | InputString | Name | '' |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.geometry |
GeometrySocket |
Geometry |
i.pattern_mode |
MenuSocket |
Pattern Mode |
i.name |
StringSocket |
Name |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.geometry |
GeometrySocket |
Geometry |
StoreNamedAttribute
StoreNamedAttribute(
geometry=None,
selection=True,
name='',
value=0.0,
*,
data_type='FLOAT',
domain='POINT',
)Store the result of a field on a geometry as an attribute with the specified name
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| geometry | InputGeometry | Geometry | None |
| selection | InputBoolean | Selection | True |
| name | InputString | Name | '' |
| value | InputFloat | Value | 0.0 |
Attributes
| Name | Description |
|---|---|
data_type |
|
domain |
|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| boolean | Create Store Named Attribute with operation ‘Boolean’. True or false |
| byte_color | Create Store Named Attribute with operation ‘Byte Color’. RGBA color with 8-bit positive integer values |
| color | Create Store Named Attribute with operation ‘Color’. RGBA color with 32-bit floating-point values |
| edge | Create Store Named Attribute with operation ‘Edge’. Attribute on mesh edge |
| face | Create Store Named Attribute with operation ‘Face’. Attribute on mesh faces |
| face_corner | Create Store Named Attribute with operation ‘Face Corner’. Attribute on mesh face corner |
| float | Create Store Named Attribute with operation ‘Float’. Floating-point value |
| input_2d_vector | Create Store Named Attribute with operation ‘2D Vector’. 2D vector with floating-point values |
| input_4x4_matrix | Create Store Named Attribute with operation ‘4x4 Matrix’. Floating point matrix |
| input_8_bit_integer | Create Store Named Attribute with operation ‘8-Bit Integer’. Smaller integer with a range from -128 to 127 |
| instance | Create Store Named Attribute with operation ‘Instance’. Attribute on instance |
| integer | Create Store Named Attribute with operation ‘Integer’. 32-bit integer |
| layer | Create Store Named Attribute with operation ‘Layer’. Attribute on Grease Pencil layer |
| point | Create Store Named Attribute with operation ‘Point’. Attribute on point |
| quaternion | Create Store Named Attribute with operation ‘Quaternion’. Floating point quaternion rotation |
| spline | Create Store Named Attribute with operation ‘Spline’. Attribute on spline |
| vector | Create Store Named Attribute with operation ‘Vector’. 3D vector with floating-point values |
boolean
boolean(geometry=None, selection=True, name='', value=False)Create Store Named Attribute with operation ‘Boolean’. True or false
byte_color
byte_color(geometry=None, selection=True, name='', value=None)Create Store Named Attribute with operation ‘Byte Color’. RGBA color with 8-bit positive integer values
color
color(geometry=None, selection=True, name='', value=None)Create Store Named Attribute with operation ‘Color’. RGBA color with 32-bit floating-point values
edge
edge(geometry=None, selection=True, name='', value=0.0)Create Store Named Attribute with operation ‘Edge’. Attribute on mesh edge
face
face(geometry=None, selection=True, name='', value=0.0)Create Store Named Attribute with operation ‘Face’. Attribute on mesh faces
face_corner
face_corner(geometry=None, selection=True, name='', value=0.0)Create Store Named Attribute with operation ‘Face Corner’. Attribute on mesh face corner
float
float(geometry=None, selection=True, name='', value=0.0)Create Store Named Attribute with operation ‘Float’. Floating-point value
input_2d_vector
input_2d_vector(geometry=None, selection=True, name='', value=None)Create Store Named Attribute with operation ‘2D Vector’. 2D vector with floating-point values
input_4x4_matrix
input_4x4_matrix(geometry=None, selection=True, name='', value=None)Create Store Named Attribute with operation ‘4x4 Matrix’. Floating point matrix
input_8_bit_integer
input_8_bit_integer(geometry=None, selection=True, name='', value=0)Create Store Named Attribute with operation ‘8-Bit Integer’. Smaller integer with a range from -128 to 127
instance
instance(geometry=None, selection=True, name='', value=0.0)Create Store Named Attribute with operation ‘Instance’. Attribute on instance
integer
integer(geometry=None, selection=True, name='', value=0)Create Store Named Attribute with operation ‘Integer’. 32-bit integer
layer
layer(geometry=None, selection=True, name='', value=0.0)Create Store Named Attribute with operation ‘Layer’. Attribute on Grease Pencil layer
point
point(geometry=None, selection=True, name='', value=0.0)Create Store Named Attribute with operation ‘Point’. Attribute on point
quaternion
quaternion(geometry=None, selection=True, name='', value=None)Create Store Named Attribute with operation ‘Quaternion’. Floating point quaternion rotation
spline
spline(geometry=None, selection=True, name='', value=0.0)Create Store Named Attribute with operation ‘Spline’. Attribute on spline
vector
vector(geometry=None, selection=True, name='', value=None)Create Store Named Attribute with operation ‘Vector’. 3D vector with floating-point values
Inputs
| Attribute | Type | Description |
|---|---|---|
i.geometry |
GeometrySocket |
Geometry |
i.selection |
BooleanSocket |
Selection |
i.name |
StringSocket |
Name |
i.value |
FloatSocket |
Value |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.geometry |
GeometrySocket |
Geometry |