nodes.geometry.attribute

nodes.geometry.attribute

Classes

Name Description
BlurAttribute Mix attribute values of neighboring elements
DomainSize Retrieve the number of elements in a geometry for each attribute domain
RemoveNamedAttribute Delete an attribute with a specified name from a geometry. Typically used to optimize performance
StoreNamedAttribute Store the result of a field on a geometry as an attribute with the specified name

BlurAttribute

nodes.geometry.attribute.BlurAttribute(
    value=0.0,
    iterations=1,
    weight=1.0,
    *,
    data_type='FLOAT',
)

Mix attribute values of neighboring elements

Attributes

Name Description
data_type
i_iterations Input socket: Iterations
i_value Input socket: Value
i_weight Input socket: Weight
name
node
o_value Output socket: Value
tree
type

Methods

Name Description
color Create Blur Attribute with operation ‘Color’.
float Create Blur Attribute with operation ‘Float’.
integer Create Blur Attribute with operation ‘Integer’.
vector Create Blur Attribute with operation ‘Vector’.
color
nodes.geometry.attribute.BlurAttribute.color(
    value=None,
    iterations=1,
    weight=1.0,
)

Create Blur Attribute with operation ‘Color’.

float
nodes.geometry.attribute.BlurAttribute.float(
    value=0.0,
    iterations=1,
    weight=1.0,
)

Create Blur Attribute with operation ‘Float’.

integer
nodes.geometry.attribute.BlurAttribute.integer(
    value=0,
    iterations=1,
    weight=1.0,
)

Create Blur Attribute with operation ‘Integer’.

vector
nodes.geometry.attribute.BlurAttribute.vector(
    value=None,
    iterations=1,
    weight=1.0,
)

Create Blur Attribute with operation ‘Vector’.

DomainSize

nodes.geometry.attribute.DomainSize(geometry=None, *, component='MESH')

Retrieve the number of elements in a geometry for each attribute domain

Attributes

Name Description
component
i_geometry Input socket: Geometry
name
node
o_edge_count Output socket: Edge Count
o_face_corner_count Output socket: Face Corner Count
o_face_count Output socket: Face Count
o_instance_count Output socket: Instance Count
o_layer_count Output socket: Layer Count
o_point_count Output socket: Point Count
o_spline_count Output socket: Spline Count
tree
type

RemoveNamedAttribute

nodes.geometry.attribute.RemoveNamedAttribute(
    geometry=None,
    pattern_mode='Exact',
    name='',
)

Delete an attribute with a specified name from a geometry. Typically used to optimize performance

Attributes

Name Description
i_geometry Input socket: Geometry
i_name Input socket: Name
i_pattern_mode Input socket: Pattern Mode
name
node
o_geometry Output socket: Geometry
tree
type

StoreNamedAttribute

nodes.geometry.attribute.StoreNamedAttribute(
    geometry=None,
    selection=True,
    name='',
    value=0.0,
    *,
    data_type='FLOAT',
    domain='POINT',
)

Store the result of a field on a geometry as an attribute with the specified name

Attributes

Name Description
data_type
domain
i_geometry Input socket: Geometry
i_name Input socket: Name
i_selection Input socket: Selection
i_value Input socket: Value
name
node
o_geometry Output socket: Geometry
tree
type

Methods

Name Description
boolean Create Store Named Attribute with operation ‘Boolean’.
byte_color Create Store Named Attribute with operation ‘Byte Color’.
color Create Store Named Attribute with operation ‘Color’.
edge Create Store Named Attribute with operation ‘Edge’.
face Create Store Named Attribute with operation ‘Face’.
face_corner Create Store Named Attribute with operation ‘Face Corner’.
float Create Store Named Attribute with operation ‘Float’.
instance Create Store Named Attribute with operation ‘Instance’.
int8 Create Store Named Attribute with operation ‘8-Bit Integer’.
integer Create Store Named Attribute with operation ‘Integer’.
layer Create Store Named Attribute with operation ‘Layer’.
matrix Create Store Named Attribute with operation ‘4x4 Matrix’.
point Create Store Named Attribute with operation ‘Point’.
quaternion Create Store Named Attribute with operation ‘Quaternion’.
spline Create Store Named Attribute with operation ‘Spline’.
vector Create Store Named Attribute with operation ‘Vector’.
vector2 Create Store Named Attribute with operation ‘2D Vector’.
boolean
nodes.geometry.attribute.StoreNamedAttribute.boolean(
    geometry=None,
    selection=True,
    name='',
    value=False,
)

Create Store Named Attribute with operation ‘Boolean’.

byte_color
nodes.geometry.attribute.StoreNamedAttribute.byte_color(
    geometry=None,
    selection=True,
    name='',
    value=None,
)

Create Store Named Attribute with operation ‘Byte Color’.

color
nodes.geometry.attribute.StoreNamedAttribute.color(
    geometry=None,
    selection=True,
    name='',
    value=None,
)

Create Store Named Attribute with operation ‘Color’.

edge
nodes.geometry.attribute.StoreNamedAttribute.edge(
    geometry=None,
    selection=True,
    name='',
    value=0.0,
)

Create Store Named Attribute with operation ‘Edge’.

face
nodes.geometry.attribute.StoreNamedAttribute.face(
    geometry=None,
    selection=True,
    name='',
    value=0.0,
)

Create Store Named Attribute with operation ‘Face’.

face_corner
nodes.geometry.attribute.StoreNamedAttribute.face_corner(
    geometry=None,
    selection=True,
    name='',
    value=0.0,
)

Create Store Named Attribute with operation ‘Face Corner’.

float
nodes.geometry.attribute.StoreNamedAttribute.float(
    geometry=None,
    selection=True,
    name='',
    value=0.0,
)

Create Store Named Attribute with operation ‘Float’.

instance
nodes.geometry.attribute.StoreNamedAttribute.instance(
    geometry=None,
    selection=True,
    name='',
    value=0.0,
)

Create Store Named Attribute with operation ‘Instance’.

int8
nodes.geometry.attribute.StoreNamedAttribute.int8(
    geometry=None,
    selection=True,
    name='',
    value=0,
)

Create Store Named Attribute with operation ‘8-Bit Integer’.

integer
nodes.geometry.attribute.StoreNamedAttribute.integer(
    geometry=None,
    selection=True,
    name='',
    value=0,
)

Create Store Named Attribute with operation ‘Integer’.

layer
nodes.geometry.attribute.StoreNamedAttribute.layer(
    geometry=None,
    selection=True,
    name='',
    value=0.0,
)

Create Store Named Attribute with operation ‘Layer’.

matrix
nodes.geometry.attribute.StoreNamedAttribute.matrix(
    geometry=None,
    selection=True,
    name='',
    value=None,
)

Create Store Named Attribute with operation ‘4x4 Matrix’.

point
nodes.geometry.attribute.StoreNamedAttribute.point(
    geometry=None,
    selection=True,
    name='',
    value=0.0,
)

Create Store Named Attribute with operation ‘Point’.

quaternion
nodes.geometry.attribute.StoreNamedAttribute.quaternion(
    geometry=None,
    selection=True,
    name='',
    value=None,
)

Create Store Named Attribute with operation ‘Quaternion’.

spline
nodes.geometry.attribute.StoreNamedAttribute.spline(
    geometry=None,
    selection=True,
    name='',
    value=0.0,
)

Create Store Named Attribute with operation ‘Spline’.

vector
nodes.geometry.attribute.StoreNamedAttribute.vector(
    geometry=None,
    selection=True,
    name='',
    value=None,
)

Create Store Named Attribute with operation ‘Vector’.

vector2
nodes.geometry.attribute.StoreNamedAttribute.vector2(
    geometry=None,
    selection=True,
    name='',
    value=None,
)

Create Store Named Attribute with operation ‘2D Vector’.