nodes.geometry.converter

nodes.geometry.converter

Classes

Name Description
AlignRotationToVector Orient a rotation along the given direction
AxesToRotation Create a rotation from a primary and (ideally orthogonal) secondary axis
AxisAngleToRotation Build a rotation from an axis and a rotation around that axis
BitMath Perform bitwise operations on 32-bit integers
Blackbody Convert a blackbody temperature to an RGB value
BooleanMath Perform a logical operation on the given boolean inputs
Clamp Clamp a value between a minimum and a maximum
ColorRamp Map values to colors with the use of a gradient
CombineBundle Combine multiple socket values into one.
CombineColor Combine four channels into a single color, based on a particular color model
CombineMatrix Construct a 4x4 matrix from its individual values
CombineTransform Combine a translation vector, a rotation, and a scale vector into a transformation matrix
CombineXYZ Create a vector from X, Y, and Z components
EulerToRotation Build a rotation from separate angles around each axis
FindInString Find the number of times a given string occurs in another string and the position of the first match
FloatCurve Map an input float to a curve and outputs a float value
FloatToInteger Convert the given floating-point number to an integer, with a choice of methods
HashValue Generate a randomized integer using the given input value as a seed
IndexOfNearest Find the nearest element in a group. Similar to the “Sample Nearest” node
IntegerMath Perform various math operations on the given integer inputs
InvertMatrix Compute the inverse of the given matrix, if one exists
InvertRotation Compute the inverse of the given rotation
JoinBundle Join multiple bundles together
MapRange Remap a value from a range to a target range
MatchString Check if a given string exists within another string
Math Perform math operations
MatrixDeterminant Compute the determinant of the given matrix
Mix Mix values by a factor
MultiplyMatrices Perform a matrix multiplication on two input matrices
PackUVIslands Scale islands of a UV map and move them so they fill the UV space as much as possible
ProjectPoint Project a point using a matrix, using location, rotation, scale, and perspective divide
QuaternionToRotation Build a rotation from quaternion components
RandomValue Output a randomized value
ReplaceString Replace a given string segment with another
RotateEuler Apply a secondary Euler rotation to a given Euler rotation
RotateRotation Apply a secondary rotation to a given rotation value
RotateVector Apply a rotation to a given vector
RotationToAxisAngle Convert a rotation to axis angle components
RotationToEuler Convert a standard rotation value to an Euler rotation
RotationToQuaternion Retrieve the quaternion components representing a rotation
SeparateBundle Split a bundle into multiple sockets.
SeparateColor Split a color into separate channels, based on a particular color model
SeparateMatrix Split a 4x4 matrix into its individual values
SeparateTransform Split a transformation matrix into a translation vector, a rotation, and a scale vector
SeparateXYZ Split a vector into its X, Y, and Z components
SliceString Extract a string segment from a larger string
StringLength Output the number of characters in the given string
StringToValue Derive a numeric value from a given string representation
Switch Switch between two inputs
TransformDirection Apply a transformation matrix (excluding translation) to the given vector
TransformPoint Apply a transformation matrix to the given vector
TransposeMatrix Flip a matrix over its diagonal, turning columns into rows and vice-versa
UVUnwrap Generate a UV map based on seam edges
ValueToString Generate a string representation of the given input value

AlignRotationToVector

nodes.geometry.converter.AlignRotationToVector(
    rotation=None,
    factor=1.0,
    vector=None,
    *,
    axis='Z',
    pivot_axis='AUTO',
)

Orient a rotation along the given direction

Attributes

Name Description
axis
i_factor Input socket: Factor
i_rotation Input socket: Rotation
i_vector Input socket: Vector
name
node
o_rotation Output socket: Rotation
pivot_axis
tree
type

AxesToRotation

nodes.geometry.converter.AxesToRotation(
    primary_axis=None,
    secondary_axis=None,
    *,
    primary='Z',
    secondary='X',
)

Create a rotation from a primary and (ideally orthogonal) secondary axis

Attributes

Name Description
i_primary_axis Input socket: Primary Axis
i_secondary_axis Input socket: Secondary Axis
name
node
o_rotation Output socket: Rotation
primary
primary_axis
secondary
secondary_axis
tree
type

AxisAngleToRotation

nodes.geometry.converter.AxisAngleToRotation(axis=None, angle=0.0)

Build a rotation from an axis and a rotation around that axis

Attributes

Name Description
i_angle Input socket: Angle
i_axis Input socket: Axis
name
node
o_rotation Output socket: Rotation
tree
type

BitMath

nodes.geometry.converter.BitMath(a=0, b=0, shift=0, *, operation='AND')

Perform bitwise operations on 32-bit integers

Attributes

Name Description
i_a Input socket: A
i_b Input socket: B
i_shift Input socket: Shift
name
node
o_value Output socket: Value
operation
tree
type

Methods

Name Description
exclusive_or Create Bit Math with operation ‘Exclusive Or’.
l_and Create Bit Math with operation ‘And’.
l_not Create Bit Math with operation ‘Not’.
l_or Create Bit Math with operation ‘Or’.
rotate Create Bit Math with operation ‘Rotate’.
shift Create Bit Math with operation ‘Shift’.
exclusive_or
nodes.geometry.converter.BitMath.exclusive_or(a=0, b=0)

Create Bit Math with operation ‘Exclusive Or’.

l_and
nodes.geometry.converter.BitMath.l_and(a=0, b=0)

Create Bit Math with operation ‘And’.

l_not
nodes.geometry.converter.BitMath.l_not(a=0)

Create Bit Math with operation ‘Not’.

l_or
nodes.geometry.converter.BitMath.l_or(a=0, b=0)

Create Bit Math with operation ‘Or’.

rotate
nodes.geometry.converter.BitMath.rotate(a=0, shift=0)

Create Bit Math with operation ‘Rotate’.

shift
nodes.geometry.converter.BitMath.shift(a=0, shift=0)

Create Bit Math with operation ‘Shift’.

Blackbody

nodes.geometry.converter.Blackbody(temperature=6500.0)

Convert a blackbody temperature to an RGB value

Attributes

Name Description
i_temperature Input socket: Temperature
name
node
o_color Output socket: Color
tree
type

BooleanMath

nodes.geometry.converter.BooleanMath(
    boolean=False,
    boolean_001=False,
    *,
    operation='AND',
)

Perform a logical operation on the given boolean inputs

Attributes

Name Description
i_boolean Input socket: Boolean
i_boolean_001 Input socket: Boolean
name
node
o_boolean Output socket: Boolean
operation
tree
type

Methods

Name Description
equal Create Boolean Math with operation ‘Equal’.
imply Create Boolean Math with operation ‘Imply’.
l_and Create Boolean Math with operation ‘And’.
l_not Create Boolean Math with operation ‘Not’.
l_or Create Boolean Math with operation ‘Or’.
nor Create Boolean Math with operation ‘Nor’.
not_and Create Boolean Math with operation ‘Not And’.
not_equal Create Boolean Math with operation ‘Not Equal’.
subtract Create Boolean Math with operation ‘Subtract’.
equal
nodes.geometry.converter.BooleanMath.equal(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘Equal’.

imply
nodes.geometry.converter.BooleanMath.imply(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘Imply’.

l_and
nodes.geometry.converter.BooleanMath.l_and(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘And’.

l_not
nodes.geometry.converter.BooleanMath.l_not(boolean=False)

Create Boolean Math with operation ‘Not’.

l_or
nodes.geometry.converter.BooleanMath.l_or(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘Or’.

nor
nodes.geometry.converter.BooleanMath.nor(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘Nor’.

not_and
nodes.geometry.converter.BooleanMath.not_and(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘Not And’.

not_equal
nodes.geometry.converter.BooleanMath.not_equal(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘Not Equal’.

subtract
nodes.geometry.converter.BooleanMath.subtract(boolean=False, boolean_001=False)

Create Boolean Math with operation ‘Subtract’.

Clamp

nodes.geometry.converter.Clamp(
    value=1.0,
    min=0.0,
    max=1.0,
    *,
    clamp_type='MINMAX',
)

Clamp a value between a minimum and a maximum

Attributes

Name Description
clamp_type
i_max Input socket: Max
i_min Input socket: Min
i_value Input socket: Value
name
node
o_result Output socket: Result
tree
type

ColorRamp

nodes.geometry.converter.ColorRamp(fac=0.5)

Map values to colors with the use of a gradient

Attributes

Name Description
i_fac Input socket: Factor
name
node
o_alpha Output socket: Alpha
o_color Output socket: Color
tree
type

CombineBundle

nodes.geometry.converter.CombineBundle(define_signature=False)

Combine multiple socket values into one.

Attributes

Name Description
define_signature
name
node
o_bundle Output socket: Bundle
tree
type

CombineColor

nodes.geometry.converter.CombineColor(
    red=0.0,
    green=0.0,
    blue=0.0,
    alpha=1.0,
    *,
    mode='RGB',
)

Combine four channels into a single color, based on a particular color model

Attributes

Name Description
i_alpha Input socket: Alpha
i_blue Input socket: Blue
i_green Input socket: Green
i_red Input socket: Red
mode
name
node
o_color Output socket: Color
tree
type

CombineMatrix

nodes.geometry.converter.CombineMatrix(
    column_1_row_1=1.0,
    column_1_row_2=0.0,
    column_1_row_3=0.0,
    column_1_row_4=0.0,
    column_2_row_1=0.0,
    column_2_row_2=1.0,
    column_2_row_3=0.0,
    column_2_row_4=0.0,
    column_3_row_1=0.0,
    column_3_row_2=0.0,
    column_3_row_3=1.0,
    column_3_row_4=0.0,
    column_4_row_1=0.0,
    column_4_row_2=0.0,
    column_4_row_3=0.0,
    column_4_row_4=1.0,
)

Construct a 4x4 matrix from its individual values

Attributes

Name Description
i_column_1_row_1 Input socket: Column 1 Row 1
i_column_1_row_2 Input socket: Column 1 Row 2
i_column_1_row_3 Input socket: Column 1 Row 3
i_column_1_row_4 Input socket: Column 1 Row 4
i_column_2_row_1 Input socket: Column 2 Row 1
i_column_2_row_2 Input socket: Column 2 Row 2
i_column_2_row_3 Input socket: Column 2 Row 3
i_column_2_row_4 Input socket: Column 2 Row 4
i_column_3_row_1 Input socket: Column 3 Row 1
i_column_3_row_2 Input socket: Column 3 Row 2
i_column_3_row_3 Input socket: Column 3 Row 3
i_column_3_row_4 Input socket: Column 3 Row 4
i_column_4_row_1 Input socket: Column 4 Row 1
i_column_4_row_2 Input socket: Column 4 Row 2
i_column_4_row_3 Input socket: Column 4 Row 3
i_column_4_row_4 Input socket: Column 4 Row 4
name
node
o_matrix Output socket: Matrix
tree
type

CombineTransform

nodes.geometry.converter.CombineTransform(
    translation=None,
    rotation=None,
    scale=None,
)

Combine a translation vector, a rotation, and a scale vector into a transformation matrix

Attributes

Name Description
i_rotation Input socket: Rotation
i_scale Input socket: Scale
i_translation Input socket: Translation
name
node
o_transform Output socket: Transform
tree
type

CombineXYZ

nodes.geometry.converter.CombineXYZ(x=0.0, y=0.0, z=0.0)

Create a vector from X, Y, and Z components

Attributes

Name Description
i_x Input socket: X
i_y Input socket: Y
i_z Input socket: Z
name
node
o_vector Output socket: Vector
tree
type

EulerToRotation

nodes.geometry.converter.EulerToRotation(euler=None)

Build a rotation from separate angles around each axis

Attributes

Name Description
i_euler Input socket: Euler
name
node
o_rotation Output socket: Rotation
tree
type

FindInString

nodes.geometry.converter.FindInString(string='', search='')

Find the number of times a given string occurs in another string and the position of the first match

Attributes

Name Description
i_search Input socket: Search
i_string Input socket: String
name
node
o_count Output socket: Count
o_first_found Output socket: First Found
tree
type

FloatCurve

nodes.geometry.converter.FloatCurve(factor=1.0, value=1.0)

Map an input float to a curve and outputs a float value

Attributes

Name Description
i_factor Input socket: Factor
i_value Input socket: Value
name
node
o_value Output socket: Value
tree
type

FloatToInteger

nodes.geometry.converter.FloatToInteger(float=0.0, *, rounding_mode='ROUND')

Convert the given floating-point number to an integer, with a choice of methods

Attributes

Name Description
i_float Input socket: Float
name
node
o_integer Output socket: Integer
rounding_mode
tree
type

HashValue

nodes.geometry.converter.HashValue(value=0, seed=0, *, data_type='INT')

Generate a randomized integer using the given input value as a seed

Attributes

Name Description
data_type
i_seed Input socket: Seed
i_value Input socket: Value
name
node
o_hash Output socket: Hash
tree
type

Methods

Name Description
color Create Hash Value with operation ‘Color’.
float Create Hash Value with operation ‘Float’.
integer Create Hash Value with operation ‘Integer’.
matrix Create Hash Value with operation ‘Matrix’.
rotation Create Hash Value with operation ‘Rotation’.
string Create Hash Value with operation ‘String’.
vector Create Hash Value with operation ‘Vector’.
color
nodes.geometry.converter.HashValue.color(value=None, seed=0)

Create Hash Value with operation ‘Color’.

float
nodes.geometry.converter.HashValue.float(value=0.0, seed=0)

Create Hash Value with operation ‘Float’.

integer
nodes.geometry.converter.HashValue.integer(value=0, seed=0)

Create Hash Value with operation ‘Integer’.

matrix
nodes.geometry.converter.HashValue.matrix(value=None, seed=0)

Create Hash Value with operation ‘Matrix’.

rotation
nodes.geometry.converter.HashValue.rotation(value=None, seed=0)

Create Hash Value with operation ‘Rotation’.

string
nodes.geometry.converter.HashValue.string(value='', seed=0)

Create Hash Value with operation ‘String’.

vector
nodes.geometry.converter.HashValue.vector(value=None, seed=0)

Create Hash Value with operation ‘Vector’.

IndexOfNearest

nodes.geometry.converter.IndexOfNearest(position=None, group_id=0)

Find the nearest element in a group. Similar to the “Sample Nearest” node

Attributes

Name Description
i_group_id Input socket: Group ID
i_position Input socket: Position
name
node
o_has_neighbor Output socket: Has Neighbor
o_index Output socket: Index
tree
type

IntegerMath

nodes.geometry.converter.IntegerMath(
    value=0,
    value_001=0,
    value_002=0,
    *,
    operation='ADD',
)

Perform various math operations on the given integer inputs

Attributes

Name Description
i_value Input socket: Value
i_value_001 Input socket: Value
i_value_002 Input socket: Value
name
node
o_value Output socket: Value
operation
tree
type

Methods

Name Description
absolute Create Integer Math with operation ‘Absolute’.
add Create Integer Math with operation ‘Add’.
divide Create Integer Math with operation ‘Divide’.
divide_ceiling Create Integer Math with operation ‘Divide Ceiling’.
divide_floor Create Integer Math with operation ‘Divide Floor’.
divide_round Create Integer Math with operation ‘Divide Round’.
floored_modulo Create Integer Math with operation ‘Floored Modulo’.
greatest_common_divisor Create Integer Math with operation ‘Greatest Common Divisor’.
least_common_multiple Create Integer Math with operation ‘Least Common Multiple’.
maximum Create Integer Math with operation ‘Maximum’.
minimum Create Integer Math with operation ‘Minimum’.
modulo Create Integer Math with operation ‘Modulo’.
multiply Create Integer Math with operation ‘Multiply’.
multiply_add Create Integer Math with operation ‘Multiply Add’.
negate Create Integer Math with operation ‘Negate’.
power Create Integer Math with operation ‘Power’.
sign Create Integer Math with operation ‘Sign’.
subtract Create Integer Math with operation ‘Subtract’.
absolute
nodes.geometry.converter.IntegerMath.absolute(value=0)

Create Integer Math with operation ‘Absolute’.

add
nodes.geometry.converter.IntegerMath.add(value=0, value_001=0)

Create Integer Math with operation ‘Add’.

divide
nodes.geometry.converter.IntegerMath.divide(value=0, value_001=0)

Create Integer Math with operation ‘Divide’.

divide_ceiling
nodes.geometry.converter.IntegerMath.divide_ceiling(value=0, value_001=0)

Create Integer Math with operation ‘Divide Ceiling’.

divide_floor
nodes.geometry.converter.IntegerMath.divide_floor(value=0, value_001=0)

Create Integer Math with operation ‘Divide Floor’.

divide_round
nodes.geometry.converter.IntegerMath.divide_round(value=0, value_001=0)

Create Integer Math with operation ‘Divide Round’.

floored_modulo
nodes.geometry.converter.IntegerMath.floored_modulo(value=0, value_001=0)

Create Integer Math with operation ‘Floored Modulo’.

greatest_common_divisor
nodes.geometry.converter.IntegerMath.greatest_common_divisor(
    value=0,
    value_001=0,
)

Create Integer Math with operation ‘Greatest Common Divisor’.

least_common_multiple
nodes.geometry.converter.IntegerMath.least_common_multiple(value=0, value_001=0)

Create Integer Math with operation ‘Least Common Multiple’.

maximum
nodes.geometry.converter.IntegerMath.maximum(value=0, value_001=0)

Create Integer Math with operation ‘Maximum’.

minimum
nodes.geometry.converter.IntegerMath.minimum(value=0, value_001=0)

Create Integer Math with operation ‘Minimum’.

modulo
nodes.geometry.converter.IntegerMath.modulo(value=0, value_001=0)

Create Integer Math with operation ‘Modulo’.

multiply
nodes.geometry.converter.IntegerMath.multiply(value=0, value_001=0)

Create Integer Math with operation ‘Multiply’.

multiply_add
nodes.geometry.converter.IntegerMath.multiply_add(
    value=0,
    value_001=0,
    value_002=0,
)

Create Integer Math with operation ‘Multiply Add’.

negate
nodes.geometry.converter.IntegerMath.negate(value=0)

Create Integer Math with operation ‘Negate’.

power
nodes.geometry.converter.IntegerMath.power(value=0, value_001=0)

Create Integer Math with operation ‘Power’.

sign
nodes.geometry.converter.IntegerMath.sign(value=0)

Create Integer Math with operation ‘Sign’.

subtract
nodes.geometry.converter.IntegerMath.subtract(value=0, value_001=0)

Create Integer Math with operation ‘Subtract’.

InvertMatrix

nodes.geometry.converter.InvertMatrix(matrix=None)

Compute the inverse of the given matrix, if one exists

Attributes

Name Description
i_matrix Input socket: Matrix
name
node
o_invertible Output socket: Invertible
o_matrix Output socket: Matrix
tree
type

InvertRotation

nodes.geometry.converter.InvertRotation(rotation=None)

Compute the inverse of the given rotation

Attributes

Name Description
i_rotation Input socket: Rotation
name
node
o_rotation Output socket: Rotation
tree
type

JoinBundle

nodes.geometry.converter.JoinBundle(bundle=None)

Join multiple bundles together

Attributes

Name Description
i_bundle Input socket: Bundle
name
node
o_bundle Output socket: Bundle
tree
type

MapRange

nodes.geometry.converter.MapRange(
    value=1.0,
    from_min=0.0,
    from_max=1.0,
    to_min=0.0,
    to_max=1.0,
    steps=4.0,
    vector=None,
    from_min_float3=None,
    from_max_float3=None,
    to_min_float3=None,
    to_max_float3=None,
    steps_float3=None,
    *,
    clamp=False,
    interpolation_type='LINEAR',
    data_type='FLOAT',
)

Remap a value from a range to a target range

Attributes

Name Description
clamp
data_type
i_from_max Input socket: From Max
i_from_max_float3 Input socket: From Max
i_from_min Input socket: From Min
i_from_min_float3 Input socket: From Min
i_steps Input socket: Steps
i_steps_float3 Input socket: Steps
i_to_max Input socket: To Max
i_to_max_float3 Input socket: To Max
i_to_min Input socket: To Min
i_to_min_float3 Input socket: To Min
i_value Input socket: Value
i_vector Input socket: Vector
interpolation_type
name
node
o_result Output socket: Result
o_vector Output socket: Vector
tree
type

Methods

Name Description
float Create Map Range with operation ‘Float’.
vector Create Map Range with operation ‘Vector’.
float
nodes.geometry.converter.MapRange.float(
    value=1.0,
    from_min=0.0,
    from_max=1.0,
    to_min=0.0,
    to_max=1.0,
)

Create Map Range with operation ‘Float’.

vector
nodes.geometry.converter.MapRange.vector(
    vector=None,
    from_min3=None,
    from_max3=None,
    to_min3=None,
    to_max3=None,
)

Create Map Range with operation ‘Vector’.

MatchString

nodes.geometry.converter.MatchString(string='', operation='Starts With', key='')

Check if a given string exists within another string

Attributes

Name Description
i_key Input socket: Key
i_operation Input socket: Operation
i_string Input socket: String
name
node
o_result Output socket: Result
tree
type

Math

nodes.geometry.converter.Math(
    value=0.5,
    value_001=0.5,
    value_002=0.5,
    *,
    operation='ADD',
    use_clamp=False,
)

Perform math operations

Attributes

Name Description
i_value Input socket: Value
i_value_001 Input socket: Value
i_value_002 Input socket: Value
name
node
o_value Output socket: Value
operation
tree
type
use_clamp

Methods

Name Description
absolute Create Math with operation ‘Absolute’.
add Create Math with operation ‘Add’.
arccosine Create Math with operation ‘Arccosine’.
arcsine Create Math with operation ‘Arcsine’.
arctan2 Create Math with operation ‘Arctan2’.
arctangent Create Math with operation ‘Arctangent’.
ceil Create Math with operation ‘Ceil’.
compare Create Math with operation ‘Compare’.
cosine Create Math with operation ‘Cosine’.
divide Create Math with operation ‘Divide’.
exponent Create Math with operation ‘Exponent’.
floor Create Math with operation ‘Floor’.
floored_modulo Create Math with operation ‘Floored Modulo’.
fraction Create Math with operation ‘Fraction’.
greater_than Create Math with operation ‘Greater Than’.
hyperbolic_cosine Create Math with operation ‘Hyperbolic Cosine’.
hyperbolic_sine Create Math with operation ‘Hyperbolic Sine’.
hyperbolic_tangent Create Math with operation ‘Hyperbolic Tangent’.
inverse_square_root Create Math with operation ‘Inverse Square Root’.
less_than Create Math with operation ‘Less Than’.
logarithm Create Math with operation ‘Logarithm’.
maximum Create Math with operation ‘Maximum’.
minimum Create Math with operation ‘Minimum’.
multiply Create Math with operation ‘Multiply’.
multiply_add Create Math with operation ‘Multiply Add’.
ping_pong Create Math with operation ‘Ping-Pong’.
power Create Math with operation ‘Power’.
round Create Math with operation ‘Round’.
sign Create Math with operation ‘Sign’.
sine Create Math with operation ‘Sine’.
smooth_maximum Create Math with operation ‘Smooth Maximum’.
smooth_minimum Create Math with operation ‘Smooth Minimum’.
snap Create Math with operation ‘Snap’.
square_root Create Math with operation ‘Square Root’.
subtract Create Math with operation ‘Subtract’.
tangent Create Math with operation ‘Tangent’.
to_degrees Create Math with operation ‘To Degrees’.
to_radians Create Math with operation ‘To Radians’.
truncate Create Math with operation ‘Truncate’.
truncated_modulo Create Math with operation ‘Truncated Modulo’.
wrap Create Math with operation ‘Wrap’.
absolute
nodes.geometry.converter.Math.absolute(value=0.5)

Create Math with operation ‘Absolute’.

add
nodes.geometry.converter.Math.add(value=0.5, value_001=0.5)

Create Math with operation ‘Add’.

arccosine
nodes.geometry.converter.Math.arccosine(value=0.5)

Create Math with operation ‘Arccosine’.

arcsine
nodes.geometry.converter.Math.arcsine(value=0.5)

Create Math with operation ‘Arcsine’.

arctan2
nodes.geometry.converter.Math.arctan2(value=0.5, value_001=0.5)

Create Math with operation ‘Arctan2’.

arctangent
nodes.geometry.converter.Math.arctangent(value=0.5)

Create Math with operation ‘Arctangent’.

ceil
nodes.geometry.converter.Math.ceil(value=0.5)

Create Math with operation ‘Ceil’.

compare
nodes.geometry.converter.Math.compare(value=0.5, value_001=0.5, value_002=0.5)

Create Math with operation ‘Compare’.

cosine
nodes.geometry.converter.Math.cosine(value=0.5)

Create Math with operation ‘Cosine’.

divide
nodes.geometry.converter.Math.divide(value=0.5, value_001=0.5)

Create Math with operation ‘Divide’.

exponent
nodes.geometry.converter.Math.exponent(value=0.5)

Create Math with operation ‘Exponent’.

floor
nodes.geometry.converter.Math.floor(value=0.5)

Create Math with operation ‘Floor’.

floored_modulo
nodes.geometry.converter.Math.floored_modulo(value=0.5, value_001=0.5)

Create Math with operation ‘Floored Modulo’.

fraction
nodes.geometry.converter.Math.fraction(value=0.5)

Create Math with operation ‘Fraction’.

greater_than
nodes.geometry.converter.Math.greater_than(value=0.5, value_001=0.5)

Create Math with operation ‘Greater Than’.

hyperbolic_cosine
nodes.geometry.converter.Math.hyperbolic_cosine(value=0.5)

Create Math with operation ‘Hyperbolic Cosine’.

hyperbolic_sine
nodes.geometry.converter.Math.hyperbolic_sine(value=0.5)

Create Math with operation ‘Hyperbolic Sine’.

hyperbolic_tangent
nodes.geometry.converter.Math.hyperbolic_tangent(value=0.5)

Create Math with operation ‘Hyperbolic Tangent’.

inverse_square_root
nodes.geometry.converter.Math.inverse_square_root(value=0.5)

Create Math with operation ‘Inverse Square Root’.

less_than
nodes.geometry.converter.Math.less_than(value=0.5, value_001=0.5)

Create Math with operation ‘Less Than’.

logarithm
nodes.geometry.converter.Math.logarithm(value=0.5, value_001=0.5)

Create Math with operation ‘Logarithm’.

maximum
nodes.geometry.converter.Math.maximum(value=0.5, value_001=0.5)

Create Math with operation ‘Maximum’.

minimum
nodes.geometry.converter.Math.minimum(value=0.5, value_001=0.5)

Create Math with operation ‘Minimum’.

multiply
nodes.geometry.converter.Math.multiply(value=0.5, value_001=0.5)

Create Math with operation ‘Multiply’.

multiply_add
nodes.geometry.converter.Math.multiply_add(
    value=0.5,
    value_001=0.5,
    value_002=0.5,
)

Create Math with operation ‘Multiply Add’.

ping_pong
nodes.geometry.converter.Math.ping_pong(value=0.5, value_001=0.5)

Create Math with operation ‘Ping-Pong’.

power
nodes.geometry.converter.Math.power(value=0.5, value_001=0.5)

Create Math with operation ‘Power’.

round
nodes.geometry.converter.Math.round(value=0.5)

Create Math with operation ‘Round’.

sign
nodes.geometry.converter.Math.sign(value=0.5)

Create Math with operation ‘Sign’.

sine
nodes.geometry.converter.Math.sine(value=0.5)

Create Math with operation ‘Sine’.

smooth_maximum
nodes.geometry.converter.Math.smooth_maximum(
    value=0.5,
    value_001=0.5,
    value_002=0.5,
)

Create Math with operation ‘Smooth Maximum’.

smooth_minimum
nodes.geometry.converter.Math.smooth_minimum(
    value=0.5,
    value_001=0.5,
    value_002=0.5,
)

Create Math with operation ‘Smooth Minimum’.

snap
nodes.geometry.converter.Math.snap(value=0.5, value_001=0.5)

Create Math with operation ‘Snap’.

square_root
nodes.geometry.converter.Math.square_root(value=0.5)

Create Math with operation ‘Square Root’.

subtract
nodes.geometry.converter.Math.subtract(value=0.5, value_001=0.5)

Create Math with operation ‘Subtract’.

tangent
nodes.geometry.converter.Math.tangent(value=0.5)

Create Math with operation ‘Tangent’.

to_degrees
nodes.geometry.converter.Math.to_degrees(value=0.5)

Create Math with operation ‘To Degrees’.

to_radians
nodes.geometry.converter.Math.to_radians(value=0.5)

Create Math with operation ‘To Radians’.

truncate
nodes.geometry.converter.Math.truncate(value=0.5)

Create Math with operation ‘Truncate’.

truncated_modulo
nodes.geometry.converter.Math.truncated_modulo(value=0.5, value_001=0.5)

Create Math with operation ‘Truncated Modulo’.

wrap
nodes.geometry.converter.Math.wrap(value=0.5, value_001=0.5, value_002=0.5)

Create Math with operation ‘Wrap’.

MatrixDeterminant

nodes.geometry.converter.MatrixDeterminant(matrix=None)

Compute the determinant of the given matrix

Attributes

Name Description
i_matrix Input socket: Matrix
name
node
o_determinant Output socket: Determinant
tree
type

Mix

nodes.geometry.converter.Mix(
    factor_float=0.5,
    factor_vector=None,
    a_float=0.0,
    b_float=0.0,
    a_vector=None,
    b_vector=None,
    a_color=None,
    b_color=None,
    a_rotation=None,
    b_rotation=None,
    *,
    data_type='FLOAT',
    factor_mode='UNIFORM',
    blend_type='MIX',
    clamp_factor=False,
    clamp_result=False,
)

Mix values by a factor

Attributes

Name Description
blend_type
clamp_factor
clamp_result
data_type
factor_mode
i_a_color Input socket: A
i_a_float Input socket: A
i_a_rotation Input socket: A
i_a_vector Input socket: A
i_b_color Input socket: B
i_b_float Input socket: B
i_b_rotation Input socket: B
i_b_vector Input socket: B
i_factor_float Input socket: Factor
i_factor_vector Input socket: Factor
name
node
o_result_color Output socket: Result
o_result_float Output socket: Result
o_result_rotation Output socket: Result
o_result_vector Output socket: Result
tree
type

Methods

Name Description
color Create Mix with operation ‘Color’.
float Create Mix with operation ‘Float’.
rotation Create Mix with operation ‘Rotation’.
vector Create Mix with operation ‘Vector’.
color
nodes.geometry.converter.Mix.color(factor=0.5, a_color=None, b_color=None)

Create Mix with operation ‘Color’.

float
nodes.geometry.converter.Mix.float(factor=0.5, a=0.0, b=0.0)

Create Mix with operation ‘Float’.

rotation
nodes.geometry.converter.Mix.rotation(
    factor=0.5,
    a_rotation=None,
    b_rotation=None,
)

Create Mix with operation ‘Rotation’.

vector
nodes.geometry.converter.Mix.vector(factor=0.5, a=None, b=None)

Create Mix with operation ‘Vector’.

MultiplyMatrices

nodes.geometry.converter.MultiplyMatrices(matrix=None, matrix_001=None)

Perform a matrix multiplication on two input matrices

Attributes

Name Description
i_matrix Input socket: Matrix
i_matrix_001 Input socket: Matrix
name
node
o_matrix Output socket: Matrix
tree
type

PackUVIslands

nodes.geometry.converter.PackUVIslands(
    uv=None,
    selection=True,
    margin=0.001,
    rotate=True,
    method='Bounding Box',
)

Scale islands of a UV map and move them so they fill the UV space as much as possible

Attributes

Name Description
i_margin Input socket: Margin
i_method Input socket: Method
i_rotate Input socket: Rotate
i_selection Input socket: Selection
i_uv Input socket: UV
name
node
o_uv Output socket: UV
tree
type

ProjectPoint

nodes.geometry.converter.ProjectPoint(vector=None, transform=None)

Project a point using a matrix, using location, rotation, scale, and perspective divide

Attributes

Name Description
i_transform Input socket: Transform
i_vector Input socket: Vector
name
node
o_vector Output socket: Vector
tree
type

QuaternionToRotation

nodes.geometry.converter.QuaternionToRotation(w=1.0, x=0.0, y=0.0, z=0.0)

Build a rotation from quaternion components

Attributes

Name Description
i_w Input socket: W
i_x Input socket: X
i_y Input socket: Y
i_z Input socket: Z
name
node
o_rotation Output socket: Rotation
tree
type

RandomValue

nodes.geometry.converter.RandomValue(
    min=None,
    max=None,
    min_001=0.0,
    max_001=1.0,
    min_002=0,
    max_002=100,
    probability=0.5,
    id=0,
    seed=0,
    *,
    data_type='FLOAT',
)

Output a randomized value

Attributes

Name Description
data_type
i_id Input socket: ID
i_max Input socket: Max
i_max_001 Input socket: Max
i_max_002 Input socket: Max
i_min Input socket: Min
i_min_001 Input socket: Min
i_min_002 Input socket: Min
i_probability Input socket: Probability
i_seed Input socket: Seed
name
node
o_value Output socket: Value
o_value_001 Output socket: Value
o_value_002 Output socket: Value
o_value_003 Output socket: Value
tree
type

Methods

Name Description
boolean Create Random Value with operation ‘Boolean’.
float Create Random Value with operation ‘Float’.
integer Create Random Value with operation ‘Integer’.
vector Create Random Value with operation ‘Vector’.
boolean
nodes.geometry.converter.RandomValue.boolean(probability=0.5, id=0, seed=0)

Create Random Value with operation ‘Boolean’.

float
nodes.geometry.converter.RandomValue.float(min=0.0, max=1.0, id=0, seed=0)

Create Random Value with operation ‘Float’.

integer
nodes.geometry.converter.RandomValue.integer(min=0, max=100, id=0, seed=0)

Create Random Value with operation ‘Integer’.

vector
nodes.geometry.converter.RandomValue.vector(min=None, max=None, id=0, seed=0)

Create Random Value with operation ‘Vector’.

ReplaceString

nodes.geometry.converter.ReplaceString(string='', find='', replace='')

Replace a given string segment with another

Attributes

Name Description
i_find Input socket: Find
i_replace Input socket: Replace
i_string Input socket: String
name
node
o_string Output socket: String
tree
type

RotateEuler

nodes.geometry.converter.RotateEuler(
    rotation=None,
    rotate_by=None,
    axis=None,
    angle=0.0,
    *,
    rotation_type='EULER',
    space='OBJECT',
)

Apply a secondary Euler rotation to a given Euler rotation

Attributes

Name Description
i_angle Input socket: Angle
i_axis Input socket: Axis
i_rotate_by Input socket: Rotate By
i_rotation Input socket: Rotation
name
node
o_rotation Output socket: Rotation
rotation_type
space
tree
type

RotateRotation

nodes.geometry.converter.RotateRotation(
    rotation=None,
    rotate_by=None,
    *,
    rotation_space='GLOBAL',
)

Apply a secondary rotation to a given rotation value

Attributes

Name Description
i_rotate_by Input socket: Rotate By
i_rotation Input socket: Rotation
name
node
o_rotation Output socket: Rotation
rotation_space
tree
type

RotateVector

nodes.geometry.converter.RotateVector(vector=None, rotation=None)

Apply a rotation to a given vector

Attributes

Name Description
i_rotation Input socket: Rotation
i_vector Input socket: Vector
name
node
o_vector Output socket: Vector
tree
type

RotationToAxisAngle

nodes.geometry.converter.RotationToAxisAngle(rotation=None)

Convert a rotation to axis angle components

Attributes

Name Description
i_rotation Input socket: Rotation
name
node
o_angle Output socket: Angle
o_axis Output socket: Axis
tree
type

RotationToEuler

nodes.geometry.converter.RotationToEuler(rotation=None)

Convert a standard rotation value to an Euler rotation

Attributes

Name Description
i_rotation Input socket: Rotation
name
node
o_euler Output socket: Euler
tree
type

RotationToQuaternion

nodes.geometry.converter.RotationToQuaternion(rotation=None)

Retrieve the quaternion components representing a rotation

Attributes

Name Description
i_rotation Input socket: Rotation
name
node
o_w Output socket: W
o_x Output socket: X
o_y Output socket: Y
o_z Output socket: Z
tree
type

SeparateBundle

nodes.geometry.converter.SeparateBundle(bundle=None, *, define_signature=False)

Split a bundle into multiple sockets.

Attributes

Name Description
define_signature
i_bundle Input socket: Bundle
name
node
tree
type

SeparateColor

nodes.geometry.converter.SeparateColor(color=None, *, mode='RGB')

Split a color into separate channels, based on a particular color model

Attributes

Name Description
i_color Input socket: Color
mode
name
node
o_alpha Output socket: Alpha
o_blue Output socket: Blue
o_green Output socket: Green
o_red Output socket: Red
tree
type

SeparateMatrix

nodes.geometry.converter.SeparateMatrix(matrix=None)

Split a 4x4 matrix into its individual values

Attributes

Name Description
i_matrix Input socket: Matrix
name
node
o_column_1_row_1 Output socket: Column 1 Row 1
o_column_1_row_2 Output socket: Column 1 Row 2
o_column_1_row_3 Output socket: Column 1 Row 3
o_column_1_row_4 Output socket: Column 1 Row 4
o_column_2_row_1 Output socket: Column 2 Row 1
o_column_2_row_2 Output socket: Column 2 Row 2
o_column_2_row_3 Output socket: Column 2 Row 3
o_column_2_row_4 Output socket: Column 2 Row 4
o_column_3_row_1 Output socket: Column 3 Row 1
o_column_3_row_2 Output socket: Column 3 Row 2
o_column_3_row_3 Output socket: Column 3 Row 3
o_column_3_row_4 Output socket: Column 3 Row 4
o_column_4_row_1 Output socket: Column 4 Row 1
o_column_4_row_2 Output socket: Column 4 Row 2
o_column_4_row_3 Output socket: Column 4 Row 3
o_column_4_row_4 Output socket: Column 4 Row 4
tree
type

SeparateTransform

nodes.geometry.converter.SeparateTransform(transform=None)

Split a transformation matrix into a translation vector, a rotation, and a scale vector

Attributes

Name Description
i_transform Input socket: Transform
name
node
o_rotation Output socket: Rotation
o_scale Output socket: Scale
o_translation Output socket: Translation
tree
type

SeparateXYZ

nodes.geometry.converter.SeparateXYZ(vector=None)

Split a vector into its X, Y, and Z components

Attributes

Name Description
i_vector Input socket: Vector
name
node
o_x Output socket: X
o_y Output socket: Y
o_z Output socket: Z
tree
type

SliceString

nodes.geometry.converter.SliceString(string='', position=0, length=10)

Extract a string segment from a larger string

Attributes

Name Description
i_length Input socket: Length
i_position Input socket: Position
i_string Input socket: String
name
node
o_string Output socket: String
tree
type

StringLength

nodes.geometry.converter.StringLength(string='')

Output the number of characters in the given string

Attributes

Name Description
i_string Input socket: String
name
node
o_length Output socket: Length
tree
type

StringToValue

nodes.geometry.converter.StringToValue(string='', *, data_type='FLOAT')

Derive a numeric value from a given string representation

Attributes

Name Description
data_type
i_string Input socket: String
name
node
o_length Output socket: Length
o_value Output socket: Value
tree
type

Methods

Name Description
float Create String to Value with operation ‘Float’.
integer Create String to Value with operation ‘Integer’.
float
nodes.geometry.converter.StringToValue.float(string='')

Create String to Value with operation ‘Float’.

integer
nodes.geometry.converter.StringToValue.integer(string='')

Create String to Value with operation ‘Integer’.

Switch

nodes.geometry.converter.Switch(
    switch=False,
    false=None,
    true=None,
    *,
    input_type='GEOMETRY',
)

Switch between two inputs

Attributes

Name Description
i_false Input socket: False
i_switch Input socket: Switch
i_true Input socket: True
input_type
name
node
o_output Output socket: Output
tree
type

Methods

Name Description
boolean Create Switch with operation ‘Boolean’.
bundle Create Switch with operation ‘Bundle’.
closure Create Switch with operation ‘Closure’.
collection Create Switch with operation ‘Collection’.
color Create Switch with operation ‘Color’.
float Create Switch with operation ‘Float’.
geometry Create Switch with operation ‘Geometry’.
image Create Switch with operation ‘Image’.
integer Create Switch with operation ‘Integer’.
material Create Switch with operation ‘Material’.
matrix Create Switch with operation ‘Matrix’.
menu Create Switch with operation ‘Menu’.
object Create Switch with operation ‘Object’.
rotation Create Switch with operation ‘Rotation’.
string Create Switch with operation ‘String’.
vector Create Switch with operation ‘Vector’.
boolean
nodes.geometry.converter.Switch.boolean(switch=False, false=False, true=False)

Create Switch with operation ‘Boolean’.

bundle
nodes.geometry.converter.Switch.bundle(switch=False, false=None, true=None)

Create Switch with operation ‘Bundle’.

closure
nodes.geometry.converter.Switch.closure(switch=False, false=None, true=None)

Create Switch with operation ‘Closure’.

collection
nodes.geometry.converter.Switch.collection(switch=False, false=None, true=None)

Create Switch with operation ‘Collection’.

color
nodes.geometry.converter.Switch.color(switch=False, false=None, true=None)

Create Switch with operation ‘Color’.

float
nodes.geometry.converter.Switch.float(switch=False, false=0.0, true=0.0)

Create Switch with operation ‘Float’.

geometry
nodes.geometry.converter.Switch.geometry(switch=False, false=None, true=None)

Create Switch with operation ‘Geometry’.

image
nodes.geometry.converter.Switch.image(switch=False, false=None, true=None)

Create Switch with operation ‘Image’.

integer
nodes.geometry.converter.Switch.integer(switch=False, false=0, true=0)

Create Switch with operation ‘Integer’.

material
nodes.geometry.converter.Switch.material(switch=False, false=None, true=None)

Create Switch with operation ‘Material’.

matrix
nodes.geometry.converter.Switch.matrix(switch=False, false=None, true=None)

Create Switch with operation ‘Matrix’.

menu
nodes.geometry.converter.Switch.menu(switch=False, false=None, true=None)

Create Switch with operation ‘Menu’.

object
nodes.geometry.converter.Switch.object(switch=False, false=None, true=None)

Create Switch with operation ‘Object’.

rotation
nodes.geometry.converter.Switch.rotation(switch=False, false=None, true=None)

Create Switch with operation ‘Rotation’.

string
nodes.geometry.converter.Switch.string(switch=False, false='', true='')

Create Switch with operation ‘String’.

vector
nodes.geometry.converter.Switch.vector(switch=False, false=None, true=None)

Create Switch with operation ‘Vector’.

TransformDirection

nodes.geometry.converter.TransformDirection(direction=None, transform=None)

Apply a transformation matrix (excluding translation) to the given vector

Attributes

Name Description
i_direction Input socket: Direction
i_transform Input socket: Transform
name
node
o_direction Output socket: Direction
tree
type

TransformPoint

nodes.geometry.converter.TransformPoint(vector=None, transform=None)

Apply a transformation matrix to the given vector

Attributes

Name Description
i_transform Input socket: Transform
i_vector Input socket: Vector
name
node
o_vector Output socket: Vector
tree
type

TransposeMatrix

nodes.geometry.converter.TransposeMatrix(matrix=None)

Flip a matrix over its diagonal, turning columns into rows and vice-versa

Attributes

Name Description
i_matrix Input socket: Matrix
name
node
o_matrix Output socket: Matrix
tree
type

UVUnwrap

nodes.geometry.converter.UVUnwrap(
    selection=True,
    seam=False,
    margin=0.001,
    fill_holes=True,
    method='Angle Based',
)

Generate a UV map based on seam edges

Attributes

Name Description
i_fill_holes Input socket: Fill Holes
i_margin Input socket: Margin
i_method Input socket: Method
i_seam Input socket: Seam
i_selection Input socket: Selection
name
node
o_uv Output socket: UV
tree
type

ValueToString

nodes.geometry.converter.ValueToString(
    value=0.0,
    decimals=0,
    *,
    data_type='FLOAT',
)

Generate a string representation of the given input value

Attributes

Name Description
data_type
i_decimals Input socket: Decimals
i_value Input socket: Value
name
node
o_string Output socket: String
tree
type

Methods

Name Description
float Create Value to String with operation ‘Float’.
integer Create Value to String with operation ‘Integer’.
float
nodes.geometry.converter.ValueToString.float(value=0.0, decimals=0)

Create Value to String with operation ‘Float’.

integer
nodes.geometry.converter.ValueToString.integer(value=0)

Create Value to String with operation ‘Integer’.