nodes.geometry.groups

groups

Attributes

Name Description
GROUP_NAME

Classes

Name Description
ClipFieldToBox
OffsetVector Evaluate a given vector field at an offset to the current Index.
OtherVertex Given a vertex and an edge number from that vertex, returns the other
PrincipalComponents Compute PCA on a given vector field.

ClipFieldToBox

ClipFieldToBox(box_object=None, invert=False)

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
name
node
node_tree
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
outputs
tree
type

OffsetVector

OffsetVector(index=None, vector=None, offset=0)

Evaluate a given vector field at an offset to the current Index.

Attributes

Name Description
i
name
node
node_tree
o
outputs
tree
type

OtherVertex

OtherVertex(vertex_index=None, edge_number=0)

Given a vertex and an edge number from that vertex, returns the other vertex of that edge.

Attributes

Name Description
i
name
node
node_tree
o
outputs
tree
type

PrincipalComponents

PrincipalComponents(position=None, group_id=None)

Compute PCA on a given vector field.

Attributes

Name Description
i
name
node
node_tree
o
outputs
tree
type