nodes.geometry.groups

groups

Classes

Name Description
OffsetVector Evaluate a given vector field at an offset to the current Index.
OtherVertex Given a vertex and an edge number from that vertex, returns the other

OffsetVector

OffsetVector(index=None, vector=None, offset=0)

Evaluate a given vector field at an offset to the current Index.

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type

OtherVertex

OtherVertex(vertex_index=None, edge_number=0)

Given a vertex and an edge number from that vertex, returns the other vertex of that edge.

Attributes

Name Description
i
inputs
name
node
o
outputs
tree
type