nodes.geometry.input
nodes.geometry.input
Classes
| Name | Description |
|---|---|
| ActiveCamera | Retrieve the scene’s active camera |
| ActiveElement | Active element indices of the edited geometry, for tool execution |
| Boolean | Provide a True/False value that can be connected to other nodes in the tree |
| CameraInfo | Retrieve information from a camera object |
| CollectionInfo | Retrieve geometry instances from a collection |
| Color | Output a color value chosen with the color picker widget |
| CornersOfEdge | Retrieve face corners connected to edges |
| CornersOfFace | Retrieve corners that make up a face |
| CornersOfVertex | Retrieve face corners connected to vertices |
| Cursor3D | The scene’s 3D cursor location and rotation |
| CurveHandlePositions | Retrieve the position of each Bézier control point’s handles |
| CurveOfPoint | Retrieve the curve a control point is part of |
| CurveTangent | Retrieve the direction of curves at each control point |
| CurveTilt | Retrieve the angle at each control point used to twist the curve’s normal around its tangent |
| EdgeAngle | The angle between the normals of connected manifold faces |
| EdgeNeighbors | Retrieve the number of faces that use each edge as one of their sides |
| EdgePathsToSelection | Output a selection of edges by following paths across mesh edges |
| EdgeVertices | Retrieve topology information relating to each edge of a mesh |
| EdgesOfCorner | Retrieve the edges on both sides of a face corner |
| EdgesOfVertex | Retrieve the edges connected to each vertex |
| EdgesToFaceGroups | Group faces into regions surrounded by the selected boundary edges |
| EndpointSelection | Provide a selection for an arbitrary number of endpoints in each spline |
| FaceArea | Calculate the surface area of a mesh’s faces |
| FaceGroupBoundaries | Find edges on the boundaries between groups of faces with the same ID value |
| FaceNeighbors | Retrieve topology information relating to each face of a mesh |
| FaceOfCorner | Retrieve the face each face corner is part of |
| FaceSet | Each face’s sculpt face set value |
| ID | Retrieve a stable random identifier value from the “id” attribute on the point domain, or the index if the attribute does not exist |
| Image | Input an image data-block |
| ImageInfo | Retrieve information about an image |
| ImportCSV | Import geometry from an CSV file |
| ImportOBJ | Import geometry from an OBJ file |
| ImportPLY | Import a point cloud from a PLY file |
| ImportSTL | Import a mesh from an STL file |
| ImportText | Import a string from a text file |
| ImportVDB | Import volume data from a .vdb file |
| Index | Retrieve an integer value indicating the position of each element in the list, starting at zero |
| InstanceBounds | Calculate position bounds of each instance’s geometry set |
| InstanceRotation | Retrieve the rotation of each instance in the geometry |
| InstanceScale | Retrieve the scale of each instance in the geometry |
| InstanceTransform | Retrieve the full transformation of each instance in the geometry |
| Integer | Provide an integer value that can be connected to other nodes in the tree |
| IsEdgeSmooth | Retrieve whether each edge is marked for smooth or split normals |
| IsFacePlanar | Retrieve whether all triangles in a face are on the same plane, i.e. whether they have the same normal |
| IsFaceSmooth | Retrieve whether each face is marked for smooth or sharp normals |
| IsSplineCyclic | Retrieve whether each spline endpoint connects to the beginning |
| IsViewport | Retrieve whether the nodes are being evaluated for the viewport rather than the final render |
| MaterialIndex | Retrieve the index of the material used for each element in the geometry’s list of materials |
| MeshIsland | Retrieve information about separate connected regions in a mesh |
| MousePosition | Retrieve the position of the mouse cursor |
| NamedAttribute | Retrieve the data of a specified attribute |
| NamedLayerSelection | Output a selection of a Grease Pencil layer |
| Normal | Retrieve a unit length vector indicating the direction pointing away from the geometry at each element |
| ObjectInfo | Retrieve information from an object |
| OffsetCornerInFace | Retrieve corners in the same face as another |
| OffsetPointInCurve | Offset a control point index within its curve |
| PointsOfCurve | Retrieve a point index within a curve |
| Position | Retrieve a vector indicating the location of each element |
| Radius | Retrieve the radius at each point on curve or point cloud geometry |
| Rotation | Provide a rotation value that can be connected to other nodes in the tree |
| SceneTime | Retrieve the current time in the scene’s animation in units of seconds or frames |
| Selection | User selection of the edited geometry, for tool execution |
| SelfObject | Retrieve the object that contains the geometry nodes modifier currently being executed |
| ShortestEdgePaths | Find the shortest paths along mesh edges to selected end vertices, with customizable cost per edge |
| SpecialCharacters | Output string characters that cannot be typed directly with the keyboard |
| SplineLength | Retrieve the total length of each spline, as a distance or as a number of points |
| SplineParameter | Retrieve how far along each spline a control point is |
| SplineResolution | Retrieve the number of evaluated points that will be generated for every control point on curves |
| String | Provide a string value that can be connected to other nodes in the tree |
| UVTangent | Generate tangent directions based on a UV map |
| Vector | Provide a vector value that can be connected to other nodes in the tree |
| VertexNeighbors | Retrieve topology information relating to each vertex of a mesh |
| VertexOfCorner | Retrieve the vertex each face corner is attached to |
| ViewportTransform | Retrieve the view direction and location of the 3D viewport |
| VoxelIndex | Retrieve the integer coordinates of the voxel that the field is evaluated on |
ActiveCamera
nodes.geometry.input.ActiveCamera()Retrieve the scene’s active camera
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_active_camera | Output socket: Active Camera |
| tree | |
| type |
ActiveElement
nodes.geometry.input.ActiveElement(domain='POINT')Active element indices of the edited geometry, for tool execution
Attributes
| Name | Description |
|---|---|
| domain | |
| name | |
| node | |
| o_exists | Output socket: Exists |
| o_index | Output socket: Index |
| tree | |
| type |
Methods
| Name | Description |
|---|---|
| edge | Create Active Element with operation ‘Edge’. |
| face | Create Active Element with operation ‘Face’. |
| layer | Create Active Element with operation ‘Layer’. |
| point | Create Active Element with operation ‘Point’. |
edge
nodes.geometry.input.ActiveElement.edge()Create Active Element with operation ‘Edge’.
face
nodes.geometry.input.ActiveElement.face()Create Active Element with operation ‘Face’.
layer
nodes.geometry.input.ActiveElement.layer()Create Active Element with operation ‘Layer’.
point
nodes.geometry.input.ActiveElement.point()Create Active Element with operation ‘Point’.
Boolean
nodes.geometry.input.Boolean(boolean=False)Provide a True/False value that can be connected to other nodes in the tree
Attributes
| Name | Description |
|---|---|
| boolean | |
| name | |
| node | |
| o_boolean | Output socket: Boolean |
| tree | |
| type |
CameraInfo
nodes.geometry.input.CameraInfo(camera=None)Retrieve information from a camera object
Attributes
| Name | Description |
|---|---|
| i_camera | Input socket: Camera |
| name | |
| node | |
| o_clip_end | Output socket: Clip End |
| o_clip_start | Output socket: Clip Start |
| o_focal_length | Output socket: Focal Length |
| o_focus_distance | Output socket: Focus Distance |
| o_is_orthographic | Output socket: Is Orthographic |
| o_orthographic_scale | Output socket: Orthographic Scale |
| o_projection_matrix | Output socket: Projection Matrix |
| o_sensor | Output socket: Sensor |
| o_shift | Output socket: Shift |
| tree | |
| type |
CollectionInfo
nodes.geometry.input.CollectionInfo(
collection=None,
separate_children=False,
reset_children=False,
*,
transform_space='ORIGINAL',
)Retrieve geometry instances from a collection
Attributes
| Name | Description |
|---|---|
| i_collection | Input socket: Collection |
| i_reset_children | Input socket: Reset Children |
| i_separate_children | Input socket: Separate Children |
| name | |
| node | |
| o_instances | Output socket: Instances |
| transform_space | |
| tree | |
| type |
Color
nodes.geometry.input.Color(value=(0.735, 0.735, 0.735, 1.0))Output a color value chosen with the color picker widget
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_color | Output socket: Color |
| tree | |
| type | |
| value |
CornersOfEdge
nodes.geometry.input.CornersOfEdge(edge_index=0, weights=0.0, sort_index=0)Retrieve face corners connected to edges
Attributes
| Name | Description |
|---|---|
| i_edge_index | Input socket: Edge Index |
| i_sort_index | Input socket: Sort Index |
| i_weights | Input socket: Weights |
| name | |
| node | |
| o_corner_index | Output socket: Corner Index |
| o_total | Output socket: Total |
| tree | |
| type |
CornersOfFace
nodes.geometry.input.CornersOfFace(face_index=0, weights=0.0, sort_index=0)Retrieve corners that make up a face
Attributes
| Name | Description |
|---|---|
| i_face_index | Input socket: Face Index |
| i_sort_index | Input socket: Sort Index |
| i_weights | Input socket: Weights |
| name | |
| node | |
| o_corner_index | Output socket: Corner Index |
| o_total | Output socket: Total |
| tree | |
| type |
CornersOfVertex
nodes.geometry.input.CornersOfVertex(vertex_index=0, weights=0.0, sort_index=0)Retrieve face corners connected to vertices
Attributes
| Name | Description |
|---|---|
| i_sort_index | Input socket: Sort Index |
| i_vertex_index | Input socket: Vertex Index |
| i_weights | Input socket: Weights |
| name | |
| node | |
| o_corner_index | Output socket: Corner Index |
| o_total | Output socket: Total |
| tree | |
| type |
Cursor3D
nodes.geometry.input.Cursor3D()The scene’s 3D cursor location and rotation
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_location | Output socket: Location |
| o_rotation | Output socket: Rotation |
| tree | |
| type |
CurveHandlePositions
nodes.geometry.input.CurveHandlePositions(relative=False)Retrieve the position of each Bézier control point’s handles
Attributes
| Name | Description |
|---|---|
| i_relative | Input socket: Relative |
| name | |
| node | |
| o_left | Output socket: Left |
| o_right | Output socket: Right |
| tree | |
| type |
CurveOfPoint
nodes.geometry.input.CurveOfPoint(point_index=0)Retrieve the curve a control point is part of
Attributes
| Name | Description |
|---|---|
| i_point_index | Input socket: Point Index |
| name | |
| node | |
| o_curve_index | Output socket: Curve Index |
| o_index_in_curve | Output socket: Index in Curve |
| tree | |
| type |
CurveTangent
nodes.geometry.input.CurveTangent()Retrieve the direction of curves at each control point
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_tangent | Output socket: Tangent |
| tree | |
| type |
CurveTilt
nodes.geometry.input.CurveTilt()Retrieve the angle at each control point used to twist the curve’s normal around its tangent
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_tilt | Output socket: Tilt |
| tree | |
| type |
EdgeAngle
nodes.geometry.input.EdgeAngle()The angle between the normals of connected manifold faces
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_signed_angle | Output socket: Signed Angle |
| o_unsigned_angle | Output socket: Unsigned Angle |
| tree | |
| type |
EdgeNeighbors
nodes.geometry.input.EdgeNeighbors()Retrieve the number of faces that use each edge as one of their sides
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_face_count | Output socket: Face Count |
| tree | |
| type |
EdgePathsToSelection
nodes.geometry.input.EdgePathsToSelection(
start_vertices=True,
next_vertex_index=-1,
)Output a selection of edges by following paths across mesh edges
Attributes
| Name | Description |
|---|---|
| i_next_vertex_index | Input socket: Next Vertex Index |
| i_start_vertices | Input socket: Start Vertices |
| name | |
| node | |
| o_selection | Output socket: Selection |
| tree | |
| type |
EdgeVertices
nodes.geometry.input.EdgeVertices()Retrieve topology information relating to each edge of a mesh
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_position_1 | Output socket: Position 1 |
| o_position_2 | Output socket: Position 2 |
| o_vertex_index_1 | Output socket: Vertex Index 1 |
| o_vertex_index_2 | Output socket: Vertex Index 2 |
| tree | |
| type |
EdgesOfCorner
nodes.geometry.input.EdgesOfCorner(corner_index=0)Retrieve the edges on both sides of a face corner
Attributes
| Name | Description |
|---|---|
| i_corner_index | Input socket: Corner Index |
| name | |
| node | |
| o_next_edge_index | Output socket: Next Edge Index |
| o_previous_edge_index | Output socket: Previous Edge Index |
| tree | |
| type |
EdgesOfVertex
nodes.geometry.input.EdgesOfVertex(vertex_index=0, weights=0.0, sort_index=0)Retrieve the edges connected to each vertex
Attributes
| Name | Description |
|---|---|
| i_sort_index | Input socket: Sort Index |
| i_vertex_index | Input socket: Vertex Index |
| i_weights | Input socket: Weights |
| name | |
| node | |
| o_edge_index | Output socket: Edge Index |
| o_total | Output socket: Total |
| tree | |
| type |
EdgesToFaceGroups
nodes.geometry.input.EdgesToFaceGroups(boundary_edges=True)Group faces into regions surrounded by the selected boundary edges
Attributes
| Name | Description |
|---|---|
| i_boundary_edges | Input socket: Boundary Edges |
| name | |
| node | |
| o_face_group_id | Output socket: Face Group ID |
| tree | |
| type |
EndpointSelection
nodes.geometry.input.EndpointSelection(start_size=1, end_size=1)Provide a selection for an arbitrary number of endpoints in each spline
Attributes
| Name | Description |
|---|---|
| i_end_size | Input socket: End Size |
| i_start_size | Input socket: Start Size |
| name | |
| node | |
| o_selection | Output socket: Selection |
| tree | |
| type |
FaceArea
nodes.geometry.input.FaceArea()Calculate the surface area of a mesh’s faces
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_area | Output socket: Area |
| tree | |
| type |
FaceGroupBoundaries
nodes.geometry.input.FaceGroupBoundaries(face_set=0)Find edges on the boundaries between groups of faces with the same ID value
Attributes
| Name | Description |
|---|---|
| i_face_set | Input socket: Face Group ID |
| name | |
| node | |
| o_boundary_edges | Output socket: Boundary Edges |
| tree | |
| type |
FaceNeighbors
nodes.geometry.input.FaceNeighbors()Retrieve topology information relating to each face of a mesh
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_face_count | Output socket: Face Count |
| o_vertex_count | Output socket: Vertex Count |
| tree | |
| type |
FaceOfCorner
nodes.geometry.input.FaceOfCorner(corner_index=0)Retrieve the face each face corner is part of
Attributes
| Name | Description |
|---|---|
| i_corner_index | Input socket: Corner Index |
| name | |
| node | |
| o_face_index | Output socket: Face Index |
| o_index_in_face | Output socket: Index in Face |
| tree | |
| type |
FaceSet
nodes.geometry.input.FaceSet()Each face’s sculpt face set value
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_exists | Output socket: Exists |
| o_face_set | Output socket: Face Set |
| tree | |
| type |
ID
nodes.geometry.input.ID()Retrieve a stable random identifier value from the “id” attribute on the point domain, or the index if the attribute does not exist
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_id | Output socket: ID |
| tree | |
| type |
Image
nodes.geometry.input.Image()Input an image data-block
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_image | Output socket: Image |
| tree | |
| type |
ImageInfo
nodes.geometry.input.ImageInfo(image=None, frame=0)Retrieve information about an image
Attributes
| Name | Description |
|---|---|
| i_frame | Input socket: Frame |
| i_image | Input socket: Image |
| name | |
| node | |
| o_fps | Output socket: FPS |
| o_frame_count | Output socket: Frame Count |
| o_has_alpha | Output socket: Has Alpha |
| o_height | Output socket: Height |
| o_width | Output socket: Width |
| tree | |
| type |
ImportCSV
nodes.geometry.input.ImportCSV(path='', delimiter=',')Import geometry from an CSV file
Attributes
| Name | Description |
|---|---|
| i_delimiter | Input socket: Delimiter |
| i_path | Input socket: Path |
| name | |
| node | |
| o_point_cloud | Output socket: Point Cloud |
| tree | |
| type |
ImportOBJ
nodes.geometry.input.ImportOBJ(path='')Import geometry from an OBJ file
Attributes
| Name | Description |
|---|---|
| i_path | Input socket: Path |
| name | |
| node | |
| o_instances | Output socket: Instances |
| tree | |
| type |
ImportPLY
nodes.geometry.input.ImportPLY(path='')Import a point cloud from a PLY file
Attributes
| Name | Description |
|---|---|
| i_path | Input socket: Path |
| name | |
| node | |
| o_mesh | Output socket: Mesh |
| tree | |
| type |
ImportSTL
nodes.geometry.input.ImportSTL(path='')Import a mesh from an STL file
Attributes
| Name | Description |
|---|---|
| i_path | Input socket: Path |
| name | |
| node | |
| o_mesh | Output socket: Mesh |
| tree | |
| type |
ImportText
nodes.geometry.input.ImportText(path='')Import a string from a text file
Attributes
| Name | Description |
|---|---|
| i_path | Input socket: Path |
| name | |
| node | |
| o_string | Output socket: String |
| tree | |
| type |
ImportVDB
nodes.geometry.input.ImportVDB(path='')Import volume data from a .vdb file
Attributes
| Name | Description |
|---|---|
| i_path | Input socket: Path |
| name | |
| node | |
| o_volume | Output socket: Volume |
| tree | |
| type |
Index
nodes.geometry.input.Index()Retrieve an integer value indicating the position of each element in the list, starting at zero
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_index | Output socket: Index |
| tree | |
| type |
InstanceBounds
nodes.geometry.input.InstanceBounds(use_radius=True)Calculate position bounds of each instance’s geometry set
Attributes
| Name | Description |
|---|---|
| i_use_radius | Input socket: Use Radius |
| name | |
| node | |
| o_max | Output socket: Max |
| o_min | Output socket: Min |
| tree | |
| type |
InstanceRotation
nodes.geometry.input.InstanceRotation()Retrieve the rotation of each instance in the geometry
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_rotation | Output socket: Rotation |
| tree | |
| type |
InstanceScale
nodes.geometry.input.InstanceScale()Retrieve the scale of each instance in the geometry
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_scale | Output socket: Scale |
| tree | |
| type |
InstanceTransform
nodes.geometry.input.InstanceTransform()Retrieve the full transformation of each instance in the geometry
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_transform | Output socket: Transform |
| tree | |
| type |
Integer
nodes.geometry.input.Integer(integer=1)Provide an integer value that can be connected to other nodes in the tree
Attributes
| Name | Description |
|---|---|
| integer | |
| name | |
| node | |
| o_integer | Output socket: Integer |
| tree | |
| type |
IsEdgeSmooth
nodes.geometry.input.IsEdgeSmooth()Retrieve whether each edge is marked for smooth or split normals
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_smooth | Output socket: Smooth |
| tree | |
| type |
IsFacePlanar
nodes.geometry.input.IsFacePlanar(threshold=0.01)Retrieve whether all triangles in a face are on the same plane, i.e. whether they have the same normal
Attributes
| Name | Description |
|---|---|
| i_threshold | Input socket: Threshold |
| name | |
| node | |
| o_planar | Output socket: Planar |
| tree | |
| type |
IsFaceSmooth
nodes.geometry.input.IsFaceSmooth()Retrieve whether each face is marked for smooth or sharp normals
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_smooth | Output socket: Smooth |
| tree | |
| type |
IsSplineCyclic
nodes.geometry.input.IsSplineCyclic()Retrieve whether each spline endpoint connects to the beginning
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_cyclic | Output socket: Cyclic |
| tree | |
| type |
IsViewport
nodes.geometry.input.IsViewport()Retrieve whether the nodes are being evaluated for the viewport rather than the final render
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_is_viewport | Output socket: Is Viewport |
| tree | |
| type |
MaterialIndex
nodes.geometry.input.MaterialIndex()Retrieve the index of the material used for each element in the geometry’s list of materials
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_material_index | Output socket: Material Index |
| tree | |
| type |
MeshIsland
nodes.geometry.input.MeshIsland()Retrieve information about separate connected regions in a mesh
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_island_count | Output socket: Island Count |
| o_island_index | Output socket: Island Index |
| tree | |
| type |
MousePosition
nodes.geometry.input.MousePosition()Retrieve the position of the mouse cursor
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_mouse_x | Output socket: Mouse X |
| o_mouse_y | Output socket: Mouse Y |
| o_region_height | Output socket: Region Height |
| o_region_width | Output socket: Region Width |
| tree | |
| type |
NamedAttribute
nodes.geometry.input.NamedAttribute(name='', *, data_type='FLOAT')Retrieve the data of a specified attribute
Attributes
| Name | Description |
|---|---|
| data_type | |
| i_name | Input socket: Name |
| name | |
| node | |
| o_attribute | Output socket: Attribute |
| o_exists | Output socket: Exists |
| tree | |
| type |
Methods
| Name | Description |
|---|---|
| boolean | Create Named Attribute with operation ‘Boolean’. |
| color | Create Named Attribute with operation ‘Color’. |
| float | Create Named Attribute with operation ‘Float’. |
| integer | Create Named Attribute with operation ‘Integer’. |
| matrix | Create Named Attribute with operation ‘4x4 Matrix’. |
| quaternion | Create Named Attribute with operation ‘Quaternion’. |
| vector | Create Named Attribute with operation ‘Vector’. |
boolean
nodes.geometry.input.NamedAttribute.boolean(name='')Create Named Attribute with operation ‘Boolean’.
color
nodes.geometry.input.NamedAttribute.color(name='')Create Named Attribute with operation ‘Color’.
float
nodes.geometry.input.NamedAttribute.float(name='')Create Named Attribute with operation ‘Float’.
integer
nodes.geometry.input.NamedAttribute.integer(name='')Create Named Attribute with operation ‘Integer’.
matrix
nodes.geometry.input.NamedAttribute.matrix(name='')Create Named Attribute with operation ‘4x4 Matrix’.
quaternion
nodes.geometry.input.NamedAttribute.quaternion(name='')Create Named Attribute with operation ‘Quaternion’.
vector
nodes.geometry.input.NamedAttribute.vector(name='')Create Named Attribute with operation ‘Vector’.
NamedLayerSelection
nodes.geometry.input.NamedLayerSelection(name='')Output a selection of a Grease Pencil layer
Attributes
| Name | Description |
|---|---|
| i_name | Input socket: Name |
| name | |
| node | |
| o_selection | Output socket: Selection |
| tree | |
| type |
Normal
nodes.geometry.input.Normal(legacy_corner_normals=False)Retrieve a unit length vector indicating the direction pointing away from the geometry at each element
Attributes
| Name | Description |
|---|---|
| legacy_corner_normals | |
| name | |
| node | |
| o_normal | Output socket: Normal |
| o_true_normal | Output socket: True Normal |
| tree | |
| type |
ObjectInfo
nodes.geometry.input.ObjectInfo(
object=None,
as_instance=False,
*,
transform_space='ORIGINAL',
)Retrieve information from an object
Attributes
| Name | Description |
|---|---|
| i_as_instance | Input socket: As Instance |
| i_object | Input socket: Object |
| name | |
| node | |
| o_geometry | Output socket: Geometry |
| o_location | Output socket: Location |
| o_rotation | Output socket: Rotation |
| o_scale | Output socket: Scale |
| o_transform | Output socket: Transform |
| transform_space | |
| tree | |
| type |
OffsetCornerInFace
nodes.geometry.input.OffsetCornerInFace(corner_index=0, offset=0)Retrieve corners in the same face as another
Attributes
| Name | Description |
|---|---|
| i_corner_index | Input socket: Corner Index |
| i_offset | Input socket: Offset |
| name | |
| node | |
| o_corner_index | Output socket: Corner Index |
| tree | |
| type |
OffsetPointInCurve
nodes.geometry.input.OffsetPointInCurve(point_index=0, offset=0)Offset a control point index within its curve
Attributes
| Name | Description |
|---|---|
| i_offset | Input socket: Offset |
| i_point_index | Input socket: Point Index |
| name | |
| node | |
| o_is_valid_offset | Output socket: Is Valid Offset |
| o_point_index | Output socket: Point Index |
| tree | |
| type |
PointsOfCurve
nodes.geometry.input.PointsOfCurve(curve_index=0, weights=0.0, sort_index=0)Retrieve a point index within a curve
Attributes
| Name | Description |
|---|---|
| i_curve_index | Input socket: Curve Index |
| i_sort_index | Input socket: Sort Index |
| i_weights | Input socket: Weights |
| name | |
| node | |
| o_point_index | Output socket: Point Index |
| o_total | Output socket: Total |
| tree | |
| type |
Position
nodes.geometry.input.Position()Retrieve a vector indicating the location of each element
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_position | Output socket: Position |
| tree | |
| type |
Radius
nodes.geometry.input.Radius()Retrieve the radius at each point on curve or point cloud geometry
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_radius | Output socket: Radius |
| tree | |
| type |
Rotation
nodes.geometry.input.Rotation(rotation_euler=(0.0, 0.0, 0.0))Provide a rotation value that can be connected to other nodes in the tree
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_rotation | Output socket: Rotation |
| rotation_euler | |
| tree | |
| type |
SceneTime
nodes.geometry.input.SceneTime()Retrieve the current time in the scene’s animation in units of seconds or frames
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_frame | Output socket: Frame |
| o_seconds | Output socket: Seconds |
| tree | |
| type |
Selection
nodes.geometry.input.Selection()User selection of the edited geometry, for tool execution
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_float | Output socket: Float |
| o_selection | Output socket: Boolean |
| tree | |
| type |
SelfObject
nodes.geometry.input.SelfObject()Retrieve the object that contains the geometry nodes modifier currently being executed
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_self_object | Output socket: Self Object |
| tree | |
| type |
ShortestEdgePaths
nodes.geometry.input.ShortestEdgePaths(end_vertex=False, edge_cost=1.0)Find the shortest paths along mesh edges to selected end vertices, with customizable cost per edge
Attributes
| Name | Description |
|---|---|
| i_edge_cost | Input socket: Edge Cost |
| i_end_vertex | Input socket: End Vertex |
| name | |
| node | |
| o_next_vertex_index | Output socket: Next Vertex Index |
| o_total_cost | Output socket: Total Cost |
| tree | |
| type |
SpecialCharacters
nodes.geometry.input.SpecialCharacters()Output string characters that cannot be typed directly with the keyboard
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_line_break | Output socket: Line Break |
| o_tab | Output socket: Tab |
| tree | |
| type |
SplineLength
nodes.geometry.input.SplineLength()Retrieve the total length of each spline, as a distance or as a number of points
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_length | Output socket: Length |
| o_point_count | Output socket: Point Count |
| tree | |
| type |
SplineParameter
nodes.geometry.input.SplineParameter()Retrieve how far along each spline a control point is
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_factor | Output socket: Factor |
| o_index | Output socket: Index |
| o_length | Output socket: Length |
| tree | |
| type |
SplineResolution
nodes.geometry.input.SplineResolution()Retrieve the number of evaluated points that will be generated for every control point on curves
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_resolution | Output socket: Resolution |
| tree | |
| type |
String
nodes.geometry.input.String(string='')Provide a string value that can be connected to other nodes in the tree
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_string | Output socket: String |
| string | |
| tree | |
| type |
UVTangent
nodes.geometry.input.UVTangent(method='Exact', uv=None)Generate tangent directions based on a UV map
Attributes
| Name | Description |
|---|---|
| i_method | Input socket: Method |
| i_uv | Input socket: UV |
| name | |
| node | |
| o_tangent | Output socket: Tangent |
| tree | |
| type |
Vector
nodes.geometry.input.Vector(vector=(0.0, 0.0, 0.0))Provide a vector value that can be connected to other nodes in the tree
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_vector | Output socket: Vector |
| tree | |
| type | |
| vector |
VertexNeighbors
nodes.geometry.input.VertexNeighbors()Retrieve topology information relating to each vertex of a mesh
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_face_count | Output socket: Face Count |
| o_vertex_count | Output socket: Vertex Count |
| tree | |
| type |
VertexOfCorner
nodes.geometry.input.VertexOfCorner(corner_index=0)Retrieve the vertex each face corner is attached to
Attributes
| Name | Description |
|---|---|
| i_corner_index | Input socket: Corner Index |
| name | |
| node | |
| o_vertex_index | Output socket: Vertex Index |
| tree | |
| type |
ViewportTransform
nodes.geometry.input.ViewportTransform()Retrieve the view direction and location of the 3D viewport
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_is_orthographic | Output socket: Is Orthographic |
| o_projection | Output socket: Projection |
| o_view | Output socket: View |
| tree | |
| type |
VoxelIndex
nodes.geometry.input.VoxelIndex()Retrieve the integer coordinates of the voxel that the field is evaluated on
Attributes
| Name | Description |
|---|---|
| name | |
| node | |
| o_extent_x | Output socket: Extent X |
| o_extent_y | Output socket: Extent Y |
| o_extent_z | Output socket: Extent Z |
| o_is_tile | Output socket: Is Tile |
| o_x | Output socket: X |
| o_y | Output socket: Y |
| o_z | Output socket: Z |
| tree | |
| type |