nodes.geometry.texture
texture
Classes
| Name | Description |
|---|---|
| BrickTexture | Generate a procedural texture producing bricks |
| CheckerTexture | Generate a checkerboard texture |
| GaborTexture | Generate Gabor noise |
| GradientTexture | Generate interpolated color and intensity values based on the input vector |
| ImageTexture | Sample values from an image texture |
| MagicTexture | Generate a psychedelic color texture |
| NoiseTexture | Generate fractal Perlin noise |
| VoronoiTexture | Generate Worley noise based on the distance to random points. Typically used to generate textures such as stones, water, or biological cells |
| WaveTexture | Generate procedural bands or rings with noise |
| WhiteNoiseTexture | Calculate a random value or color based on an input seed |
BrickTexture
BrickTexture(
vector=None,
color1=None,
color2=None,
mortar=None,
scale=5.0,
mortar_size=0.02,
mortar_smooth=0.1,
bias=0.0,
brick_width=0.5,
row_height=0.25,
*,
offset_frequency=2,
squash_frequency=2,
offset=0.5,
squash=1.0,
)Generate a procedural texture producing bricks
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vector | InputVector | Vector | None |
| color1 | InputColor | Color1 | None |
| color2 | InputColor | Color2 | None |
| mortar | InputColor | Mortar | None |
| scale | InputFloat | Scale | 5.0 |
| mortar_size | InputFloat | Mortar Size | 0.02 |
| mortar_smooth | InputFloat | Mortar Smooth | 0.1 |
| bias | InputFloat | Bias | 0.0 |
| brick_width | InputFloat | Brick Width | 0.5 |
| row_height | InputFloat | Row Height | 0.25 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
offset |
|
offset_frequency |
|
outputs |
|
squash |
|
squash_frequency |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vector |
VectorSocket |
Vector |
i.color1 |
ColorSocket |
Color1 |
i.color2 |
ColorSocket |
Color2 |
i.mortar |
ColorSocket |
Mortar |
i.scale |
FloatSocket |
Scale |
i.mortar_size |
FloatSocket |
Mortar Size |
i.mortar_smooth |
FloatSocket |
Mortar Smooth |
i.bias |
FloatSocket |
Bias |
i.brick_width |
FloatSocket |
Brick Width |
i.row_height |
FloatSocket |
Row Height |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.color |
ColorSocket |
Color |
o.fac |
FloatSocket |
Factor |
CheckerTexture
CheckerTexture(vector=None, color1=None, color2=None, scale=5.0)Generate a checkerboard texture
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vector | InputVector | Vector | None |
| color1 | InputColor | Color1 | None |
| color2 | InputColor | Color2 | None |
| scale | InputFloat | Scale | 5.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vector |
VectorSocket |
Vector |
i.color1 |
ColorSocket |
Color1 |
i.color2 |
ColorSocket |
Color2 |
i.scale |
FloatSocket |
Scale |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.color |
ColorSocket |
Color |
o.fac |
FloatSocket |
Factor |
GaborTexture
GaborTexture(
vector=None,
scale=5.0,
frequency=2.0,
anisotropy=1.0,
orientation_2d=0.7854,
orientation_3d=None,
*,
gabor_type='2D',
)Generate Gabor noise
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vector | InputVector | Vector | None |
| scale | InputFloat | Scale | 5.0 |
| frequency | InputFloat | Frequency | 2.0 |
| anisotropy | InputFloat | Anisotropy | 1.0 |
| orientation_2d | InputFloat | Orientation | 0.7854 |
| orientation_3d | InputVector | Orientation | None |
Attributes
| Name | Description |
|---|---|
gabor_type |
|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| input_2d | Create Gabor Texture with operation ‘2D’. Use the 2D vector (X, Y) as input. The Z component is ignored. |
| input_3d | Create Gabor Texture with operation ‘3D’. Use the 3D vector (X, Y, Z) as input |
input_2d
input_2d(
vector=None,
scale=5.0,
frequency=2.0,
anisotropy=1.0,
orientation_2d=0.7854,
)Create Gabor Texture with operation ‘2D’. Use the 2D vector (X, Y) as input. The Z component is ignored.
input_3d
input_3d(
vector=None,
scale=5.0,
frequency=2.0,
anisotropy=1.0,
orientation_3d=None,
)Create Gabor Texture with operation ‘3D’. Use the 3D vector (X, Y, Z) as input
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vector |
VectorSocket |
Vector |
i.scale |
FloatSocket |
Scale |
i.frequency |
FloatSocket |
Frequency |
i.anisotropy |
FloatSocket |
Anisotropy |
i.orientation_2d |
FloatSocket |
Orientation |
i.orientation_3d |
VectorSocket |
Orientation |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.value |
FloatSocket |
Value |
o.phase |
FloatSocket |
Phase |
o.intensity |
FloatSocket |
Intensity |
GradientTexture
GradientTexture(vector=None, *, gradient_type='LINEAR')Generate interpolated color and intensity values based on the input vector
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vector | InputVector | Vector | None |
Attributes
| Name | Description |
|---|---|
gradient_type |
|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| diagonal | Create Gradient Texture with operation ‘Diagonal’. Create a diagonal progression |
| easing | Create Gradient Texture with operation ‘Easing’. Create a progression easing from one step to the next |
| linear | Create Gradient Texture with operation ‘Linear’. Create a linear progression |
| quadratic | Create Gradient Texture with operation ‘Quadratic’. Create a quadratic progression |
| quadratic_sphere | Create Gradient Texture with operation ‘Quadratic Sphere’. Create a quadratic progression in the shape of a sphere |
| radial | Create Gradient Texture with operation ‘Radial’. Create a radial progression |
| spherical | Create Gradient Texture with operation ‘Spherical’. Create a spherical progression |
diagonal
diagonal(vector=None)Create Gradient Texture with operation ‘Diagonal’. Create a diagonal progression
easing
easing(vector=None)Create Gradient Texture with operation ‘Easing’. Create a progression easing from one step to the next
linear
linear(vector=None)Create Gradient Texture with operation ‘Linear’. Create a linear progression
quadratic
quadratic(vector=None)Create Gradient Texture with operation ‘Quadratic’. Create a quadratic progression
quadratic_sphere
quadratic_sphere(vector=None)Create Gradient Texture with operation ‘Quadratic Sphere’. Create a quadratic progression in the shape of a sphere
radial
radial(vector=None)Create Gradient Texture with operation ‘Radial’. Create a radial progression
spherical
spherical(vector=None)Create Gradient Texture with operation ‘Spherical’. Create a spherical progression
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vector |
VectorSocket |
Vector |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.color |
ColorSocket |
Color |
o.fac |
FloatSocket |
Factor |
ImageTexture
ImageTexture(
image=None,
vector=None,
frame=0,
*,
interpolation='Linear',
extension='REPEAT',
)Sample values from an image texture
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| image | InputImage | Image | None |
| vector | InputVector | Vector | None |
| frame | InputInteger | Frame | 0 |
Attributes
| Name | Description |
|---|---|
extension |
|
i |
|
inputs |
|
interpolation |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.image |
ImageSocket |
Image |
i.vector |
VectorSocket |
Vector |
i.frame |
IntegerSocket |
Frame |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.color |
ColorSocket |
Color |
o.alpha |
FloatSocket |
Alpha |
MagicTexture
MagicTexture(vector=None, scale=5.0, distortion=1.0, *, turbulence_depth=0)Generate a psychedelic color texture
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vector | InputVector | Vector | None |
| scale | InputFloat | Scale | 5.0 |
| distortion | InputFloat | Distortion | 1.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
turbulence_depth |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vector |
VectorSocket |
Vector |
i.scale |
FloatSocket |
Scale |
i.distortion |
FloatSocket |
Distortion |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.color |
ColorSocket |
Color |
o.fac |
FloatSocket |
Factor |
NoiseTexture
NoiseTexture(
vector=None,
w=0.0,
scale=5.0,
detail=2.0,
roughness=0.5,
lacunarity=2.0,
offset=0.0,
gain=1.0,
distortion=0.0,
*,
noise_dimensions='3D',
noise_type='FBM',
normalize=False,
)Generate fractal Perlin noise
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vector | InputVector | Vector | None |
| w | InputFloat | W | 0.0 |
| scale | InputFloat | Scale | 5.0 |
| detail | InputFloat | Detail | 2.0 |
| roughness | InputFloat | Roughness | 0.5 |
| lacunarity | InputFloat | Lacunarity | 2.0 |
| offset | InputFloat | Offset | 0.0 |
| gain | InputFloat | Gain | 1.0 |
| distortion | InputFloat | Distortion | 0.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
noise_dimensions |
|
noise_type |
|
normalize |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| fbm | Create Noise Texture with operation ‘fBM’. The standard fractal Perlin noise |
| hetero_terrain | Create Noise Texture with operation ‘Hetero Terrain’. Similar to Hybrid Multifractal creates a heterogeneous terrain, but with the likeness of river channels |
| hybrid_multifractal | Create Noise Texture with operation ‘Hybrid Multifractal’. Create peaks and valleys with different roughness values |
| multifractal | Create Noise Texture with operation ‘Multifractal’. More uneven result (varies with location), more similar to a real terrain |
| ridged_multifractal | Create Noise Texture with operation ‘Ridged Multifractal’. Create sharp peaks |
fbm
fbm(
vector=None,
scale=5.0,
detail=2.0,
roughness=0.5,
lacunarity=2.0,
distortion=0.0,
)Create Noise Texture with operation ‘fBM’. The standard fractal Perlin noise
hetero_terrain
hetero_terrain(
vector=None,
scale=5.0,
detail=2.0,
roughness=0.5,
lacunarity=2.0,
offset=0.0,
distortion=0.0,
)Create Noise Texture with operation ‘Hetero Terrain’. Similar to Hybrid Multifractal creates a heterogeneous terrain, but with the likeness of river channels
hybrid_multifractal
hybrid_multifractal(
vector=None,
scale=5.0,
detail=2.0,
roughness=0.5,
lacunarity=2.0,
offset=0.0,
gain=1.0,
distortion=0.0,
)Create Noise Texture with operation ‘Hybrid Multifractal’. Create peaks and valleys with different roughness values
multifractal
multifractal(
vector=None,
scale=5.0,
detail=2.0,
roughness=0.5,
lacunarity=2.0,
distortion=0.0,
)Create Noise Texture with operation ‘Multifractal’. More uneven result (varies with location), more similar to a real terrain
ridged_multifractal
ridged_multifractal(
vector=None,
scale=5.0,
detail=2.0,
roughness=0.5,
lacunarity=2.0,
offset=0.0,
gain=1.0,
distortion=0.0,
)Create Noise Texture with operation ‘Ridged Multifractal’. Create sharp peaks
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vector |
VectorSocket |
Vector |
i.w |
FloatSocket |
W |
i.scale |
FloatSocket |
Scale |
i.detail |
FloatSocket |
Detail |
i.roughness |
FloatSocket |
Roughness |
i.lacunarity |
FloatSocket |
Lacunarity |
i.offset |
FloatSocket |
Offset |
i.gain |
FloatSocket |
Gain |
i.distortion |
FloatSocket |
Distortion |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.fac |
FloatSocket |
Factor |
o.color |
ColorSocket |
Color |
VoronoiTexture
VoronoiTexture(
vector=None,
w=0.0,
scale=5.0,
detail=0.0,
roughness=0.5,
lacunarity=2.0,
smoothness=1.0,
exponent=0.5,
randomness=1.0,
*,
voronoi_dimensions='3D',
distance='EUCLIDEAN',
feature='F1',
normalize=False,
)Generate Worley noise based on the distance to random points. Typically used to generate textures such as stones, water, or biological cells
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vector | InputVector | Vector | None |
| w | InputFloat | W | 0.0 |
| scale | InputFloat | Scale | 5.0 |
| detail | InputFloat | Detail | 0.0 |
| roughness | InputFloat | Roughness | 0.5 |
| lacunarity | InputFloat | Lacunarity | 2.0 |
| smoothness | InputFloat | Smoothness | 1.0 |
| exponent | InputFloat | Exponent | 0.5 |
| randomness | InputFloat | Randomness | 1.0 |
Attributes
| Name | Description |
|---|---|
distance |
|
feature |
|
i |
|
inputs |
|
name |
|
node |
|
normalize |
|
o |
|
outputs |
|
tree |
|
type |
|
voronoi_dimensions |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vector |
VectorSocket |
Vector |
i.w |
FloatSocket |
W |
i.scale |
FloatSocket |
Scale |
i.detail |
FloatSocket |
Detail |
i.roughness |
FloatSocket |
Roughness |
i.lacunarity |
FloatSocket |
Lacunarity |
i.smoothness |
FloatSocket |
Smoothness |
i.exponent |
FloatSocket |
Exponent |
i.randomness |
FloatSocket |
Randomness |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.distance |
FloatSocket |
Distance |
o.color |
ColorSocket |
Color |
o.position |
VectorSocket |
Position |
o.w |
FloatSocket |
W |
o.radius |
FloatSocket |
Radius |
WaveTexture
WaveTexture(
vector=None,
scale=5.0,
distortion=0.0,
detail=2.0,
detail_scale=1.0,
detail_roughness=0.5,
phase_offset=0.0,
*,
wave_type='BANDS',
bands_direction='X',
rings_direction='X',
wave_profile='SIN',
)Generate procedural bands or rings with noise
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vector | InputVector | Vector | None |
| scale | InputFloat | Scale | 5.0 |
| distortion | InputFloat | Distortion | 0.0 |
| detail | InputFloat | Detail | 2.0 |
| detail_scale | InputFloat | Detail Scale | 1.0 |
| detail_roughness | InputFloat | Detail Roughness | 0.5 |
| phase_offset | InputFloat | Phase Offset | 0.0 |
Attributes
| Name | Description |
|---|---|
bands_direction |
|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
rings_direction |
|
tree |
|
type |
|
wave_profile |
|
wave_type |
Methods
| Name | Description |
|---|---|
| bands | Create Wave Texture with operation ‘Bands’. Use standard wave texture in bands |
| rings | Create Wave Texture with operation ‘Rings’. Use wave texture in rings |
bands
bands(
vector=None,
scale=5.0,
distortion=0.0,
detail=2.0,
detail_scale=1.0,
detail_roughness=0.5,
phase_offset=0.0,
)Create Wave Texture with operation ‘Bands’. Use standard wave texture in bands
rings
rings(
vector=None,
scale=5.0,
distortion=0.0,
detail=2.0,
detail_scale=1.0,
detail_roughness=0.5,
phase_offset=0.0,
)Create Wave Texture with operation ‘Rings’. Use wave texture in rings
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vector |
VectorSocket |
Vector |
i.scale |
FloatSocket |
Scale |
i.distortion |
FloatSocket |
Distortion |
i.detail |
FloatSocket |
Detail |
i.detail_scale |
FloatSocket |
Detail Scale |
i.detail_roughness |
FloatSocket |
Detail Roughness |
i.phase_offset |
FloatSocket |
Phase Offset |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.color |
ColorSocket |
Color |
o.fac |
FloatSocket |
Factor |
WhiteNoiseTexture
WhiteNoiseTexture(vector=None, w=0.0, *, noise_dimensions='3D')Calculate a random value or color based on an input seed
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vector | InputVector | Vector | None |
| w | InputFloat | W | 0.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
noise_dimensions |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vector |
VectorSocket |
Vector |
i.w |
FloatSocket |
W |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.value |
FloatSocket |
Value |
o.color |
ColorSocket |
Color |