nodes.geometry.texture

nodes.geometry.texture

Classes

Name Description
BrickTexture Generate a procedural texture producing bricks
CheckerTexture Generate a checkerboard texture
GaborTexture Generate Gabor noise
GradientTexture Generate interpolated color and intensity values based on the input vector
ImageTexture Sample values from an image texture
MagicTexture Generate a psychedelic color texture
NoiseTexture Generate fractal Perlin noise
VoronoiTexture Generate Worley noise based on the distance to random points. Typically used to generate textures such as stones, water, or biological cells
WaveTexture Generate procedural bands or rings with noise
WhiteNoiseTexture Calculate a random value or color based on an input seed

BrickTexture

nodes.geometry.texture.BrickTexture(
    vector=None,
    color1=None,
    color2=None,
    mortar=None,
    scale=5.0,
    mortar_size=0.02,
    mortar_smooth=0.1,
    bias=0.0,
    brick_width=0.5,
    row_height=0.25,
    *,
    offset_frequency=2,
    squash_frequency=2,
    offset=0.5,
    squash=1.0,
)

Generate a procedural texture producing bricks

Attributes

Name Description
i_bias Input socket: Bias
i_brick_width Input socket: Brick Width
i_color1 Input socket: Color1
i_color2 Input socket: Color2
i_mortar Input socket: Mortar
i_mortar_size Input socket: Mortar Size
i_mortar_smooth Input socket: Mortar Smooth
i_row_height Input socket: Row Height
i_scale Input socket: Scale
i_vector Input socket: Vector
name
node
o_color Output socket: Color
o_fac Output socket: Factor
offset
offset_frequency
squash
squash_frequency
tree
type

CheckerTexture

nodes.geometry.texture.CheckerTexture(
    vector=None,
    color1=None,
    color2=None,
    scale=5.0,
)

Generate a checkerboard texture

Attributes

Name Description
i_color1 Input socket: Color1
i_color2 Input socket: Color2
i_scale Input socket: Scale
i_vector Input socket: Vector
name
node
o_color Output socket: Color
o_fac Output socket: Factor
tree
type

GaborTexture

nodes.geometry.texture.GaborTexture(
    vector=None,
    scale=5.0,
    frequency=2.0,
    anisotropy=1.0,
    orientation_2d=0.7854,
    orientation_3d=None,
    *,
    gabor_type='2D',
)

Generate Gabor noise

Attributes

Name Description
gabor_type
i_anisotropy Input socket: Anisotropy
i_frequency Input socket: Frequency
i_orientation_2d Input socket: Orientation
i_orientation_3d Input socket: Orientation
i_scale Input socket: Scale
i_vector Input socket: Vector
name
node
o_intensity Output socket: Intensity
o_phase Output socket: Phase
o_value Output socket: Value
tree
type

GradientTexture

nodes.geometry.texture.GradientTexture(vector=None, *, gradient_type='LINEAR')

Generate interpolated color and intensity values based on the input vector

Attributes

Name Description
gradient_type
i_vector Input socket: Vector
name
node
o_color Output socket: Color
o_fac Output socket: Factor
tree
type

ImageTexture

nodes.geometry.texture.ImageTexture(
    image=None,
    vector=None,
    frame=0,
    *,
    interpolation='Linear',
    extension='REPEAT',
)

Sample values from an image texture

Attributes

Name Description
extension
i_frame Input socket: Frame
i_image Input socket: Image
i_vector Input socket: Vector
interpolation
name
node
o_alpha Output socket: Alpha
o_color Output socket: Color
tree
type

MagicTexture

nodes.geometry.texture.MagicTexture(
    vector=None,
    scale=5.0,
    distortion=1.0,
    *,
    turbulence_depth=0,
)

Generate a psychedelic color texture

Attributes

Name Description
i_distortion Input socket: Distortion
i_scale Input socket: Scale
i_vector Input socket: Vector
name
node
o_color Output socket: Color
o_fac Output socket: Factor
tree
turbulence_depth
type

NoiseTexture

nodes.geometry.texture.NoiseTexture(
    vector=None,
    w=0.0,
    scale=5.0,
    detail=2.0,
    roughness=0.5,
    lacunarity=2.0,
    offset=0.0,
    gain=1.0,
    distortion=0.0,
    *,
    noise_dimensions='3D',
    noise_type='FBM',
    normalize=False,
)

Generate fractal Perlin noise

Attributes

Name Description
i_detail Input socket: Detail
i_distortion Input socket: Distortion
i_gain Input socket: Gain
i_lacunarity Input socket: Lacunarity
i_offset Input socket: Offset
i_roughness Input socket: Roughness
i_scale Input socket: Scale
i_vector Input socket: Vector
i_w Input socket: W
name
node
noise_dimensions
noise_type
normalize
o_color Output socket: Color
o_fac Output socket: Factor
tree
type

VoronoiTexture

nodes.geometry.texture.VoronoiTexture(
    vector=None,
    w=0.0,
    scale=5.0,
    detail=0.0,
    roughness=0.5,
    lacunarity=2.0,
    smoothness=1.0,
    exponent=0.5,
    randomness=1.0,
    *,
    voronoi_dimensions='3D',
    distance='EUCLIDEAN',
    feature='F1',
    normalize=False,
)

Generate Worley noise based on the distance to random points. Typically used to generate textures such as stones, water, or biological cells

Attributes

Name Description
distance
feature
i_detail Input socket: Detail
i_exponent Input socket: Exponent
i_lacunarity Input socket: Lacunarity
i_randomness Input socket: Randomness
i_roughness Input socket: Roughness
i_scale Input socket: Scale
i_smoothness Input socket: Smoothness
i_vector Input socket: Vector
i_w Input socket: W
name
node
normalize
o_color Output socket: Color
o_distance Output socket: Distance
o_position Output socket: Position
o_radius Output socket: Radius
o_w Output socket: W
tree
type
voronoi_dimensions

WaveTexture

nodes.geometry.texture.WaveTexture(
    vector=None,
    scale=5.0,
    distortion=0.0,
    detail=2.0,
    detail_scale=1.0,
    detail_roughness=0.5,
    phase_offset=0.0,
    *,
    wave_type='BANDS',
    bands_direction='X',
    rings_direction='X',
    wave_profile='SIN',
)

Generate procedural bands or rings with noise

Attributes

Name Description
bands_direction
i_detail Input socket: Detail
i_detail_roughness Input socket: Detail Roughness
i_detail_scale Input socket: Detail Scale
i_distortion Input socket: Distortion
i_phase_offset Input socket: Phase Offset
i_scale Input socket: Scale
i_vector Input socket: Vector
name
node
o_color Output socket: Color
o_fac Output socket: Factor
rings_direction
tree
type
wave_profile
wave_type

WhiteNoiseTexture

nodes.geometry.texture.WhiteNoiseTexture(
    vector=None,
    w=0.0,
    *,
    noise_dimensions='3D',
)

Calculate a random value or color based on an input seed

Attributes

Name Description
i_vector Input socket: Vector
i_w Input socket: W
name
node
noise_dimensions
o_color Output socket: Color
o_value Output socket: Value
tree
type