nodes.geometry.vector
vector
Classes
| Name | Description |
|---|---|
| RadialTiling | Transform Coordinate System for Radial Tiling |
| VectorCurves | Map input vector components with curves |
| VectorMath | Perform vector math operation |
| VectorRotate | Rotate a vector around a pivot point (center) |
RadialTiling
RadialTiling(vector=None, sides=5.0, roundness=0.0, *, normalize=False)Transform Coordinate System for Radial Tiling
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vector | InputVector | Vector | None |
| sides | InputFloat | Sides | 5.0 |
| roundness | InputFloat | Roundness | 0.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
normalize |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vector |
VectorSocket |
Vector |
i.sides |
FloatSocket |
Sides |
i.roundness |
FloatSocket |
Roundness |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.segment_coordinates |
VectorSocket |
Segment Coordinates |
o.segment_id |
FloatSocket |
Segment ID |
o.segment_width |
FloatSocket |
Segment Width |
o.segment_rotation |
FloatSocket |
Segment Rotation |
VectorCurves
VectorCurves(fac=1.0, vector=None)Map input vector components with curves
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| fac | InputFloat | Factor | 1.0 |
| vector | InputVector | Vector | None |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.fac |
FloatSocket |
Factor |
i.vector |
VectorSocket |
Vector |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.vector |
VectorSocket |
Vector |
VectorMath
VectorMath(
vector=None,
vector_001=None,
vector_002=None,
scale=1.0,
*,
operation='ADD',
)Perform vector math operation
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vector | InputVector | Vector | None |
| vector_001 | InputVector | Vector | None |
| vector_002 | InputVector | Vector | None |
| scale | InputFloat | Scale | 1.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
operation |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| absolute | Create Vector Math with operation ‘Absolute’. Entry-wise absolute |
| add | Create Vector Math with operation ‘Add’. A + B |
| ceil | Create Vector Math with operation ‘Ceil’. Entry-wise ceil |
| cosine | Create Vector Math with operation ‘Cosine’. Entry-wise cos(A) |
| cross_product | Create Vector Math with operation ‘Cross Product’. A cross B |
| distance | Create Vector Math with operation ‘Distance’. Distance between A and B |
| divide | Create Vector Math with operation ‘Divide’. Entry-wise divide |
| dot_product | Create Vector Math with operation ‘Dot Product’. A dot B |
| faceforward | Create Vector Math with operation ‘Faceforward’. Orients a vector A to point away from a surface B as defined by its normal C. Returns (dot(B, C) < 0) ? A : -A |
| floor | Create Vector Math with operation ‘Floor’. Entry-wise floor |
| fraction | Create Vector Math with operation ‘Fraction’. The fraction part of A entry-wise |
| length | Create Vector Math with operation ‘Length’. Length of A |
| maximum | Create Vector Math with operation ‘Maximum’. Entry-wise maximum |
| minimum | Create Vector Math with operation ‘Minimum’. Entry-wise minimum |
| modulo | Create Vector Math with operation ‘Modulo’. Entry-wise modulo using fmod(A,B) |
| multiply | Create Vector Math with operation ‘Multiply’. Entry-wise multiply |
| multiply_add | Create Vector Math with operation ‘Multiply Add’. A * B + C |
| normalize | Create Vector Math with operation ‘Normalize’. Normalize A |
| power | Create Vector Math with operation ‘Power’. Entry-wise power |
| project | Create Vector Math with operation ‘Project’. Project A onto B |
| reflect | Create Vector Math with operation ‘Reflect’. Reflect A around the normal B. B does not need to be normalized. |
| refract | Create Vector Math with operation ‘Refract’. For a given incident vector A, surface normal B and ratio of indices of refraction, Ior, refract returns the refraction vector, R |
| scale | Create Vector Math with operation ‘Scale’. A multiplied by Scale |
| sign | Create Vector Math with operation ‘Sign’. Entry-wise sign |
| sine | Create Vector Math with operation ‘Sine’. Entry-wise sin(A) |
| snap | Create Vector Math with operation ‘Snap’. Round A to the largest integer multiple of B less than or equal A |
| subtract | Create Vector Math with operation ‘Subtract’. A - B |
| tangent | Create Vector Math with operation ‘Tangent’. Entry-wise tan(A) |
| wrap | Create Vector Math with operation ‘Wrap’. Entry-wise wrap(A,B) |
absolute
absolute(vector=None)Create Vector Math with operation ‘Absolute’. Entry-wise absolute
add
add(vector=None, vector_001=None)Create Vector Math with operation ‘Add’. A + B
ceil
ceil(vector=None)Create Vector Math with operation ‘Ceil’. Entry-wise ceil
cosine
cosine(vector=None)Create Vector Math with operation ‘Cosine’. Entry-wise cos(A)
cross_product
cross_product(vector=None, vector_001=None)Create Vector Math with operation ‘Cross Product’. A cross B
distance
distance(vector=None, vector_001=None)Create Vector Math with operation ‘Distance’. Distance between A and B
divide
divide(vector=None, vector_001=None)Create Vector Math with operation ‘Divide’. Entry-wise divide
dot_product
dot_product(vector=None, vector_001=None)Create Vector Math with operation ‘Dot Product’. A dot B
faceforward
faceforward(vector=None, vector_001=None, vector_002=None)Create Vector Math with operation ‘Faceforward’. Orients a vector A to point away from a surface B as defined by its normal C. Returns (dot(B, C) < 0) ? A : -A
floor
floor(vector=None)Create Vector Math with operation ‘Floor’. Entry-wise floor
fraction
fraction(vector=None)Create Vector Math with operation ‘Fraction’. The fraction part of A entry-wise
length
length(vector=None)Create Vector Math with operation ‘Length’. Length of A
maximum
maximum(vector=None, vector_001=None)Create Vector Math with operation ‘Maximum’. Entry-wise maximum
minimum
minimum(vector=None, vector_001=None)Create Vector Math with operation ‘Minimum’. Entry-wise minimum
modulo
modulo(vector=None, vector_001=None)Create Vector Math with operation ‘Modulo’. Entry-wise modulo using fmod(A,B)
multiply
multiply(vector=None, vector_001=None)Create Vector Math with operation ‘Multiply’. Entry-wise multiply
multiply_add
multiply_add(vector=None, vector_001=None, vector_002=None)Create Vector Math with operation ‘Multiply Add’. A * B + C
normalize
normalize(vector=None)Create Vector Math with operation ‘Normalize’. Normalize A
power
power(vector=None, vector_001=None)Create Vector Math with operation ‘Power’. Entry-wise power
project
project(vector=None, vector_001=None)Create Vector Math with operation ‘Project’. Project A onto B
reflect
reflect(vector=None, vector_001=None)Create Vector Math with operation ‘Reflect’. Reflect A around the normal B. B does not need to be normalized.
refract
refract(vector=None, vector_001=None, scale=1.0)Create Vector Math with operation ‘Refract’. For a given incident vector A, surface normal B and ratio of indices of refraction, Ior, refract returns the refraction vector, R
scale
scale(vector=None, scale=1.0)Create Vector Math with operation ‘Scale’. A multiplied by Scale
sign
sign(vector=None)Create Vector Math with operation ‘Sign’. Entry-wise sign
sine
sine(vector=None)Create Vector Math with operation ‘Sine’. Entry-wise sin(A)
snap
snap(vector=None, vector_001=None)Create Vector Math with operation ‘Snap’. Round A to the largest integer multiple of B less than or equal A
subtract
subtract(vector=None, vector_001=None)Create Vector Math with operation ‘Subtract’. A - B
tangent
tangent(vector=None)Create Vector Math with operation ‘Tangent’. Entry-wise tan(A)
wrap
wrap(vector=None, vector_001=None, vector_002=None)Create Vector Math with operation ‘Wrap’. Entry-wise wrap(A,B)
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vector |
VectorSocket |
Vector |
i.vector_001 |
VectorSocket |
Vector |
i.vector_002 |
VectorSocket |
Vector |
i.scale |
FloatSocket |
Scale |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.vector |
VectorSocket |
Vector |
o.value |
FloatSocket |
Value |
VectorRotate
VectorRotate(
vector=None,
center=None,
axis=None,
angle=0.0,
rotation=None,
*,
rotation_type='AXIS_ANGLE',
invert=False,
)Rotate a vector around a pivot point (center)
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vector | InputVector | Vector | None |
| center | InputVector | Center | None |
| axis | InputVector | Axis | None |
| angle | InputFloat | Angle | 0.0 |
| rotation | InputVector | Rotation | None |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
invert |
|
name |
|
node |
|
o |
|
outputs |
|
rotation_type |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| axis_angle | Create Vector Rotate with operation ‘Axis Angle’. Rotate a point using axis angle |
| euler | Create Vector Rotate with operation ‘Euler’. Rotate a point using XYZ order |
| x_axis | Create Vector Rotate with operation ‘X Axis’. Rotate a point using X axis |
| y_axis | Create Vector Rotate with operation ‘Y Axis’. Rotate a point using Y axis |
| z_axis | Create Vector Rotate with operation ‘Z Axis’. Rotate a point using Z axis |
axis_angle
axis_angle(vector=None, center=None, axis=None, angle=0.0)Create Vector Rotate with operation ‘Axis Angle’. Rotate a point using axis angle
euler
euler(vector=None, center=None, rotation=None)Create Vector Rotate with operation ‘Euler’. Rotate a point using XYZ order
x_axis
x_axis(vector=None, center=None, angle=0.0)Create Vector Rotate with operation ‘X Axis’. Rotate a point using X axis
y_axis
y_axis(vector=None, center=None, angle=0.0)Create Vector Rotate with operation ‘Y Axis’. Rotate a point using Y axis
z_axis
z_axis(vector=None, center=None, angle=0.0)Create Vector Rotate with operation ‘Z Axis’. Rotate a point using Z axis
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vector |
VectorSocket |
Vector |
i.center |
VectorSocket |
Center |
i.axis |
VectorSocket |
Axis |
i.angle |
FloatSocket |
Angle |
i.rotation |
VectorSocket |
Rotation |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.vector |
VectorSocket |
Vector |