nodes.geometry.zone
zone
Classes
| Name | Description |
|---|---|
| BaseRepeatZone | |
| BaseSimulationZone | |
| BaseZone | |
| BaseZoneInput | Base class for zone input nodes |
| BaseZoneOutput | Base class for zone output nodes |
| ClosureInput | Closure Input node |
| ClosureOutput | Closure Output node |
| ClosureZone | |
| ForEachGeometryElementInput | For Each Geometry Element Input node |
| ForEachGeometryElementOutput | For Each Geometry Element Output node |
| ForEachGeometryElementZone | |
| RepeatInput | Repeat Input node |
| RepeatOutput | Repeat Output node |
| RepeatZone | Wrapper that supports both direct unpacking and iteration |
| SimulationInput | Simulation Input node |
| SimulationOutput | Simulation Output node |
| SimulationZone |
BaseRepeatZone
BaseRepeatZone(node=None)Attributes
| Name | Description |
|---|---|
i |
Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING. |
items |
|
name |
|
node |
|
o |
Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING. |
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| capture | Capture something as an input to the simulation |
capture
capture(value, domain='POINT')Capture something as an input to the simulation
BaseSimulationZone
BaseSimulationZone(node=None)Attributes
| Name | Description |
|---|---|
i |
Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING. |
items |
|
name |
|
node |
|
o |
Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING. |
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| capture | Capture something as an input to the simulation |
capture
capture(value, domain='POINT')Capture something as an input to the simulation
BaseZone
BaseZone(node=None)Attributes
| Name | Description |
|---|---|
i |
Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING. |
items |
Return the items collection |
name |
|
node |
|
o |
Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING. |
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| capture | Capture something as an input to the simulation |
capture
capture(value, domain='POINT')Capture something as an input to the simulation
BaseZoneInput
BaseZoneInput(node=None)Base class for zone input nodes
Attributes
| Name | Description |
|---|---|
i |
Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING. |
items |
Return the items collection |
name |
|
node |
|
o |
Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING. |
output |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| capture | Capture something as an input to the simulation |
capture
capture(value, domain='POINT')Capture something as an input to the simulation
BaseZoneOutput
BaseZoneOutput(node=None)Base class for zone output nodes
Attributes
| Name | Description |
|---|---|
i |
Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING. |
items |
Return the items collection |
name |
|
node |
|
o |
Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING. |
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| capture | Capture something as an input to the simulation |
capture
capture(value, domain='POINT')Capture something as an input to the simulation
ClosureInput
ClosureInput()Closure Input node
Attributes
| Name | Description |
|---|---|
i |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| link |
link
link(target)ClosureOutput
ClosureOutput(define_signature=False)Closure Output node
Attributes
| Name | Description |
|---|---|
define_signature |
|
i |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| link | |
| sync_signature |
link
link(source)sync_signature
sync_signature(node)Outputs
| Attribute | Type | Description |
|---|---|---|
o.closure |
ClosureSocket |
Closure |
ClosureZone
ClosureZone()Attributes
| Name | Description |
|---|---|
input |
|
output |
ForEachGeometryElementInput
ForEachGeometryElementInput(geometry=None, selection=True)For Each Geometry Element Input node
Attributes
| Name | Description |
|---|---|
i |
|
items |
|
name |
|
node |
|
o |
|
output |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| capture | Capture something as an input to the simulation |
capture
capture(value, domain='POINT')Capture something as an input to the simulation
ForEachGeometryElementOutput
ForEachGeometryElementOutput(domain='POINT', **kwargs)For Each Geometry Element Output node
Attributes
| Name | Description |
|---|---|
domain |
|
i |
|
items |
|
items_generated |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| capture | Capture something as an input to the simulation |
| capture_generated |
capture
capture(value, domain='POINT')Capture something as an input to the simulation
capture_generated
capture_generated(value)ForEachGeometryElementZone
ForEachGeometryElementZone(geometry=None, selection=True, *, domain='POINT')Attributes
| Name | Description |
|---|---|
index |
|
input |
|
output |
RepeatInput
RepeatInput(iterations=1)Repeat Input node
Attributes
| Name | Description |
|---|---|
i |
Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING. |
items |
|
name |
|
node |
|
o |
|
output |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| capture | Capture something as an input to the simulation |
capture
capture(value, domain='POINT')Capture something as an input to the simulation
RepeatOutput
RepeatOutput(node=None)Repeat Output node
Attributes
| Name | Description |
|---|---|
i |
Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING. |
items |
|
name |
|
node |
|
o |
Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING. |
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| capture | Capture something as an input to the simulation |
capture
capture(value, domain='POINT')Capture something as an input to the simulation
RepeatZone
RepeatZone(iterations=1, items={})Wrapper that supports both direct unpacking and iteration
Attributes
| Name | Description |
|---|---|
input |
|
iteration |
The current iteration index. |
output |
SimulationInput
SimulationInput(node=None)Simulation Input node
Attributes
| Name | Description |
|---|---|
i |
Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING. |
items |
|
name |
|
node |
|
o |
|
output |
|
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| capture | Capture something as an input to the simulation |
capture
capture(value, domain='POINT')Capture something as an input to the simulation
SimulationOutput
SimulationOutput(node=None)Simulation Output node
Attributes
| Name | Description |
|---|---|
i |
|
items |
|
name |
|
node |
|
o |
Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING. |
outputs |
|
tree |
|
type |
Methods
| Name | Description |
|---|---|
| capture | Capture something as an input to the simulation |
capture
capture(value, domain='POINT')Capture something as an input to the simulation
SimulationZone
SimulationZone(items={})Attributes
| Name | Description |
|---|---|
delta_time |
|
input |
|
output |