nodes.geometry.zone

zone

Classes

Name Description
BaseRepeatZone
BaseSimulationZone
BaseZone
BaseZoneInput Base class for zone input nodes
BaseZoneOutput Base class for zone output nodes
ForEachGeometryElementInput For Each Geometry Element Input node
ForEachGeometryElementOutput For Each Geometry Element Output node
ForEachGeometryElementZone
RepeatInput Repeat Input node
RepeatOutput Repeat Output node
RepeatZone Wrapper that supports both direct unpacking and iteration
SimulationInput Simulation Input node
SimulationOutput Simulation Output node
SimulationZone

BaseRepeatZone

BaseRepeatZone()

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
inputs
items
name
node
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
outputs
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
capture(value, domain='POINT')

Capture something as an input to the simulation

BaseSimulationZone

BaseSimulationZone()

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
inputs
items
name
node
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
outputs
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
capture(value, domain='POINT')

Capture something as an input to the simulation

BaseZone

BaseZone()

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
inputs
items Return the items collection
name
node
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
outputs
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
capture(value, domain='POINT')

Capture something as an input to the simulation

BaseZoneInput

BaseZoneInput()

Base class for zone input nodes

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
inputs
items Return the items collection
name
node
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
output
outputs
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
capture(value, domain='POINT')

Capture something as an input to the simulation

BaseZoneOutput

BaseZoneOutput()

Base class for zone output nodes

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
inputs
items Return the items collection
name
node
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
outputs
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
capture(value, domain='POINT')

Capture something as an input to the simulation

ForEachGeometryElementInput

ForEachGeometryElementInput(geometry=None, selection=True)

For Each Geometry Element Input node

Attributes

Name Description
i
inputs
items
name
node
o
output
outputs
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
capture(value, domain='POINT')

Capture something as an input to the simulation

ForEachGeometryElementOutput

ForEachGeometryElementOutput(domain='POINT', **kwargs)

For Each Geometry Element Output node

Attributes

Name Description
domain
i
inputs
items
items_generated
name
node
o
outputs
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture_generated
capture
capture(value, domain='POINT')

Capture something as an input to the simulation

capture_generated
capture_generated(value)

ForEachGeometryElementZone

ForEachGeometryElementZone(geometry=None, selection=True, *, domain='POINT')

Attributes

Name Description
index
input
output

RepeatInput

RepeatInput(iterations=1)

Repeat Input node

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
inputs
items
name
node
o
output
outputs
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
capture(value, domain='POINT')

Capture something as an input to the simulation

RepeatOutput

RepeatOutput()

Repeat Output node

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
inputs
items
name
node
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
outputs
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
capture(value, domain='POINT')

Capture something as an input to the simulation

RepeatZone

RepeatZone(iterations=1, *args, **kwargs)

Wrapper that supports both direct unpacking and iteration

Attributes

Name Description
i The current iteration index.
input
output

SimulationInput

SimulationInput()

Simulation Input node

Attributes

Name Description
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
inputs
items
name
node
o
output
outputs
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
capture(value, domain='POINT')

Capture something as an input to the simulation

SimulationOutput

SimulationOutput()

Simulation Output node

Attributes

Name Description
i
inputs
items
name
node
o Output socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
outputs
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
capture(value, domain='POINT')

Capture something as an input to the simulation

SimulationZone

SimulationZone(*args, **kwargs)

Attributes

Name Description
delta_time
input
output