nodes.geometry.zone

nodes.geometry.zone

Classes

Name Description
BaseRepeatZone
BaseSimulationZone
BaseZone
BaseZoneInput Base class for zone input nodes
BaseZoneOutput Base class for zone output nodes
ForEachGeometryElementInput For Each Geometry Element Input node
ForEachGeometryElementOutput For Each Geometry Element Output node
ForEachGeometryElementZone
RepeatInput Repeat Input node
RepeatOutput Repeat Output node
RepeatZone Wrapper that supports both direct unpacking and iteration
SimulationInput Simulation Input node
SimulationOutput Simulation Output node
SimulationZone

BaseRepeatZone

nodes.geometry.zone.BaseRepeatZone()

Attributes

Name Description
inputs Get all input sockets based on items collection
items
name
node
outputs Get all output sockets based on items collection
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
nodes.geometry.zone.BaseRepeatZone.capture(value, domain='POINT')

Capture something as an input to the simulation

BaseSimulationZone

nodes.geometry.zone.BaseSimulationZone()

Attributes

Name Description
inputs Get all input sockets based on items collection
items
name
node
outputs Get all output sockets based on items collection
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
nodes.geometry.zone.BaseSimulationZone.capture(value, domain='POINT')

Capture something as an input to the simulation

BaseZone

nodes.geometry.zone.BaseZone()

Attributes

Name Description
inputs Get all input sockets based on items collection
items Return the items collection
name
node
outputs Get all output sockets based on items collection
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
nodes.geometry.zone.BaseZone.capture(value, domain='POINT')

Capture something as an input to the simulation

BaseZoneInput

nodes.geometry.zone.BaseZoneInput()

Base class for zone input nodes

Attributes

Name Description
inputs Get all input sockets based on items collection
items Return the items collection
name
node
output
outputs Get all output sockets based on items collection
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
nodes.geometry.zone.BaseZoneInput.capture(value, domain='POINT')

Capture something as an input to the simulation

BaseZoneOutput

nodes.geometry.zone.BaseZoneOutput()

Base class for zone output nodes

Attributes

Name Description
inputs Get all input sockets based on items collection
items Return the items collection
name
node
outputs Get all output sockets based on items collection
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
nodes.geometry.zone.BaseZoneOutput.capture(value, domain='POINT')

Capture something as an input to the simulation

ForEachGeometryElementInput

nodes.geometry.zone.ForEachGeometryElementInput(geometry=None, selection=True)

For Each Geometry Element Input node

Attributes

Name Description
i_geometry Input socket: Geometry
i_selection Input socket: Selection
inputs Get all input sockets based on items collection
items
name
node
o_index Output socket: Index
output
outputs Get all output sockets based on items collection
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
nodes.geometry.zone.ForEachGeometryElementInput.capture(value, domain='POINT')

Capture something as an input to the simulation

ForEachGeometryElementOutput

nodes.geometry.zone.ForEachGeometryElementOutput(domain='POINT', **kwargs)

For Each Geometry Element Output node

Attributes

Name Description
domain
i_geometry Input socket: Geometry
inputs Get all input sockets based on items collection
items
items_generated
name
node
o_generation Output socket: Geometry
o_geometry Output socket: Geometry
outputs Get all output sockets based on items collection
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture_generated
capture
nodes.geometry.zone.ForEachGeometryElementOutput.capture(value, domain='POINT')

Capture something as an input to the simulation

capture_generated
nodes.geometry.zone.ForEachGeometryElementOutput.capture_generated(value)

ForEachGeometryElementZone

nodes.geometry.zone.ForEachGeometryElementZone(
    geometry=None,
    selection=True,
    *,
    domain='POINT',
)

Attributes

Name Description
index
input
output

RepeatInput

nodes.geometry.zone.RepeatInput(iterations=1)

Repeat Input node

Attributes

Name Description
inputs Get all input sockets based on items collection
items
name
node
o_iteration Output socket: Iteration
output
outputs Get all output sockets based on items collection
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
nodes.geometry.zone.RepeatInput.capture(value, domain='POINT')

Capture something as an input to the simulation

RepeatOutput

nodes.geometry.zone.RepeatOutput()

Repeat Output node

Attributes

Name Description
inputs Get all input sockets based on items collection
items
name
node
outputs Get all output sockets based on items collection
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
nodes.geometry.zone.RepeatOutput.capture(value, domain='POINT')

Capture something as an input to the simulation

RepeatZone

nodes.geometry.zone.RepeatZone(iterations=1, *args, **kwargs)

Wrapper that supports both direct unpacking and iteration

Attributes

Name Description
i Input socket: Skip simluation frame
input
output

SimulationInput

nodes.geometry.zone.SimulationInput()

Simulation Input node

Attributes

Name Description
inputs Get all input sockets based on items collection
items
name
node
o_delta_time Output socket: Delta Time
output
outputs Get all output sockets based on items collection
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
nodes.geometry.zone.SimulationInput.capture(value, domain='POINT')

Capture something as an input to the simulation

SimulationOutput

nodes.geometry.zone.SimulationOutput()

Simulation Output node

Attributes

Name Description
i_skip Input socket: Skip simluation frame
inputs Get all input sockets based on items collection
items
name
node
outputs Get all output sockets based on items collection
tree
type

Methods

Name Description
capture Capture something as an input to the simulation
capture
nodes.geometry.zone.SimulationOutput.capture(value, domain='POINT')

Capture something as an input to the simulation

SimulationZone

nodes.geometry.zone.SimulationZone(*args, **kwargs)

Attributes

Name Description
input
output

Methods

Name Description
delta_time
delta_time
nodes.geometry.zone.SimulationZone.delta_time()