nodes.shader.manual

manual

Classes

Name Description
Attribute Retrieve attributes attached to objects or geometry
MenuSwitch Node builder for the Menu Switch node (Shader tree)

Attribute

Attribute(attribute_type='GEOMETRY', attribute_name='')

Retrieve attributes attached to objects or geometry

Attributes

Name Description
attribute_name
attribute_type
i Input socket accessor. Subclasses narrow the return type via TYPE_CHECKING.
name
node
o
outputs
tree
type

Methods

Name Description
geometry Create Attribute with operation ‘Geometry’.
instancer Create Attribute with operation ‘Instancer’.
object Create Attribute with operation ‘Object’.
view_layer Create Attribute with operation ‘View Layer’.
geometry
geometry(attribute_name='')

Create Attribute with operation ‘Geometry’.

instancer
instancer(attribute_name='')

Create Attribute with operation ‘Instancer’.

object
object(attribute_name='')

Create Attribute with operation ‘Object’.

view_layer
view_layer(attribute_name='')

Create Attribute with operation ‘View Layer’.

MenuSwitch

MenuSwitch(menu=None, items={}, *, data_type='FLOAT')

Node builder for the Menu Switch node (Shader tree)

Attributes

Name Description
data_type Input socket: Data Type
i
name
node
o
outputs
tree
type

Methods

Name Description
boolean
bundle
closure
color
float
integer
is_selected Gets the boolean output socket that is True when the named menu item is selected.
menu
shader
vector
boolean
boolean(menu=None, items={})
bundle
bundle(menu=None, items={})
closure
closure(menu=None, items={})
color
color(menu=None, items={})
float
float(menu=None, items={})
integer
integer(menu=None, items={})
is_selected
is_selected(name)

Gets the boolean output socket that is True when the named menu item is selected.

Cannot be used with the “Output” name as this refers to the output socket itself.

Parameters
Name Type Description Default
name str The name of the menu item to get the selected socket for. required
Returns
Name Type Description
BooleanSocket The boolean output socket that is True when the named menu item is selected.
menu
menu(menu=None, items={})
shader
shader(menu=None, items={})
vector
vector(menu=None, items={})

Functions

Name Description
material
tree

material

material(
    name='New Material',
    *,
    collapse=False,
    arrange='sugiyama',
    fake_user=False,
)

tree

tree(
    name='Shader Nodes',
    *,
    collapse=False,
    arrange='sugiyama',
    fake_user=False,
)