nodes.shader.output
output
Classes
| Name | Description |
|---|---|
| AovOutput | Arbitrary Output Variables. |
| LightOutput | Output light information to a light object |
| LineStyleOutput | Control the mixing of texture information into the base color of line styles |
| MaterialOutput | Output surface material information for use in rendering |
| WorldOutput | Output light color information to the scene’s World |
AovOutput
AovOutput(color=None, value=0.0, *, aov_name='')Arbitrary Output Variables.
Provide custom render passes for arbitrary shader node outputs
Parameters
color : InputColor
Color
value : InputFloat
Value
Inputs
i.color : ColorSocket
Color
i.value : FloatSocket
Value
Attributes
| Name | Description |
|---|---|
aov_name |
|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
LightOutput
LightOutput(surface=None, *, is_active_output=False, target='ALL')Output light information to a light object
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| surface | InputShader | Surface | None |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
is_active_output |
|
name |
|
node |
|
o |
|
outputs |
|
target |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.surface |
ShaderSocket |
Surface |
LineStyleOutput
LineStyleOutput(
color=None,
color_fac=1.0,
alpha=1.0,
alpha_fac=1.0,
*,
is_active_output=False,
target='ALL',
blend_type='MIX',
use_alpha=False,
use_clamp=False,
)Control the mixing of texture information into the base color of line styles
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| color | InputColor | Color | None |
| color_fac | InputFloat | Color Fac | 1.0 |
| alpha | InputFloat | Alpha | 1.0 |
| alpha_fac | InputFloat | Alpha Fac | 1.0 |
Attributes
| Name | Description |
|---|---|
blend_type |
|
i |
|
inputs |
|
is_active_output |
|
name |
|
node |
|
o |
|
outputs |
|
target |
|
tree |
|
type |
|
use_alpha |
|
use_clamp |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.color |
ColorSocket |
Color |
i.color_fac |
FloatSocket |
Color Fac |
i.alpha |
FloatSocket |
Alpha |
i.alpha_fac |
FloatSocket |
Alpha Fac |
MaterialOutput
MaterialOutput(
surface=None,
volume=None,
displacement=None,
thickness=0.0,
*,
is_active_output=False,
target='ALL',
)Output surface material information for use in rendering
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| surface | InputShader | Surface | None |
| volume | InputShader | Volume | None |
| displacement | InputVector | Displacement | None |
| thickness | InputFloat | Thickness | 0.0 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
is_active_output |
|
name |
|
node |
|
o |
|
outputs |
|
target |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.surface |
ShaderSocket |
Surface |
i.volume |
ShaderSocket |
Volume |
i.displacement |
VectorSocket |
Displacement |
i.thickness |
FloatSocket |
Thickness |
WorldOutput
WorldOutput(surface=None, volume=None, *, is_active_output=False, target='ALL')Output light color information to the scene’s World
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| surface | InputShader | Surface | None |
| volume | InputShader | Volume | None |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
is_active_output |
|
name |
|
node |
|
o |
|
outputs |
|
target |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.surface |
ShaderSocket |
Surface |
i.volume |
ShaderSocket |
Volume |