nodes.shader.vector
vector
Classes
| Name | Description |
|---|---|
| Bump | Generate a perturbed normal from a height texture for bump mapping. Typically used for faking highly detailed surfaces |
| Displacement | Displace the surface along the surface normal |
| Mapping | Transform the input vector by applying translation, rotation, and scale |
| Normal | Generate a normal vector and a dot product |
| NormalMap | Generate a perturbed normal from an RGB normal map image. Typically used for faking highly detailed surfaces |
| VectorDisplacement | Displace the surface along an arbitrary direction |
| VectorTransform | Convert a vector, point, or normal between world, camera, and object coordinate space |
Bump
Bump(
strength=1.0,
distance=0.001,
filter_width=0.1,
height=1.0,
normal=None,
*,
invert=False,
)Generate a perturbed normal from a height texture for bump mapping. Typically used for faking highly detailed surfaces
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| strength | InputFloat | Strength | 1.0 |
| distance | InputFloat | Distance | 0.001 |
| filter_width | InputFloat | Filter Width | 0.1 |
| height | InputFloat | Height | 1.0 |
| normal | InputVector | Normal | None |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
invert |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.strength |
FloatSocket |
Strength |
i.distance |
FloatSocket |
Distance |
i.filter_width |
FloatSocket |
Filter Width |
i.height |
FloatSocket |
Height |
i.normal |
VectorSocket |
Normal |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.normal |
VectorSocket |
Normal |
Displacement
Displacement(
height=0.0,
midlevel=0.5,
scale=0.01,
normal=None,
*,
space='OBJECT',
)Displace the surface along the surface normal
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| height | InputFloat | Height | 0.0 |
| midlevel | InputFloat | Midlevel | 0.5 |
| scale | InputFloat | Scale | 0.01 |
| normal | InputVector | Normal | None |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
space |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.height |
FloatSocket |
Height |
i.midlevel |
FloatSocket |
Midlevel |
i.scale |
FloatSocket |
Scale |
i.normal |
VectorSocket |
Normal |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.displacement |
VectorSocket |
Displacement |
Mapping
Mapping(
vector=None,
location=None,
rotation=None,
scale=None,
*,
vector_type='POINT',
)Transform the input vector by applying translation, rotation, and scale
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vector | InputVector | Vector | None |
| location | InputVector | Location | None |
| rotation | InputVector | Rotation | None |
| scale | InputVector | Scale | None |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
|
vector_type |
Methods
| Name | Description |
|---|---|
| normal | Create Mapping with operation ‘Normal’. Transform a unit normal vector (Location is ignored) |
| point | Create Mapping with operation ‘Point’. Transform a point |
| texture | Create Mapping with operation ‘Texture’. Transform a texture by inverse mapping the texture coordinate |
| vector | Create Mapping with operation ‘Vector’. Transform a direction vector (Location is ignored) |
normal
normal(vector=None, rotation=None, scale=None)Create Mapping with operation ‘Normal’. Transform a unit normal vector (Location is ignored)
point
point(vector=None, location=None, rotation=None, scale=None)Create Mapping with operation ‘Point’. Transform a point
texture
texture(vector=None, location=None, rotation=None, scale=None)Create Mapping with operation ‘Texture’. Transform a texture by inverse mapping the texture coordinate
vector
vector(vector=None, rotation=None, scale=None)Create Mapping with operation ‘Vector’. Transform a direction vector (Location is ignored)
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vector |
VectorSocket |
Vector |
i.location |
VectorSocket |
Location |
i.rotation |
VectorSocket |
Rotation |
i.scale |
VectorSocket |
Scale |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.vector |
VectorSocket |
Vector |
Normal
Normal(normal=None)Generate a normal vector and a dot product
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| normal | InputVector | Normal | None |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.normal |
VectorSocket |
Normal |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.normal |
VectorSocket |
Normal |
o.dot |
FloatSocket |
Dot |
NormalMap
NormalMap(strength=1.0, color=None, *, space='TANGENT', uv_map='')Generate a perturbed normal from an RGB normal map image. Typically used for faking highly detailed surfaces
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| strength | InputFloat | Strength | 1.0 |
| color | InputColor | Color | None |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
space |
|
tree |
|
type |
|
uv_map |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.strength |
FloatSocket |
Strength |
i.color |
ColorSocket |
Color |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.normal |
VectorSocket |
Normal |
VectorDisplacement
VectorDisplacement(vector=None, midlevel=0.0, scale=0.01, *, space='TANGENT')Displace the surface along an arbitrary direction
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vector | InputColor | Vector | None |
| midlevel | InputFloat | Midlevel | 0.0 |
| scale | InputFloat | Scale | 0.01 |
Attributes
| Name | Description |
|---|---|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
space |
|
tree |
|
type |
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vector |
ColorSocket |
Vector |
i.midlevel |
FloatSocket |
Midlevel |
i.scale |
FloatSocket |
Scale |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.displacement |
VectorSocket |
Displacement |
VectorTransform
VectorTransform(
vector=None,
*,
vector_type='VECTOR',
convert_from='WORLD',
convert_to='OBJECT',
)Convert a vector, point, or normal between world, camera, and object coordinate space
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| vector | InputVector | Vector | None |
Attributes
| Name | Description |
|---|---|
convert_from |
|
convert_to |
|
i |
|
inputs |
|
name |
|
node |
|
o |
|
outputs |
|
tree |
|
type |
|
vector_type |
Methods
| Name | Description |
|---|---|
| normal | Create Vector Transform with operation ‘Normal’. Transform a normal vector with unit length |
| point | Create Vector Transform with operation ‘Point’. Transform a point |
| vector | Create Vector Transform with operation ‘Vector’. Transform a direction vector |
normal
normal(vector=None)Create Vector Transform with operation ‘Normal’. Transform a normal vector with unit length
point
point(vector=None)Create Vector Transform with operation ‘Point’. Transform a point
vector
vector(vector=None)Create Vector Transform with operation ‘Vector’. Transform a direction vector
Inputs
| Attribute | Type | Description |
|---|---|---|
i.vector |
VectorSocket |
Vector |
Outputs
| Attribute | Type | Description |
|---|---|---|
o.vector |
VectorSocket |
Vector |